=== added file 'tests/lib/dtr_cases.pl'
--- tests/lib/dtr_cases.pl	1970-01-01 00:00:00 +0000
+++ tests/lib/dtr_cases.pl	2010-10-07 19:35:15 +0000
@@ -0,0 +1,906 @@
+# -*- cperl -*-
+# Copyright (C) 2005-2006 MySQL AB
+# 
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; version 2 of the License.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+# This is a library file used by the Perl version of drizzle-test-run,
+# and is part of the translation of the Bourne shell script with the
+# same name.
+
+use File::Basename;
+use IO::File();
+use strict;
+
+use My::Config;
+
+sub collect_test_cases ($);
+sub collect_one_suite ($);
+sub collect_one_test_case ($$$$$$$$$);
+
+sub dtr_options_from_test_file($$);
+
+my $do_test;
+my $skip_test;
+
+sub init_pattern {
+  my ($from, $what)= @_;
+  if ( $from =~ /^[a-z0-9]$/ ) {
+    # Does not contain any regex, make the pattern match
+    # beginning of string
+    $from= "^$from";
+  }
+  # Check that pattern is a valid regex
+  eval { "" =~/$from/; 1 } or
+    dtr_error("Invalid regex '$from' passed to $what\nPerl says: $@");
+  return $from;
+}
+
+
+
+##############################################################################
+#
+#  Collect information about test cases we are to run
+#
+##############################################################################
+
+sub collect_test_cases ($) {
+  $do_test= init_pattern($::opt_do_test, "--do-test");
+  $skip_test= init_pattern($::opt_skip_test, "--skip-test");
+
+  my $suites= shift; # Semicolon separated list of test suites
+  my $cases = [];    # Array of hash
+
+  foreach my $suite (split(",", $suites))
+  {
+    push(@$cases, collect_one_suite($suite));
+  }
+
+
+  if ( @::opt_cases )
+  {
+    # Check that the tests specified was found
+    # in at least one suite
+    foreach my $test_name_spec ( @::opt_cases )
+    {
+      my $found= 0;
+      my ($sname, $tname, $extension)= split_testname($test_name_spec);
+      foreach my $test ( @$cases )
+      {
+	# test->{name} is always in suite.name format
+	if ( $test->{name} =~ /.*\.$tname/ )
+	{
+	  $found= 1;
+	}
+      }
+      if ( not $found )
+      {
+	dtr_error("Could not find $tname in any suite");
+      }
+    }
+  }
+
+  if ( $::opt_reorder )
+  {
+    # Reorder the test cases in an order that will make them faster to run
+    my %sort_criteria;
+
+    # Make a mapping of test name to a string that represents how that test
+    # should be sorted among the other tests.  Put the most important criterion
+    # first, then a sub-criterion, then sub-sub-criterion, et c.
+    foreach my $tinfo (@$cases)
+    {
+      my @criteria = ();
+
+      # Look for tests that muct be in run in a defined order
+      # that is defined by test having the same name except for
+      # the ending digit
+
+      # Put variables into hash
+      my $test_name= $tinfo->{'name'};
+      my $depend_on_test_name;
+      if ( $test_name =~ /^([\D]+)([0-9]{1})$/ )
+      {
+	my $base_name= $1;
+	my $idx= $2;
+	dtr_verbose("$test_name =>  $base_name idx=$idx");
+	if ( $idx > 1 )
+	{
+	  $idx-= 1;
+	  $base_name= "$base_name$idx";
+	  dtr_verbose("New basename $base_name");
+	}
+
+	foreach my $tinfo2 (@$cases)
+	{
+	  if ( $tinfo2->{'name'} eq $base_name )
+	  {
+	    dtr_verbose("found dependent test $tinfo2->{'name'}");
+	    $depend_on_test_name=$base_name;
+	  }
+	}
+      }
+
+      if ( defined $depend_on_test_name )
+      {
+	dtr_verbose("Giving $test_name same critera as $depend_on_test_name");
+	$sort_criteria{$test_name} = $sort_criteria{$depend_on_test_name};
+      }
+      else
+      {
+	#
+	# Append the criteria for sorting, in order of importance.
+	#
+	# Group test with equal options together.
+	# Ending with "~" makes empty sort later than filled
+	push(@criteria, join("!", sort @{$tinfo->{'master_opt'}}) . "~");
+
+	$sort_criteria{$test_name} = join(" ", @criteria);
+      }
+    }
+
+    @$cases = sort {
+      $sort_criteria{$a->{'name'}} . $a->{'name'} cmp
+	$sort_criteria{$b->{'name'}} . $b->{'name'}; } @$cases;
+
+    if ( $::opt_script_debug )
+    {
+      # For debugging the sort-order
+      foreach my $tinfo (@$cases)
+      {
+	print("$sort_criteria{$tinfo->{'name'}} -> \t$tinfo->{'name'}\n");
+      }
+    }
+  }
+
+  return $cases;
+
+}
+
+# Valid extensions and their corresonding component id
+my %exts = ( 'test' => 'drizzled',
+	     'imtest' => 'im'
+	   );
+
+
+# Returns (suitename, testname, extension)
+sub split_testname {
+  my ($test_name)= @_;
+
+  # Get rid of directory part and split name on .'s
+  my @parts= split(/\./, basename($test_name));
+
+  if (@parts == 1){
+    # Only testname given, ex: alias
+    return (undef , $parts[0], undef);
+  } elsif (@parts == 2) {
+    # Either testname.test or suite.testname given
+    # Ex. main.alias or alias.test
+
+    if (defined $exts{$parts[1]})
+    {
+      return (undef , $parts[0], $parts[1]);
+    }
+    else
+    {
+      return ($parts[0], $parts[1], undef);
+    }
+
+  } elsif (@parts == 3) {
+    # Fully specified suitename.testname.test
+    # ex main.alias.test
+    return ( $parts[0], $parts[1], $parts[2]);
+  }
+
+  dtr_error("Illegal format of test name: $test_name");
+}
+
+
+sub collect_one_suite($)
+{
+  my $suite= shift;  # Test suite name
+  my @cases;  # Array of hash
+
+  dtr_verbose("Collecting: $suite");
+
+  my $suitepath= "$::glob_suite_path";
+  my $suitedir= "$::glob_drizzle_test_dir"; # Default
+  if ( $suite ne "main" )
+  {
+    $suitedir= dtr_path_exists(
+             "$suitepath/$suite/drizzle-tests",
+             "$suitepath/$suite/tests",
+             "$suitedir/suite/$suite",
+			       "$suitedir/$suite");
+    dtr_verbose("suitedir: $suitedir");
+  }
+
+  my $testdir= "$suitedir/t";
+  my $resdir=  "$suitedir/r";
+
+  # ----------------------------------------------------------------------
+  # Build a hash of disabled testcases for this suite
+  # ----------------------------------------------------------------------
+  my %disabled;
+  if ( open(DISABLED, "$testdir/disabled.def" ) )
+  {
+    while ( <DISABLED> )
+      {
+        chomp;
+        if ( /^\s*(\S+)\s*:\s*(.*?)\s*$/ )
+          {
+            $disabled{$1}= $2;
+          }
+      }
+    close DISABLED;
+  }
+
+  # Read suite.opt file
+  my $suite_opt_file=  "$testdir/suite.opt";
+  my $suite_opts= [];
+  if ( -f $suite_opt_file )
+  {
+    $suite_opts= dtr_get_opts_from_file($suite_opt_file);
+  }
+
+  if ( @::opt_cases )
+  {
+    # Collect in specified order
+    foreach my $test_name_spec ( @::opt_cases )
+    {
+      my ($sname, $tname, $extension)= split_testname($test_name_spec);
+
+      # The test name parts have now been defined
+      #print "  suite_name: $sname\n";
+      #print "  tname:      $tname\n";
+      #print "  extension:  $extension\n";
+
+      # Check cirrect suite if suitename is defined
+      next if (defined $sname and $suite ne $sname);
+
+      my $component_id;
+      if ( defined $extension )
+      {
+	my $full_name= "$testdir/$tname.$extension";
+	# Extension was specified, check if the test exists
+        if ( ! -f $full_name)
+        {
+	  # This is only an error if suite was specified, otherwise it
+	  # could exist in another suite
+          dtr_error("Test '$full_name' was not found in suite '$sname'")
+	    if $sname;
+
+	  next;
+        }
+	$component_id= $exts{$extension};
+      }
+      else
+      {
+	# No extension was specified
+	my ($ext, $component);
+	while (($ext, $component)= each %exts) {
+	  my $full_name= "$testdir/$tname.$ext";
+
+	  if ( ! -f $full_name ) {
+	    next;
+	  }
+	  $component_id= $component;
+	  $extension= $ext;
+	}
+	# Test not found here, could exist in other suite
+	next unless $component_id;
+      }
+
+      collect_one_test_case($testdir,$resdir,$suite,$tname,
+                            "$tname.$extension",\@cases,\%disabled,
+			    $component_id,$suite_opts);
+    }
+  }
+  else
+  {
+    opendir(TESTDIR, $testdir) or dtr_error("Can't open dir \"$testdir\": $!");
+
+    foreach my $elem ( sort readdir(TESTDIR) )
+    {
+      my $component_id= undef;
+      my $tname= undef;
+
+      if ($tname= dtr_match_extension($elem, 'test'))
+      {
+        $component_id = 'drizzled';
+      }
+      elsif ($tname= dtr_match_extension($elem, 'imtest'))
+      {
+        $component_id = 'im';
+      }
+      else
+      {
+        next;
+      }
+
+      # Skip tests that does not match the --do-test= filter
+      next if ($do_test and not $tname =~ /$do_test/o);
+
+      collect_one_test_case($testdir,$resdir,$suite,$tname,
+                            $elem,\@cases,\%disabled,$component_id,
+			    $suite_opts);
+    }
+    closedir TESTDIR;
+  }
+
+
+  #  Return empty list if no testcases found
+  return if (@cases == 0);
+
+  # ----------------------------------------------------------------------
+  # Read combinations for this suite and build testcases x combinations
+  # if any combinations exists
+  # ----------------------------------------------------------------------
+  if ( ! $::opt_skip_combination )
+  {
+    my @combinations;
+    my $combination_file= "$suitedir/combinations";
+    #print "combination_file: $combination_file\n";
+    if (@::opt_combinations)
+    {
+      # take the combination from command-line
+      dtr_verbose("Take the combination from command line");
+      foreach my $combination (@::opt_combinations) {
+	my $comb= {};
+	$comb->{name}= $combination;
+	push(@{$comb->{comb_opt}}, $combination);
+	push(@combinations, $comb);
+      }
+    }
+    elsif (-f $combination_file )
+    {
+      # Read combinations file in my.cnf format
+      dtr_verbose("Read combinations file");
+      my $config= My::Config->new($combination_file);
+
+      foreach my $group ($config->groups()) {
+	my $comb= {};
+	$comb->{name}= $group->name();
+        foreach my $option ( $group->options() ) {
+	  push(@{$comb->{comb_opt}}, $option->name()."=".$option->value());
+	}
+	push(@combinations, $comb);
+      }
+    }
+
+    if (@combinations)
+    {
+      print " - adding combinations\n";
+      #print_testcases(@cases);
+
+      my @new_cases;
+      foreach my $comb (@combinations)
+      {
+	foreach my $test (@cases)
+	{
+	  #print $test->{name}, " ", $comb, "\n";
+	  my $new_test= {};
+
+	  while (my ($key, $value) = each(%$test)) {
+	    if (ref $value eq "ARRAY") {
+	      push(@{$new_test->{$key}}, @$value);
+	    } else {
+	      $new_test->{$key}= $value;
+	    }
+	  }
+
+	  # Append the combination options to master_opt and slave_opt
+	  push(@{$new_test->{master_opt}}, @{$comb->{comb_opt}});
+	  push(@{$new_test->{slave_opt}}, @{$comb->{comb_opt}});
+
+	  # Add combination name shrt name
+	  $new_test->{combination}= $comb->{name};
+
+	  # Add the new test to new test cases list
+	  push(@new_cases, $new_test);
+	}
+      }
+      #print_testcases(@new_cases);
+      @cases= @new_cases;
+      #print_testcases(@cases);
+    }
+  }
+
+  optimize_cases(\@cases);
+  #print_testcases(@cases);
+
+  return @cases;
+}
+
+
+#
+# Loop through all test cases
+# - optimize which test to run by skipping unnecessary ones
+# - update settings if necessary
+#
+sub optimize_cases {
+  my ($cases)= @_;
+
+  foreach my $tinfo ( @$cases )
+  {
+    # Skip processing if already marked as skipped
+    next if $tinfo->{skip};
+
+    # Replication test needs an adjustment of binlog format
+    if (dtr_match_prefix($tinfo->{'name'}, "rpl"))
+    {
+
+      # =======================================================
+      # Get binlog-format used by this test from master_opt
+      # =======================================================
+      my $test_binlog_format;
+      foreach my $opt ( @{$tinfo->{master_opt}} ) {
+	$test_binlog_format= $test_binlog_format ||
+	  dtr_match_prefix($opt, "--binlog-format=");
+      }
+      # print $tinfo->{name}." uses ".$test_binlog_format."\n";
+
+      # =======================================================
+      # If a special binlog format was selected with
+      # --drizzled=--binlog-format=x, skip all test with different
+      # binlog-format
+      # =======================================================
+      if (defined $::used_binlog_format and
+	  $test_binlog_format and
+	  $::used_binlog_format ne $test_binlog_format)
+      {
+	$tinfo->{'skip'}= 1;
+	$tinfo->{'comment'}= "Requires --binlog-format='$test_binlog_format'";
+	next;
+      }
+
+      # =======================================================
+      # Check that testcase supports the designated binlog-format
+      # =======================================================
+      if ($test_binlog_format and defined $tinfo->{'sup_binlog_formats'} )
+      {
+	my $supported=
+	  grep { $_ eq $test_binlog_format } @{$tinfo->{'sup_binlog_formats'}};
+	if ( !$supported )
+	{
+	  $tinfo->{'skip'}= 1;
+	  $tinfo->{'comment'}=
+	    "Doesn't support --binlog-format='$test_binlog_format'";
+	  next;
+	}
+      }
+
+      # =======================================================
+      # Use dynamic switching of binlog-format if dtr started
+      # w/o --drizzled=--binlog-format=xxx and combinations.
+      # =======================================================
+      if (!defined $tinfo->{'combination'} and
+          !defined $::used_binlog_format)
+      {
+        $test_binlog_format= $tinfo->{'sup_binlog_formats'}->[0];
+      }
+
+      # Save binlog format for dynamic switching
+      $tinfo->{binlog_format}= $test_binlog_format;
+    }
+  }
+}
+
+
+##############################################################################
+#
+#  Collect information about a single test case
+#
+##############################################################################
+
+
+sub collect_one_test_case($$$$$$$$$) {
+  my $testdir= shift;
+  my $resdir=  shift;
+  my $suite=   shift;
+  my $tname=   shift;
+  my $elem=    shift;
+  my $cases=   shift;
+  my $disabled=shift;
+  my $component_id= shift;
+  my $suite_opts= shift;
+
+  my $path= "$testdir/$elem";
+
+  # ----------------------------------------------------------------------
+  # Skip some tests silently
+  # ----------------------------------------------------------------------
+
+  if ( $::opt_start_from and $tname lt $::opt_start_from )
+  {
+    return;
+  }
+
+
+  my $tinfo= {};
+  $tinfo->{'name'}= basename($suite) . ".$tname";
+  if ( -f "$resdir/$::opt_engine/$tname.result")
+  {
+    $tinfo->{'result_file'}= "$resdir/$::opt_engine/$tname.result";
+  }
+  else
+  {
+    $tinfo->{'result_file'}= "$resdir/$tname.result";
+  }
+  $tinfo->{'component_id'} = $component_id;
+  push(@$cases, $tinfo);
+
+  # ----------------------------------------------------------------------
+  # Skip some tests but include in list, just mark them to skip
+  # ----------------------------------------------------------------------
+
+  if ( $skip_test and $tname =~ /$skip_test/o )
+  {
+    $tinfo->{'skip'}= 1;
+    return;
+  }
+
+  # ----------------------------------------------------------------------
+  # Collect information about test case
+  # ----------------------------------------------------------------------
+
+  $tinfo->{'path'}= $path;
+  $tinfo->{'timezone'}= "GMT-3"; # for UNIX_TIMESTAMP tests to work
+
+  $tinfo->{'slave_num'}= 0; # Default, no slave
+  $tinfo->{'master_num'}= 1; # Default, 1 master
+  if ( defined dtr_match_prefix($tname,"rpl") )
+  {
+    if ( $::opt_skip_rpl )
+    {
+      $tinfo->{'skip'}= 1;
+      $tinfo->{'comment'}= "No replication tests(--skip-rpl)";
+      return;
+    }
+
+    $tinfo->{'slave_num'}= 1; # Default for rpl* tests, use one slave
+
+  }
+
+  if ( defined dtr_match_prefix($tname,"federated") )
+  {
+    # Default, federated uses the first slave as it's federated database
+    $tinfo->{'slave_num'}= 1;
+  }
+
+  my $global_master_opt_file= "$testdir/master.opt";
+  my $test_master_opt_file= "$testdir/$tname-master.opt";
+  my $slave_opt_file=  "$testdir/$tname-slave.opt";
+  my $slave_mi_file=   "$testdir/$tname.slave-mi";
+  my $master_sh=       "$testdir/$tname-master.sh";
+  my $slave_sh=        "$testdir/$tname-slave.sh";
+  my $disabled_file=   "$testdir/$tname.disabled";
+  my $im_opt_file=     "$testdir/$tname-im.opt";
+
+  $tinfo->{'master_opt'}= [];
+  $tinfo->{'slave_opt'}=  [];
+  $tinfo->{'slave_mi'}=   [];
+
+
+  # Add suite opts
+  foreach my $opt ( @$suite_opts )
+  {
+    dtr_verbose($opt);
+    push(@{$tinfo->{'master_opt'}}, $opt);
+    push(@{$tinfo->{'slave_opt'}}, $opt);
+  }
+
+  foreach  my $master_opt_file ($global_master_opt_file, $test_master_opt_file)
+  {
+    # Add master opts
+    if ( -f $master_opt_file )
+    {
+
+      my $master_opt= dtr_get_opts_from_file($master_opt_file);
+
+      foreach my $opt ( @$master_opt )
+      {
+        my $value;
+
+        # The opt file is used both to send special options to the drizzled
+        # as well as pass special test case specific options to this
+        # script
+
+        $value= dtr_match_prefix($opt, "--timezone=");
+        if ( defined $value )
+        {
+          $tinfo->{'timezone'}= $value;
+          next;
+        }
+
+        $value= dtr_match_prefix($opt, "--slave-num=");
+        if ( defined $value )
+        {
+          $tinfo->{'slave_num'}= $value;
+          next;
+        }
+
+        $value= dtr_match_prefix($opt, "--result-file=");
+        if ( defined $value )
+        {
+          # Specifies the file drizzletest should compare
+          # output against
+          if ( -f "r/$::opt_engine/$value.result")
+          {
+            $tinfo->{'result_file'}= "r/$::opt_engine/$value.result";
+          }
+          else
+          {
+            $tinfo->{'result_file'}= "r/$value.result";
+          }
+
+          next;
+        }
+
+        # If we set default time zone, remove the one we have
+        $value= dtr_match_prefix($opt, "--default-time-zone=");
+        if ( defined $value )
+        {
+          # Set timezone for this test case to something different
+          $tinfo->{'timezone'}= "GMT-8";
+          # Fallthrough, add the --default-time-zone option
+        }
+
+        # The --restart option forces a restart even if no special
+        # option is set. If the options are the same as next testcase
+        # there is no need to restart after the testcase
+        # has completed
+        if ( $opt eq "--force-restart" )
+        {
+          $tinfo->{'force_restart'}= 1;
+          next;
+        }
+
+        # Ok, this was a real option, add it
+        push(@{$tinfo->{'master_opt'}}, $opt);
+      }
+    }
+  }
+
+  # Add slave opts
+  if ( -f $slave_opt_file )
+  {
+    my $slave_opt= dtr_get_opts_from_file($slave_opt_file);
+
+    foreach my $opt ( @$slave_opt )
+    {
+      # If we set default time zone, remove the one we have
+      my $value= dtr_match_prefix($opt, "--default-time-zone=");
+      $tinfo->{'slave_opt'}= [] if defined $value;
+    }
+    push(@{$tinfo->{'slave_opt'}}, @$slave_opt);
+  }
+
+  if ( -f $slave_mi_file )
+  {
+    $tinfo->{'slave_mi'}= dtr_get_opts_from_file($slave_mi_file);
+  }
+
+  if ( -f $master_sh )
+  {
+    if ( $::glob_win32_perl )
+    {
+      $tinfo->{'skip'}= 1;
+      $tinfo->{'comment'}= "No tests with sh scripts on Windows";
+      return;
+    }
+    else
+    {
+      $tinfo->{'master_sh'}= $master_sh;
+    }
+  }
+
+  if ( -f $slave_sh )
+  {
+    if ( $::glob_win32_perl )
+    {
+      $tinfo->{'skip'}= 1;
+      $tinfo->{'comment'}= "No tests with sh scripts on Windows";
+      return;
+    }
+    else
+    {
+      $tinfo->{'slave_sh'}= $slave_sh;
+    }
+  }
+
+  if ( -f $im_opt_file )
+  {
+    $tinfo->{'im_opts'} = dtr_get_opts_from_file($im_opt_file);
+  }
+  else
+  {
+    $tinfo->{'im_opts'} = [];
+  }
+
+  # FIXME why this late?
+  my $marked_as_disabled= 0;
+  if ( $disabled->{$tname} )
+  {
+    $marked_as_disabled= 1;
+    $tinfo->{'comment'}= $disabled->{$tname};
+  }
+
+  if ( -f $disabled_file )
+  {
+    $marked_as_disabled= 1;
+    $tinfo->{'comment'}= dtr_fromfile($disabled_file);
+  }
+
+  # If test was marked as disabled, either opt_enable_disabled is off and then
+  # we skip this test, or it is on and then we run this test but warn
+
+  if ( $marked_as_disabled )
+  {
+    if ( $::opt_enable_disabled )
+    {
+      $tinfo->{'dont_skip_though_disabled'}= 1;
+    }
+    else
+    {
+      $tinfo->{'skip'}= 1;
+      $tinfo->{'disable'}= 1;   # Sub type of 'skip'
+      return;
+    }
+  }
+
+  if ( $component_id eq 'im' )
+  {
+    if ( $::glob_use_embedded_server )
+    {
+      $tinfo->{'skip'}= 1;
+      $tinfo->{'comment'}= "No IM with embedded server";
+      return;
+    }
+    elsif ( $::opt_ps_protocol )
+    {
+      $tinfo->{'skip'}= 1;
+      $tinfo->{'comment'}= "No IM with --ps-protocol";
+      return;
+    }
+    elsif ( $::opt_skip_im )
+    {
+      $tinfo->{'skip'}= 1;
+      $tinfo->{'comment'}= "No IM tests(--skip-im)";
+      return;
+    }
+  }
+  else
+  {
+    dtr_options_from_test_file($tinfo,"$testdir/${tname}.test");
+
+    if ( defined $::used_default_engine )
+    {
+      # Different default engine is used
+      # tag test to require that engine
+      $tinfo->{'ndb_test'}= 1
+	if ( $::used_default_engine =~ /^ndb/i );
+
+      $tinfo->{'innodb_test'}= 1
+	if ( $::used_default_engine =~ /^innodb/i );
+    }
+
+    if ( $tinfo->{'ndb_extra'} and ! $::opt_ndb_extra_test )
+    {
+      $tinfo->{'skip'}= 1;
+      $tinfo->{'comment'}= "Test need 'ndb_extra' option";
+      return;
+    }
+
+    if ( $tinfo->{'require_manager'} )
+    {
+      $tinfo->{'skip'}= 1;
+      $tinfo->{'comment'}= "Test need the _old_ manager(to be removed)";
+      return;
+    }
+
+    if ( $tinfo->{'need_debug'} && ! $::debug_compiled_binaries )
+    {
+      $tinfo->{'skip'}= 1;
+      $tinfo->{'comment'}= "Test need debug binaries";
+      return;
+    }
+  }
+}
+
+
+# List of tags in the .test files that if found should set
+# the specified value in "tinfo"
+our @tags=
+(
+ ["include/have_innodb.inc", "innodb_test", 1],
+ ["include/have_binlog_format_row.inc", "sup_binlog_formats", ["row"]],
+ ["include/have_log_bin.inc", "need_binlog", 1],
+ ["include/have_binlog_format_statement.inc",
+  "sup_binlog_formats", ["statement"]],
+ ["include/have_binlog_format_mixed.inc", "sup_binlog_formats", ["mixed"]],
+ ["include/have_binlog_format_mixed_or_row.inc",
+  "sup_binlog_formats", ["mixed","row"]],
+ ["include/have_binlog_format_mixed_or_statement.inc",
+  "sup_binlog_formats", ["mixed","statement"]],
+ ["include/have_binlog_format_row_or_statement.inc",
+  "sup_binlog_formats", ["row","statement"]],
+ ["include/have_debug.inc", "need_debug", 1],
+ ["require_manager", "require_manager", 1],
+);
+
+sub dtr_options_from_test_file($$) {
+  my $tinfo= shift;
+  my $file= shift;
+  #dtr_verbose("$file");
+  my $F= IO::File->new($file) or dtr_error("can't open file \"$file\": $!");
+
+  while ( my $line= <$F> )
+  {
+
+    # Skip line if it start's with #
+    next if ( $line =~ /^#/ );
+
+    # Match this line against tag in "tags" array
+    foreach my $tag (@tags)
+    {
+      if ( index($line, $tag->[0]) >= 0 )
+      {
+    	  # Tag matched, assign value to "tinfo"
+        $tinfo->{"$tag->[1]"}= $tag->[2];
+      }
+    }
+
+    # If test sources another file, open it as well
+    if ( $line =~ /^\-\-([[:space:]]*)source(.*)$/ or
+	 $line =~ /^([[:space:]]*)source(.*);$/ )
+    {
+      my $value= $2;
+      $value =~ s/^\s+//;  # Remove leading space
+      $value =~ s/[[:space:]]+$//;  # Remove ending space
+
+      my $sourced_file= "$::glob_drizzle_test_dir/$value";
+      if ( -f $sourced_file )
+      {
+	# Only source the file if it exists, we may get
+	# false positives in the regexes above if someone
+	# writes "source nnnn;" in a test case(such as drizzletest.test)
+	dtr_options_from_test_file($tinfo, $sourced_file);
+      }
+    }
+  }
+}
+
+
+sub print_testcases {
+  my (@cases)= @_;
+
+  print "=" x 60, "\n";
+  foreach my $test (@cases){
+    print "[", $test->{name}, "]", "\n";
+    while ((my ($key, $value)) = each(%$test)) {
+      print " ", $key, "=";
+      if (ref $value eq "ARRAY") {
+	print join(", ", @$value);
+      } else {
+	print $value;
+      }
+      print "\n";
+    }
+    print "\n";
+  }
+  print "=" x 60, "\n";
+}
+
+
+1;

=== added file 'tests/lib/dtr_diff.pl'
--- tests/lib/dtr_diff.pl	1970-01-01 00:00:00 +0000
+++ tests/lib/dtr_diff.pl	2010-10-07 19:35:15 +0000
@@ -0,0 +1,297 @@
+# -*- cperl -*-
+# Copyright (C) 2005 MySQL AB
+# 
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; version 2 of the License.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+# This is a library file used by the Perl version of drizzle-test-run,
+# and is part of the translation of the Bourne shell script with the
+# same name.
+
+#use Data::Dumper;
+use strict;
+
+# $Data::Dumper::Indent= 1;
+
+sub dtr_diff($$);
+
+##############################################################################
+#
+#  This is a simplified unified diff, with some special handling
+#  of unsorted result sets
+#
+##############################################################################
+
+# FIXME replace die with dtr_error
+
+#require "dtr_report.pl";
+#dtr_diff("a.txt","b.txt");
+
+sub dtr_diff ($$) {
+  my $file1 = shift;
+  my $file2 = shift;
+
+  # ----------------------------------------------------------------------
+  # We read in all of the files at once
+  # ----------------------------------------------------------------------
+
+  unless ( open(FILE1, $file1) )
+  {
+    dtr_warning("can't open \"$file1\": $!");
+    return;
+  }
+
+  unless ( open(FILE2, $file2) )
+  {
+    dtr_warning("can't open \"$file2\": $!");
+    return;
+  }
+
+  my $lines1= collect_lines(<FILE1>);
+  my $lines2= collect_lines(<FILE2>);
+  close FILE1;
+  close FILE2;
+
+#  print Dumper($lines1);
+#  print Dumper($lines2);
+
+  # ----------------------------------------------------------------------
+  # We compare line by line, but don't shift off elements until we know
+  # what to do. This way we use the "restart" method, do simple change
+  # and restart by entering the diff loop from the beginning again.
+  # ----------------------------------------------------------------------
+
+  my @context;
+  my @info;                     # Collect information, and output later
+  my $lno1= 1;
+  my $lno2= 1;
+
+  while ( @$lines1 or @$lines2 )
+  {
+    unless ( @$lines1 )
+    {
+      push(@info, map {['+',$lno1,$lno2++,$_]} @$lines2);
+      last;
+    }
+    unless ( @$lines2 )
+    {
+      push(@info, map {['-',$lno1++,$lno2,$_]} @$lines1);
+      last;
+    }
+
+    # ----------------------------------------------------------------------
+    # We know both have lines
+    # ----------------------------------------------------------------------
+
+    if ( $lines1->[0] eq $lines2->[0] )
+    {
+      # Simple case, first line match and all is well
+      push(@info, ['',$lno1++,$lno2++,$lines1->[0]]);
+      shift @$lines1;
+      shift @$lines2;
+      next;
+    }
+
+    # ----------------------------------------------------------------------
+    # Now, we know they differ
+    # ----------------------------------------------------------------------
+
+    # How far in the other one, is there a match?
+
+    my $idx2= find_next_match($lines1->[0], $lines2);
+    my $idx1= find_next_match($lines2->[0], $lines1);
+
+    # Here we could test "if ( !defined $idx2 or !defined $idx1 )" and
+    # use a more complicated diff algorithm in the case both contains
+    # each others lines, just dislocated. But for this application, there
+    # should be no need.
+
+    if ( !defined $idx2 )
+    {
+      push(@info, ['-',$lno1++,$lno2,$lines1->[0]]);
+      shift @$lines1;
+    }
+    else
+    {
+      push(@info, ['+',$lno1,$lno2++,$lines2->[0]]);
+      shift @$lines2;
+    }
+  }
+
+  # ----------------------------------------------------------------------
+  # Try to output nicely
+  # ----------------------------------------------------------------------
+
+#  print Dumper(\@info);
+
+  # We divide into "chunks" to output
+  # We want at least three lines of context
+
+  my @chunks;
+  my @chunk;
+  my $state= 'pre';          # 'pre', 'in' and 'post' difference
+  my $post_count= 0;
+
+  foreach my $info ( @info )
+  {
+    if ( $info->[0] eq '' and $state eq 'pre' )
+    {
+      # Collect no more than three lines of context before diff
+      push(@chunk, $info);
+      shift(@chunk) if @chunk > 3;
+      next;
+    }
+
+    if ( $info->[0] =~ /(\+|\-)/ and $state =~ /(pre|in)/ )
+    {
+      # Start/continue collecting diff
+      $state= 'in';
+      push(@chunk, $info);
+      next;
+    }
+
+    if ( $info->[0] eq '' and $state eq 'in' )
+    {
+      # Stop collecting diff, and collect context after diff
+      $state= 'post';
+      $post_count= 1;
+      push(@chunk, $info);
+      next;
+    }
+
+    if ( $info->[0] eq '' and $state eq 'post' and $post_count < 6 )
+    {
+      # We might find a new diff sequence soon, continue to collect
+      # non diffs but five up on 6.
+      $post_count++;
+      push(@chunk, $info);
+      next;
+    }
+
+    if ( $info->[0] eq '' and $state eq 'post' )
+    {
+      # We put an end to this, giving three non diff lines to
+      # the old chunk, and three to the new one.
+      my @left= splice(@chunk, -3, 3);
+      push(@chunks, [@chunk]);
+      $state= 'pre';
+      $post_count= 0;
+      @chunk= @left;
+      next;
+    }
+
+    if ( $info->[0] =~ /(\+|\-)/ and $state eq 'post' )
+    {
+      # We didn't split, continue collect diff
+      $state= 'in';
+      push(@chunk, $info);
+      next;
+    }
+
+  }
+
+  if ( $post_count > 3 )
+  {
+    $post_count -= 3;
+    splice(@chunk, -$post_count, $post_count);
+  }
+  push(@chunks, [@chunk]) if @chunk and $state ne 'pre';
+
+  foreach my $chunk ( @chunks )
+  {
+    my $from_file_start=  $chunk->[0]->[1];
+    my $to_file_start=    $chunk->[0]->[2];
+    my $from_file_offset= $chunk->[$#$chunk]->[1] - $from_file_start;
+    my $to_file_offset=   $chunk->[$#$chunk]->[2] - $to_file_start;
+    print "\@\@ -$from_file_start,$from_file_offset ",
+          "+$to_file_start,$to_file_offset \@\@\n";
+
+    foreach my $info ( @$chunk )
+    {
+      if ( $info->[0] eq '' )
+      {
+        print "  $info->[3]\n";
+      }
+      elsif ( $info->[0] eq '-' )
+      {
+        print "- $info->[3]\n";
+      }
+      elsif ( $info->[0] eq '+' )
+      {
+        print "+ $info->[3]\n";
+      }
+    }
+  }
+
+#  print Dumper(\@chunks);
+  
+}
+
+
+##############################################################################
+#  Find if the string is found in the array, return the index if found,
+#  if not found, return "undef"
+##############################################################################
+
+sub find_next_match {
+  my $line= shift;
+  my $lines= shift;
+
+  for ( my $idx= 0; $idx < @$lines; $idx++ )
+  {
+    return $idx if $lines->[$idx] eq $line;
+  }
+
+  return undef;                 # No match found
+}
+
+
+##############################################################################
+#  Just read the lines, but handle "sets" of lines that are unordered
+##############################################################################
+
+sub collect_lines {
+
+  my @recordset;
+  my @lines;
+
+  while (@_)
+  {
+    my $line= shift @_;
+    chomp($line);
+
+    if ( $line =~ /^\Q%unordered%\E\t/ )
+    {
+      push(@recordset, $line);
+    }
+    elsif ( @recordset )
+    {
+      push(@lines, sort @recordset);
+      @recordset= ();         # Clear it
+    }
+    else
+    {
+      push(@lines, $line);
+    }
+  }
+
+  if ( @recordset )
+  {
+    push(@lines, sort @recordset);
+    @recordset= ();         # Clear it
+  }
+
+  return \@lines;
+}
+
+1;

=== added file 'tests/lib/dtr_gcov.pl'
--- tests/lib/dtr_gcov.pl	1970-01-01 00:00:00 +0000
+++ tests/lib/dtr_gcov.pl	2010-10-07 19:35:15 +0000
@@ -0,0 +1,74 @@
+# -*- cperl -*-
+# Copyright (C) 2004, 2006 MySQL AB
+# 
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; version 2 of the License.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+# This is a library file used by the Perl version of drizzle-test-run,
+# and is part of the translation of the Bourne shell script with the
+# same name.
+
+use strict;
+
+# These are not to be prefixed with "dtr_"
+
+sub gcov_prepare ();
+sub gcov_collect ();
+
+##############################################################################
+#
+#  
+#
+##############################################################################
+
+sub gcov_prepare () {
+
+  `find $::glob_basedir -name \*.gcov \
+    -or -name \*.da | xargs rm`;
+}
+
+# Used by gcov
+our @drizzled_src_dirs=
+  (
+   "strings",
+   "mysys",
+   "include",
+   "extra",
+   "regex",
+   "isam",
+   "merge",
+   "myisam",
+   "myisammrg",
+   "MEMORY",
+   "sql",
+  );
+
+sub gcov_collect () {
+
+  print "Collecting source coverage info...\n";
+  -f $::opt_gcov_msg and unlink($::opt_gcov_msg);
+  -f $::opt_gcov_err and unlink($::opt_gcov_err);
+  foreach my $d ( @drizzled_src_dirs )
+  {
+    chdir("$::glob_basedir/$d");
+    foreach my $f ( (glob("*.h"), glob("*.cc"), glob("*.c")) )
+    {
+      `$::opt_gcov $f 2>>$::opt_gcov_err  >>$::opt_gcov_msg`;
+    }
+    chdir($::glob_drizzle_test_dir);
+  }
+  print "gcov info in $::opt_gcov_msg, errors in $::opt_gcov_err\n";
+}
+
+
+1;

=== added file 'tests/lib/dtr_gprof.pl'
--- tests/lib/dtr_gprof.pl	1970-01-01 00:00:00 +0000
+++ tests/lib/dtr_gprof.pl	2010-10-07 19:35:15 +0000
@@ -0,0 +1,64 @@
+# -*- cperl -*-
+# Copyright (C) 2004 MySQL AB
+# 
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; version 2 of the License.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+# This is a library file used by the Perl version of drizzle-test-run,
+# and is part of the translation of the Bourne shell script with the
+# same name.
+
+use strict;
+
+# These are not to be prefixed with "dtr_"
+
+sub gprof_prepare ();
+sub gprof_collect ();
+
+##############################################################################
+#
+#  
+#
+##############################################################################
+
+sub gprof_prepare () {
+
+  rdtree($::opt_gprof_dir);
+  mkdir($::opt_gprof_dir);
+}
+
+# FIXME what about master1 and slave1?!
+sub gprof_collect () {
+
+  if ( -f "$::master->[0]->{'path_myddir'}/gmon.out" )
+  {
+    # FIXME check result code?!
+    dtr_run("gprof",
+            [$::exe_master_drizzled,
+             "$::master->[0]->{'path_myddir'}/gmon.out"],
+            $::opt_gprof_master, "", "", "");
+    print "Master execution profile has been saved in $::opt_gprof_master\n";
+  }
+  if ( -f "$::slave->[0]->{'path_myddir'}/gmon.out" )
+  {
+    # FIXME check result code?!
+    dtr_run("gprof",
+            [$::exe_slave_drizzled,
+             "$::slave->[0]->{'path_myddir'}/gmon.out"],
+            $::opt_gprof_slave, "", "", "");
+    print "Slave execution profile has been saved in $::opt_gprof_slave\n";
+  }
+}
+
+
+1;

=== added file 'tests/lib/dtr_im.pl'
--- tests/lib/dtr_im.pl	1970-01-01 00:00:00 +0000
+++ tests/lib/dtr_im.pl	2010-10-07 19:35:15 +0000
@@ -0,0 +1,775 @@
+# -*- cperl -*-
+# Copyright (C) 2006 drizzle AB
+# 
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; version 2 of the License.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+# This is a library file used by the Perl version of drizzle-test-run,
+# and is part of the translation of the Bourne shell script with the
+# same name.
+
+use strict;
+
+# Private IM-related operations.
+
+sub dtr_im_kill_process ($$$$);
+sub dtr_im_load_pids ($);
+sub dtr_im_terminate ($);
+sub dtr_im_check_alive ($);
+sub dtr_im_check_main_alive ($);
+sub dtr_im_check_angel_alive ($);
+sub dtr_im_check_drizzleds_alive ($);
+sub dtr_im_check_drizzled_alive ($);
+sub dtr_im_cleanup ($);
+sub dtr_im_rm_file ($);
+sub dtr_im_errlog ($);
+sub dtr_im_kill ($);
+sub dtr_im_wait_for_connection ($$$);
+sub dtr_im_wait_for_drizzled($$$);
+
+# Public IM-related operations.
+
+sub dtr_im_start ($$);
+sub dtr_im_stop ($);
+
+##############################################################################
+#
+#  Private operations.
+#
+##############################################################################
+
+sub dtr_im_kill_process ($$$$) {
+  my $pid_lst= shift;
+  my $signal= shift;
+  my $total_retries= shift;
+  my $timeout= shift;
+
+  my %pids;
+
+  foreach my $pid ( @{$pid_lst} )
+  {
+    $pids{$pid}= 1;
+  }
+
+  for ( my $cur_attempt= 1; $cur_attempt <= $total_retries; ++$cur_attempt )
+  {
+    foreach my $pid ( keys %pids )
+    {
+      dtr_debug("Sending $signal to $pid...");
+
+      kill($signal, $pid);
+
+      unless ( kill (0, $pid) )
+      {
+        dtr_debug("Process $pid died.");
+        delete $pids{$pid};
+      }
+    }
+
+    return if scalar keys %pids == 0;
+
+    dtr_debug("Sleeping $timeout second(s) waiting for processes to die...");
+
+    sleep($timeout);
+  }
+
+  dtr_debug("Process(es) " .
+            join(' ', keys %pids) .
+            " is still alive after $total_retries " .
+            "of sending signal $signal.");
+}
+
+###########################################################################
+
+sub dtr_im_load_pids($) {
+  my $im= shift;
+
+  dtr_debug("Loading PID files...");
+
+  # Obtain drizzled-process pids.
+
+  my $instances = $im->{'instances'};
+
+  for ( my $idx= 0; $idx < 2; ++$idx )
+  {
+    dtr_debug("IM-guarded drizzled[$idx] PID file: '" .
+              $instances->[$idx]->{'path_pid'} . "'.");
+
+    my $drizzled_pid;
+
+    if ( -r $instances->[$idx]->{'path_pid'} )
+    {
+      $drizzled_pid= dtr_get_pid_from_file($instances->[$idx]->{'path_pid'});
+      dtr_debug("IM-guarded drizzled[$idx] PID: $drizzled_pid.");
+    }
+    else
+    {
+      $drizzled_pid= undef;
+      dtr_debug("IM-guarded drizzled[$idx]: no PID file.");
+    }
+
+    $instances->[$idx]->{'pid'}= $drizzled_pid;
+  }
+
+  # Re-read Instance Manager PIDs from the file, since during tests Instance
+  # Manager could have been restarted, so its PIDs could have been changed.
+
+  #   - IM-main
+
+  dtr_debug("IM-main PID file: '$im->{path_pid}'.");
+
+  if ( -f $im->{'path_pid'} )
+  {
+    $im->{'pid'} =
+      dtr_get_pid_from_file($im->{'path_pid'});
+
+    dtr_debug("IM-main PID: $im->{pid}.");
+  }
+  else
+  {
+    dtr_debug("IM-main: no PID file.");
+    $im->{'pid'}= undef;
+  }
+
+  #   - IM-angel
+
+  dtr_debug("IM-angel PID file: '$im->{path_angel_pid}'.");
+
+  if ( -f $im->{'path_angel_pid'} )
+  {
+    $im->{'angel_pid'} =
+      dtr_get_pid_from_file($im->{'path_angel_pid'});
+
+    dtr_debug("IM-angel PID: $im->{'angel_pid'}.");
+  }
+  else
+  {
+    dtr_debug("IM-angel: no PID file.");
+    $im->{'angel_pid'} = undef;
+  }
+}
+
+###########################################################################
+
+sub dtr_im_terminate($) {
+  my $im= shift;
+
+  # Load pids from pid-files. We should do it first of all, because IM deletes
+  # them on shutdown.
+
+  dtr_im_load_pids($im);
+
+  dtr_debug("Shutting Instance Manager down...");
+
+  # Ignoring SIGCHLD so that all children could rest in peace.
+
+  start_reap_all();
+
+  # Send SIGTERM to IM-main.
+
+  if ( defined $im->{'pid'} )
+  {
+    dtr_debug("IM-main pid: $im->{pid}.");
+    dtr_debug("Stopping IM-main...");
+
+    dtr_im_kill_process([ $im->{'pid'} ], 'TERM', 10, 1);
+  }
+  else
+  {
+    dtr_debug("IM-main pid: n/a.");
+  }
+
+  # If IM-angel was alive, wait for it to die.
+
+  if ( defined $im->{'angel_pid'} )
+  {
+    dtr_debug("IM-angel pid: $im->{'angel_pid'}.");
+    dtr_debug("Waiting for IM-angel to die...");
+
+    my $total_attempts= 10;
+
+    for ( my $cur_attempt=1; $cur_attempt <= $total_attempts; ++$cur_attempt )
+    {
+      unless ( kill (0, $im->{'angel_pid'}) )
+      {
+        dtr_debug("IM-angel died.");
+        last;
+      }
+
+      sleep(1);
+    }
+  }
+  else
+  {
+    dtr_debug("IM-angel pid: n/a.");
+  }
+
+  stop_reap_all();
+
+  # Re-load PIDs.
+
+  dtr_im_load_pids($im);
+}
+
+###########################################################################
+
+sub dtr_im_check_alive($) {
+  my $im= shift;
+
+  dtr_debug("Checking whether IM-components are alive...");
+
+  return 1 if dtr_im_check_main_alive($im);
+
+  return 1 if dtr_im_check_angel_alive($im);
+
+  return 1 if dtr_im_check_drizzleds_alive($im);
+
+  return 0;
+}
+
+###########################################################################
+
+sub dtr_im_check_main_alive($) {
+  my $im= shift;
+
+  # Check that the process, that we know to be IM's, is dead.
+
+  if ( defined $im->{'pid'} )
+  {
+    if ( kill (0, $im->{'pid'}) )
+    {
+      dtr_debug("IM-main (PID: $im->{pid}) is alive.");
+      return 1;
+    }
+    else
+    {
+      dtr_debug("IM-main (PID: $im->{pid}) is dead.");
+    }
+  }
+  else
+  {
+    dtr_debug("No PID file for IM-main.");
+  }
+
+  # Check that IM does not accept client connections.
+
+  if ( dtr_ping_port($im->{'port'}) )
+  {
+    dtr_debug("IM-main (port: $im->{port}) " .
+              "is accepting connections.");
+
+    dtr_im_errlog("IM-main is accepting connections on port " .
+                  "$im->{port}, but there is no " .
+                  "process information.");
+    return 1;
+  }
+  else
+  {
+    dtr_debug("IM-main (port: $im->{port}) " .
+              "does not accept connections.");
+    return 0;
+  }
+}
+
+###########################################################################
+
+sub dtr_im_check_angel_alive($) {
+  my $im= shift;
+
+  # Check that the process, that we know to be the Angel, is dead.
+
+  if ( defined $im->{'angel_pid'} )
+  {
+    if ( kill (0, $im->{'angel_pid'}) )
+    {
+      dtr_debug("IM-angel (PID: $im->{angel_pid}) is alive.");
+      return 1;
+    }
+    else
+    {
+      dtr_debug("IM-angel (PID: $im->{angel_pid}) is dead.");
+      return 0;
+    }
+  }
+  else
+  {
+    dtr_debug("No PID file for IM-angel.");
+    return 0;
+  }
+}
+
+###########################################################################
+
+sub dtr_im_check_drizzleds_alive($) {
+  my $im= shift;
+
+  dtr_debug("Checking for IM-guarded drizzled instances...");
+
+  my $instances = $im->{'instances'};
+
+  for ( my $idx= 0; $idx < 2; ++$idx )
+  {
+    dtr_debug("Checking drizzled[$idx]...");
+
+    return 1
+      if dtr_im_check_drizzled_alive($instances->[$idx]);
+  }
+}
+
+###########################################################################
+
+sub dtr_im_check_drizzled_alive($) {
+  my $drizzled_instance= shift;
+
+  # Check that the process is dead.
+
+  if ( defined $drizzled_instance->{'pid'} )
+  {
+    if ( kill (0, $drizzled_instance->{'pid'}) )
+    {
+      dtr_debug("drizzled instance (PID: $drizzled_instance->{pid}) is alive.");
+      return 1;
+    }
+    else
+    {
+      dtr_debug("drizzled instance (PID: $drizzled_instance->{pid}) is dead.");
+    }
+  }
+  else
+  {
+    dtr_debug("No PID file for drizzled instance.");
+  }
+
+  # Check that drizzled does not accept client connections.
+
+  if ( dtr_ping_port($drizzled_instance->{'port'}) )
+  {
+    dtr_debug("drizzled instance (port: $drizzled_instance->{port}) " .
+              "is accepting connections.");
+
+    dtr_im_errlog("drizzled is accepting connections on port " .
+                  "$drizzled_instance->{port}, but there is no " .
+                  "process information.");
+    return 1;
+  }
+  else
+  {
+    dtr_debug("drizzled instance (port: $drizzled_instance->{port}) " .
+              "does not accept connections.");
+    return 0;
+  }
+}
+
+###########################################################################
+
+sub dtr_im_cleanup($) {
+  my $im= shift;
+
+  dtr_im_rm_file($im->{'path_pid'});
+  dtr_im_rm_file($im->{'path_sock'});
+
+  dtr_im_rm_file($im->{'path_angel_pid'});
+
+  for ( my $idx= 0; $idx < 2; ++$idx )
+  {
+    dtr_im_rm_file($im->{'instances'}->[$idx]->{'path_pid'});
+    dtr_im_rm_file($im->{'instances'}->[$idx]->{'path_sock'});
+  }
+}
+
+###########################################################################
+
+sub dtr_im_rm_file($)
+{
+  my $file_path= shift;
+
+  if ( -f $file_path )
+  {
+    dtr_debug("Removing '$file_path'...");
+
+    unless ( unlink($file_path) )
+    {
+      dtr_warning("Can not remove '$file_path'.")
+    }
+  }
+  else
+  {
+    dtr_debug("File '$file_path' does not exist already.");
+  }
+}
+
+###########################################################################
+
+sub dtr_im_errlog($) {
+  my $msg= shift;
+
+  # Complain in error log so that a warning will be shown.
+  # 
+  # TODO: unless BUG#20761 is fixed, we will print the warning to stdout, so
+  # that it can be seen on console and does not produce pushbuild error.
+
+  # my $errlog= "$opt_vardir/log/drizzle-test-run.pl.err";
+  # 
+  # open (ERRLOG, ">>$errlog") ||
+  #   dtr_error("Can not open error log ($errlog)");
+  # 
+  # my $ts= localtime();
+  # print ERRLOG
+  #   "Warning: [$ts] $msg\n";
+  # 
+  # close ERRLOG;
+
+  my $ts= localtime();
+  print "Warning: [$ts] $msg\n";
+}
+
+###########################################################################
+
+sub dtr_im_kill($) {
+  my $im= shift;
+
+  # Re-load PIDs. That can be useful because some processes could have been
+  # restarted.
+
+  dtr_im_load_pids($im);
+
+  # Ignoring SIGCHLD so that all children could rest in peace.
+
+  start_reap_all();
+
+  # Kill IM-angel first of all.
+
+  if ( defined $im->{'angel_pid'} )
+  {
+    dtr_debug("Killing IM-angel (PID: $im->{angel_pid})...");
+    dtr_im_kill_process([ $im->{'angel_pid'} ], 'KILL', 10, 1)
+  }
+  else
+  {
+    dtr_debug("IM-angel is dead.");
+  }
+
+  # Re-load PIDs again.
+
+  dtr_im_load_pids($im);
+
+  # Kill IM-main.
+  
+  if ( defined $im->{'pid'} )
+  {
+    dtr_debug("Killing IM-main (PID: $im->pid})...");
+    dtr_im_kill_process([ $im->{'pid'} ], 'KILL', 10, 1);
+  }
+  else
+  {
+    dtr_debug("IM-main is dead.");
+  }
+
+  # Re-load PIDs again.
+
+  dtr_im_load_pids($im);
+
+  # Kill guarded drizzled instances.
+
+  my @drizzled_pids;
+
+  dtr_debug("Collecting PIDs of drizzled instances to kill...");
+
+  for ( my $idx= 0; $idx < 2; ++$idx )
+  {
+    my $pid= $im->{'instances'}->[$idx]->{'pid'};
+
+    unless ( defined $pid )
+    {
+      next;
+    }
+
+    dtr_debug("  - IM-guarded drizzled[$idx] PID: $pid.");
+
+    push (@drizzled_pids, $pid);
+  }
+
+  if ( scalar @drizzled_pids > 0 )
+  {
+    dtr_debug("Killing IM-guarded drizzled instances...");
+    dtr_im_kill_process(\@drizzled_pids, 'KILL', 10, 1);
+  }
+
+  # That's all.
+
+  stop_reap_all();
+}
+
+##############################################################################
+
+sub dtr_im_wait_for_connection($$$) {
+  my $im= shift;
+  my $total_attempts= shift;
+  my $connect_timeout= shift;
+
+  dtr_debug("Waiting for IM on port $im->{port} " .
+            "to start accepting connections...");
+
+  for ( my $cur_attempt= 1; $cur_attempt <= $total_attempts; ++$cur_attempt )
+  {
+    dtr_debug("Trying to connect to IM ($cur_attempt of $total_attempts)...");
+
+    if ( dtr_ping_port($im->{'port'}) )
+    {
+      dtr_debug("IM is accepting connections " .
+                "on port $im->{port}.");
+      return 1;
+    }
+
+    dtr_debug("Sleeping $connect_timeout...");
+    sleep($connect_timeout);
+  }
+
+  dtr_debug("IM does not accept connections " .
+            "on port $im->{port} after " .
+            ($total_attempts * $connect_timeout) . " seconds.");
+
+  return 0;
+}
+
+##############################################################################
+
+sub dtr_im_wait_for_drizzled($$$) {
+  my $drizzled= shift;
+  my $total_attempts= shift;
+  my $connect_timeout= shift;
+
+  dtr_debug("Waiting for IM-guarded drizzled on port $drizzled->{port} " .
+            "to start accepting connections...");
+
+  for ( my $cur_attempt= 1; $cur_attempt <= $total_attempts; ++$cur_attempt )
+  {
+    dtr_debug("Trying to connect to drizzled " .
+              "($cur_attempt of $total_attempts)...");
+
+    if ( dtr_ping_port($drizzled->{'port'}) )
+    {
+      dtr_debug("drizzled is accepting connections " .
+                "on port $drizzled->{port}.");
+      return 1;
+    }
+
+    dtr_debug("Sleeping $connect_timeout...");
+    sleep($connect_timeout);
+  }
+
+  dtr_debug("drizzled does not accept connections " .
+            "on port $drizzled->{port} after " .
+            ($total_attempts * $connect_timeout) . " seconds.");
+
+  return 0;
+}
+
+##############################################################################
+#
+#  Public operations.
+#
+##############################################################################
+
+sub dtr_im_start($$) {
+  my $im = shift;
+  my $opts = shift;
+
+  dtr_debug("Starting Instance Manager...");
+
+  my $args;
+  dtr_init_args(\$args);
+  dtr_add_arg($args, "--defaults-file=%s", $im->{'defaults_file'});
+
+  foreach my $opt ( @{$opts} )
+  {
+    dtr_add_arg($args, $opt);
+  }
+
+  $im->{'spawner_pid'} =
+    dtr_spawn(
+      $::exe_im,                        # path to the executable
+      $args,                            # cmd-line args
+      '',                               # stdin
+      $im->{'path_log'},                # stdout
+      $im->{'path_err'},                # stderr
+      '',                               # pid file path (not used)
+      { append_log_file => 1 }          # append log files
+      );
+
+  unless ( $im->{'spawner_pid'} )
+  {
+    dtr_error('Could not start Instance Manager.')
+  }
+
+  # Instance Manager can be run in daemon mode. In this case, it creates
+  # several processes and the parent process, created by dtr_spawn(), exits just
+  # after start. So, we have to obtain Instance Manager PID from the PID file.
+
+  dtr_debug("Waiting for IM to create PID file (" .
+            "path: '$im->{path_pid}'; " .
+            "timeout: $im->{start_timeout})...");
+
+  unless ( sleep_until_file_created($im->{'path_pid'},
+                                    $im->{'start_timeout'},
+                                    -1) ) # real PID is still unknown
+  {
+    dtr_debug("IM has not created PID file in $im->{start_timeout} secs.");
+    dtr_debug("Aborting test suite...");
+
+    dtr_kill_leftovers();
+
+    dtr_report("IM has not created PID file in $im->{start_timeout} secs.");
+    return 0;
+  }
+
+  $im->{'pid'}= dtr_get_pid_from_file($im->{'path_pid'});
+
+  dtr_debug("Instance Manager started. PID: $im->{pid}.");
+
+  # Wait until we can connect to IM.
+
+  my $IM_CONNECT_TIMEOUT= 30;
+
+  unless ( dtr_im_wait_for_connection($im,
+                                      $IM_CONNECT_TIMEOUT, 1) )
+  {
+    dtr_debug("Can not connect to Instance Manager " .
+              "in $IM_CONNECT_TIMEOUT seconds after start.");
+    dtr_debug("Aborting test suite...");
+
+    dtr_kill_leftovers();
+
+    dtr_report("Can not connect to Instance Manager " .
+               "in $IM_CONNECT_TIMEOUT seconds after start.");
+    return 0;
+  }
+
+  # Wait for IM to start guarded instances:
+  #   - wait for PID files;
+
+  dtr_debug("Waiting for guarded drizzleds instances to create PID files...");
+
+  for ( my $idx= 0; $idx < 2; ++$idx )
+  {
+    my $drizzled= $im->{'instances'}->[$idx];
+
+    if ( exists $drizzled->{'nonguarded'} )
+    {
+      next;
+    }
+
+    dtr_debug("Waiting for drizzled[$idx] to create PID file (" .
+              "path: '$drizzled->{path_pid}'; " .
+              "timeout: $drizzled->{start_timeout})...");
+
+    unless ( sleep_until_file_created($drizzled->{'path_pid'},
+                                      $drizzled->{'start_timeout'},
+                                      -1) ) # real PID is still unknown
+    {
+      dtr_debug("drizzled[$idx] has not created PID file in " .
+                 "$drizzled->{start_timeout} secs.");
+      dtr_debug("Aborting test suite...");
+
+      dtr_kill_leftovers();
+
+      dtr_report("drizzled[$idx] has not created PID file in " .
+                 "$drizzled->{start_timeout} secs.");
+      return 0;
+    }
+
+    dtr_debug("PID file for drizzled[$idx] ($drizzled->{path_pid} created.");
+  }
+
+  # Wait until we can connect to guarded drizzled-instances
+  # (in other words -- wait for IM to start guarded instances).
+
+  dtr_debug("Waiting for guarded drizzleds to start accepting connections...");
+
+  for ( my $idx= 0; $idx < 2; ++$idx )
+  {
+    my $drizzled= $im->{'instances'}->[$idx];
+
+    if ( exists $drizzled->{'nonguarded'} )
+    {
+      next;
+    }
+
+    dtr_debug("Waiting for drizzled[$idx] to accept connection...");
+
+    unless ( dtr_im_wait_for_drizzled($drizzled, 30, 1) )
+    {
+      dtr_debug("Can not connect to drizzled[$idx] " .
+                "in $IM_CONNECT_TIMEOUT seconds after start.");
+      dtr_debug("Aborting test suite...");
+
+      dtr_kill_leftovers();
+
+      dtr_report("Can not connect to drizzled[$idx] " .
+                 "in $IM_CONNECT_TIMEOUT seconds after start.");
+      return 0;
+    }
+
+    dtr_debug("drizzled[$idx] started.");
+  }
+
+  dtr_debug("Instance Manager and its components are up and running.");
+
+  return 1;
+}
+
+##############################################################################
+
+sub dtr_im_stop($) {
+  my $im= shift;
+
+  dtr_debug("Stopping Instance Manager...");
+
+  # Try graceful shutdown.
+
+  dtr_im_terminate($im);
+
+  # Check that all processes died.
+
+  unless ( dtr_im_check_alive($im) )
+  {
+    dtr_debug("Instance Manager has been stopped successfully.");
+    dtr_im_cleanup($im);
+    return 1;
+  }
+
+  # Instance Manager don't want to die. We should kill it.
+
+  dtr_im_errlog("Instance Manager did not shutdown gracefully.");
+
+  dtr_im_kill($im);
+
+  # Check again that all IM-related processes have been killed.
+
+  my $im_is_alive= dtr_im_check_alive($im);
+
+  dtr_im_cleanup($im);
+
+  if ( $im_is_alive )
+  {
+    dtr_debug("Can not kill Instance Manager or its children.");
+    return 0;
+  }
+
+  dtr_debug("Instance Manager has been killed successfully.");
+  return 1;
+}
+
+###########################################################################
+
+1;

=== added file 'tests/lib/dtr_io.pl'
--- tests/lib/dtr_io.pl	1970-01-01 00:00:00 +0000
+++ tests/lib/dtr_io.pl	2010-10-07 19:35:15 +0000
@@ -0,0 +1,218 @@
+# -*- cperl -*-
+# Copyright (C) 2004-2006 MySQL AB
+# 
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; version 2 of the License.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+# This is a library file used by the Perl version of drizzle-test-run,
+# and is part of the translation of the Bourne shell script with the
+# same name.
+
+use strict;
+
+sub dtr_get_pid_from_file ($);
+sub dtr_get_opts_from_file ($);
+sub dtr_fromfile ($);
+sub dtr_tofile ($@);
+sub dtr_tonewfile($@);
+sub dtr_lastlinefromfile($);
+sub dtr_appendfile_to_file ($$);
+sub dtr_grab_file($);
+
+
+##############################################################################
+#
+#  
+#
+##############################################################################
+
+sub dtr_get_pid_from_file ($) {
+  my $pid_file_path=  shift;
+  my $TOTAL_ATTEMPTS= 30;
+  my $timeout= 1;
+
+  # We should read from the file until we get correct pid. As it is
+  # stated in BUG#21884, pid file can be empty at some moment. So, we should
+  # read it until we get valid data.
+
+  for (my $cur_attempt= 1; $cur_attempt <= $TOTAL_ATTEMPTS; ++$cur_attempt)
+  {
+    dtr_debug("Reading pid file '$pid_file_path' " .
+              "($cur_attempt of $TOTAL_ATTEMPTS)...");
+
+    open(FILE, '<', $pid_file_path)
+      or dtr_error("can't open file \"$pid_file_path\": $!");
+
+    # Read pid number from file
+    my $pid= <FILE>;
+    chomp $pid;
+    close FILE;
+
+    return $pid if $pid=~ /^(\d+)/;
+
+    dtr_debug("Pid file '$pid_file_path' does not yet contain pid number.\n" .
+              "Sleeping $timeout second(s) more...");
+
+    sleep($timeout);
+  }
+
+  dtr_error("Pid file '$pid_file_path' is corrupted. " .
+            "Can not retrieve PID in " .
+            ($timeout * $TOTAL_ATTEMPTS) . " seconds.");
+}
+
+sub dtr_get_opts_from_file ($) {
+  my $file=  shift;
+
+  open(FILE,"<",$file) or dtr_error("can't open file \"$file\": $!");
+  my @args;
+  while ( <FILE> )
+  {
+    chomp;
+
+    #    --set-variable=init_connect=set @a='a\\0c'
+    s/^\s+//;                           # Remove leading space
+    s/\s+$//;                           # Remove ending space
+
+    # This is strange, but we need to fill whitespace inside
+    # quotes with something, to remove later. We do this to
+    # be able to split on space. Else, we have trouble with
+    # options like 
+    #
+    #   --someopt="--insideopt1 --insideopt2"
+    #
+    # But still with this, we are not 100% sure it is right,
+    # we need a shell to do it right.
+
+#    print STDERR "\n";
+#    print STDERR "AAA: $_\n";
+
+    s/\'([^\'\"]*)\'/unspace($1,"\x0a")/ge;
+    s/\"([^\'\"]*)\"/unspace($1,"\x0b")/ge;
+    s/\'([^\'\"]*)\'/unspace($1,"\x0a")/ge;
+    s/\"([^\'\"]*)\"/unspace($1,"\x0b")/ge;
+
+#    print STDERR "BBB: $_\n";
+
+#    foreach my $arg (/(--?\w.*?)(?=\s+--?\w|$)/)
+
+    # FIXME ENV vars should be expanded!!!!
+
+    foreach my $arg (split(/[ \t]+/))
+    {
+      $arg =~ tr/\x11\x0a\x0b/ \'\"/;     # Put back real chars
+      # The outermost quotes has to go
+      $arg =~ s/^([^\'\"]*)\'(.*)\'([^\'\"]*)$/$1$2$3/
+        or $arg =~ s/^([^\'\"]*)\"(.*)\"([^\'\"]*)$/$1$2$3/;
+      $arg =~ s/\\\\/\\/g;
+
+      $arg =~ s/\$\{(\w+)\}/envsubst($1)/ge;
+      $arg =~ s/\$(\w+)/envsubst($1)/ge;
+
+#      print STDERR "ARG: $arg\n";
+      # Do not pass empty string since my_getopt is not capable to handle it.
+      if (length($arg))
+      {
+        push(@args, $arg)
+      }
+    }
+  }
+  close FILE;
+  return \@args;
+}
+
+sub envsubst {
+  my $string= shift;
+
+  if ( ! defined $ENV{$string} )
+  {
+    dtr_error("opt file referense \$$string that is unknown");
+  }
+
+  return $ENV{$string};
+}
+
+sub unspace {
+  my $string= shift;
+  my $quote=  shift;
+  $string =~ s/[ \t]/\x11/g;
+  return "$quote$string$quote";
+}
+
+# Read a whole file, stripping leading and trailing whitespace.
+sub dtr_fromfile ($) {
+  my $file=  shift;
+
+  open(FILE,"<",$file) or dtr_error("can't open file \"$file\": $!");
+  my $text= join('', <FILE>);
+  close FILE;
+  $text =~ s/^\s+//;                    # Remove starting space, incl newlines
+  $text =~ s/\s+$//;                    # Remove ending space, incl newlines
+  return $text;
+}
+
+sub dtr_lastlinefromfile ($) {
+  my $file=  shift;
+  my $text;
+
+  open(FILE,"<",$file) or dtr_error("can't open file \"$file\": $!");
+  while (my $line= <FILE>)
+  {
+    $text= $line;
+  }
+  close FILE;
+  return $text;
+}
+
+
+sub dtr_tofile ($@) {
+  my $file=  shift;
+
+  open(FILE,">>",$file) or dtr_error("can't open file \"$file\": $!");
+  print FILE join("", @_);
+  close FILE;
+}
+
+sub dtr_tonewfile ($@) {
+  my $file=  shift;
+
+  open(FILE,">",$file) or dtr_error("can't open file \"$file\": $!");
+  print FILE join("", @_);
+  close FILE;
+}
+
+sub dtr_appendfile_to_file ($$) {
+  my $from_file=  shift;
+  my $to_file=  shift;
+
+  open(TOFILE,">>",$to_file) or dtr_error("can't open file \"$to_file\": $!");
+  open(FROMFILE,"<",$from_file)
+    or dtr_error("can't open file \"$from_file\": $!");
+  print TOFILE while (<FROMFILE>);
+  close FROMFILE;
+  close TOFILE;
+}
+
+# Read a whole file verbatim.
+sub dtr_grab_file($) {
+  my $file= shift;
+  open(FILE, '<', $file)
+    or return undef;
+  local $/= undef;
+  my $data= scalar(<FILE>);
+  close FILE;
+  return $data;
+}
+
+
+1;

=== added file 'tests/lib/dtr_match.pl'
--- tests/lib/dtr_match.pl	1970-01-01 00:00:00 +0000
+++ tests/lib/dtr_match.pl	2010-10-07 19:35:15 +0000
@@ -0,0 +1,98 @@
+# -*- cperl -*-
+# Copyright (C) 2004-2006 MySQL AB
+# 
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; version 2 of the License.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+# This is a library file used by the Perl version of drizzle-test-run,
+# and is part of the translation of the Bourne shell script with the
+# same name.
+
+use strict;
+
+sub dtr_match_prefix ($$);
+sub dtr_match_extension ($$);
+sub dtr_match_any_exact ($$);
+
+##############################################################################
+#
+#  
+#
+##############################################################################
+
+# Match a prefix and return what is after the prefix
+
+sub dtr_match_prefix ($$) {
+  my $string= shift;
+  my $prefix= shift;
+
+  if ( $string =~ /^\Q$prefix\E(.*)$/ ) # strncmp
+  {
+    return $1;
+  }
+  else
+  {
+    return undef;		# NULL
+  }
+}
+
+
+# Match extension and return the name without extension
+
+sub dtr_match_extension ($$) {
+  my $file= shift;
+  my $ext=  shift;
+
+  if ( $file =~ /^(.*)\.\Q$ext\E$/ ) # strchr+strcmp or something
+  {
+    return $1;
+  }
+  else
+  {
+    return undef;                       # NULL
+  }
+}
+
+
+# Match a substring anywere in a string
+
+sub dtr_match_substring ($$) {
+  my $string= shift;
+  my $substring= shift;
+
+  if ( $string =~ /(.*)\Q$substring\E(.*)$/ ) # strncmp
+  {
+    return $1;
+  }
+  else
+  {
+    return undef;		# NULL
+  }
+}
+
+
+sub dtr_match_any_exact ($$) {
+  my $string= shift;
+  my $mlist=  shift;
+
+  foreach my $m (@$mlist)
+  {
+    if ( $string eq $m )
+    {
+      return 1;
+    }
+  }
+  return 0;
+}
+
+1;

=== added file 'tests/lib/dtr_misc.pl'
--- tests/lib/dtr_misc.pl	1970-01-01 00:00:00 +0000
+++ tests/lib/dtr_misc.pl	2010-10-07 19:35:15 +0000
@@ -0,0 +1,312 @@
+# -*- cperl -*-
+# Copyright (C) 2004-2006 MySQL AB
+# 
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; version 2 of the License.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+# This is a library file used by the Perl version of drizzle-test-run,
+# and is part of the translation of the Bourne shell script with the
+# same name.
+
+use strict;
+use File::Find;
+
+sub dtr_native_path($);
+sub dtr_init_args ($);
+sub dtr_add_arg ($$@);
+sub dtr_path_exists(@);
+sub dtr_script_exists(@);
+sub dtr_file_exists(@);
+sub dtr_exe_exists(@);
+sub dtr_exe_maybe_exists(@);
+sub dtr_copy_dir($$);
+sub dtr_rdtree($);
+sub dtr_same_opts($$);
+sub dtr_cmp_opts($$);
+
+##############################################################################
+#
+#  Misc
+#
+##############################################################################
+
+# Convert path to OS native format
+sub dtr_native_path($)
+{
+  my $path= shift;
+
+  # drizzle version before 5.0 still use cygwin, no need
+  # to convert path
+  return $path
+    if ($::drizzle_version_id < 50000);
+
+  $path=~ s/\//\\/g
+    if ($::glob_win32);
+  return $path;
+}
+
+
+# FIXME move to own lib
+
+sub dtr_init_args ($) {
+  my $args = shift;
+  $$args = [];                            # Empty list
+}
+
+sub dtr_add_arg ($$@) {
+  my $args=   shift;
+  my $format= shift;
+  my @fargs = @_;
+
+  push(@$args, sprintf($format, @fargs));
+}
+
+##############################################################################
+
+#
+# NOTE! More specific paths should be given before less specific.
+# For example /client/debug should be listed before /client
+#
+sub dtr_path_exists (@) {
+  foreach my $path ( @_ )
+  {
+    return $path if -e $path;
+  }
+  if ( @_ == 1 )
+  {
+    dtr_error("Could not find $_[0]");
+  }
+  else
+  {
+    dtr_error("Could not find any of " . join(" ", @_));
+  }
+}
+
+
+#
+# NOTE! More specific paths should be given before less specific.
+# For example /client/debug should be listed before /client
+#
+sub dtr_script_exists (@) {
+  foreach my $path ( @_ )
+  {
+    if($::glob_win32)
+    {
+      return $path if -f $path;
+    }
+    else
+    {
+      return $path if -x $path;
+    }
+  }
+  if ( @_ == 1 )
+  {
+    dtr_error("Could not find $_[0]");
+  }
+  else
+  {
+    dtr_error("Could not find any of " . join(" ", @_));
+  }
+}
+
+
+#
+# NOTE! More specific paths should be given before less specific.
+# For example /client/debug should be listed before /client
+#
+sub dtr_file_exists (@) {
+  foreach my $path ( @_ )
+  {
+    return $path if -e $path;
+  }
+  return "";
+}
+
+
+#
+# NOTE! More specific paths should be given before less specific.
+# For example /client/debug should be listed before /client
+#
+sub dtr_exe_maybe_exists (@) {
+  my @path= @_;
+
+  map {$_.= ".exe"} @path if $::glob_win32;
+  map {$_.= ".nlm"} @path if $::glob_netware;
+  foreach my $path ( @path )
+  {
+    if($::glob_win32)
+    {
+      return $path if -f $path;
+    }
+    else
+    {
+      return $path if -x $path;
+    }
+  }
+  return "";
+}
+
+
+#
+# NOTE! More specific paths should be given before less specific.
+# For example /client/debug should be listed before /client
+#
+sub dtr_exe_exists (@) {
+  my @path= @_;
+  if (my $path= dtr_exe_maybe_exists(@path))
+  {
+    return $path;
+  }
+  # Could not find exe, show error
+  if ( @path == 1 )
+  {
+    dtr_error("Could not find $path[0]");
+  }
+  else
+  {
+    dtr_error("Could not find any of " . join(" ", @path));
+  }
+}
+
+
+sub dtr_copy_dir($$) {
+  my $from_dir= shift;
+  my $to_dir= shift;
+
+  # dtr_verbose("Copying from $from_dir to $to_dir");
+
+  mkpath("$to_dir");
+  opendir(DIR, "$from_dir")
+    or dtr_error("Can't find $from_dir$!");
+  for(readdir(DIR)) {
+    next if "$_" eq "." or "$_" eq "..";
+    if ( -d "$from_dir/$_" )
+    {
+      dtr_copy_dir("$from_dir/$_", "$to_dir/$_");
+      next;
+    }
+    copy("$from_dir/$_", "$to_dir/$_");
+  }
+  closedir(DIR);
+
+}
+
+
+sub dtr_rmtree($) {
+  my ($dir)= @_;
+  dtr_verbose("dtr_rdtree: $dir");
+
+  # Try to use File::Path::rmtree. Recent versions
+  # handles removal of directories and files that don't
+  # have full permissions, while older versions
+  # may have a problem with that and we use our own version
+
+  eval { rmtree($dir); };
+  if ( $@ ) {
+    dtr_warning("rmtree($dir) failed, trying with File::Find...");
+
+    my $errors= 0;
+
+    # chmod
+    find( {
+	   no_chdir => 1,
+	   wanted => sub {
+	     chmod(0777, $_)
+	       or dtr_warning("couldn't chmod(0777, $_): $!") and $errors++;
+	   }
+	  },
+	  $dir
+	);
+
+    # rm
+    finddepth( {
+	   no_chdir => 1,
+	   wanted => sub {
+	     my $file= $_;
+	     # Use special underscore (_) filehandle, caches stat info
+	     if (!-l $file and -d _ ) {
+	       rmdir($file) or
+		 dtr_warning("couldn't rmdir($file): $!") and $errors++;
+	     } else {
+	       unlink($file)
+		 or dtr_warning("couldn't unlink($file): $!") and $errors++;
+	     }
+	   }
+	  },
+	  $dir
+	);
+
+    dtr_error("Failed to remove '$dir'") if $errors;
+
+    dtr_report("OK, that worked!");
+  }
+}
+
+
+sub dtr_same_opts ($$) {
+  my $l1= shift;
+  my $l2= shift;
+  return dtr_cmp_opts($l1,$l2) == 0;
+}
+
+sub dtr_cmp_opts ($$) {
+  my $l1= shift;
+  my $l2= shift;
+
+  my @l1= @$l1;
+  my @l2= @$l2;
+
+  return -1 if @l1 < @l2;
+  return  1 if @l1 > @l2;
+
+  while ( @l1 )                         # Same length
+  {
+    my $e1= shift @l1;
+    my $e2= shift @l2;
+    my $cmp= ($e1 cmp $e2);
+    return $cmp if $cmp != 0;
+  }
+
+  return 0;                             # They are the same
+}
+
+#
+# Compare two arrays and put all unequal elements into a new one
+#
+sub dtr_diff_opts ($$) {
+  my $l1= shift;
+  my $l2= shift;
+  my $f;
+  my $l= [];
+  foreach my $e1 (@$l1) 
+  {    
+    $f= undef;
+    foreach my $e2 (@$l2) 
+    {
+      $f= 1 unless ($e1 ne $e2);
+    }
+    push(@$l, $e1) unless (defined $f);
+  }
+  foreach my $e2 (@$l2) 
+  {
+    $f= undef;
+    foreach my $e1 (@$l1) 
+    {
+      $f= 1 unless ($e1 ne $e2);
+    }
+    push(@$l, $e2) unless (defined $f);
+  }
+  return $l;
+}
+
+1;

=== added file 'tests/lib/dtr_process.pl'
--- tests/lib/dtr_process.pl	1970-01-01 00:00:00 +0000
+++ tests/lib/dtr_process.pl	2010-10-07 19:35:15 +0000
@@ -0,0 +1,1091 @@
+# -*- cperl -*-
+# Copyright (C) 2004-2006 MySQL AB
+# 
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; version 2 of the License.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+# This is a library file used by the Perl version of drizzle-test-run,
+# and is part of the translation of the Bourne shell script with the
+# same name.
+
+use Socket;
+use Errno;
+use strict;
+
+use POSIX qw(WNOHANG SIGHUP);
+
+sub dtr_run ($$$$$$;$);
+sub dtr_spawn ($$$$$$;$);
+sub dtr_check_stop_servers ($);
+sub dtr_kill_leftovers ();
+sub dtr_wait_blocking ($);
+sub dtr_record_dead_children ();
+sub dtr_ndbmgm_start($$);
+sub dtr_exit ($);
+sub sleep_until_file_created ($$$);
+sub dtr_kill_processes ($);
+sub dtr_ping_with_timeout($);
+sub dtr_ping_port ($);
+
+# Local function
+sub spawn_impl ($$$$$$$);
+
+##############################################################################
+#
+#  Execute an external command
+#
+##############################################################################
+
+sub dtr_run ($$$$$$;$) {
+  my $path=       shift;
+  my $arg_list_t= shift;
+  my $input=      shift;
+  my $output=     shift;
+  my $error=      shift;
+  my $pid_file=   shift; # Not used
+  my $spawn_opts= shift;
+
+  return spawn_impl($path,$arg_list_t,'run',$input,$output,$error,
+    $spawn_opts);
+}
+
+sub dtr_run_test ($$$$$$;$) {
+  my $path=       shift;
+  my $arg_list_t= shift;
+  my $input=      shift;
+  my $output=     shift;
+  my $error=      shift;
+  my $pid_file=   shift; # Not used
+  my $spawn_opts= shift;
+
+  return spawn_impl($path,$arg_list_t,'test',$input,$output,$error,
+    $spawn_opts);
+}
+
+sub dtr_spawn ($$$$$$;$) {
+  my $path=       shift;
+  my $arg_list_t= shift;
+  my $input=      shift;
+  my $output=     shift;
+  my $error=      shift;
+  my $pid_file=   shift; # Not used
+  my $spawn_opts= shift;
+
+  return spawn_impl($path,$arg_list_t,'spawn',$input,$output,$error,
+    $spawn_opts);
+}
+
+
+
+sub spawn_impl ($$$$$$$) {
+  my $path=       shift;
+  my $arg_list_t= shift;
+  my $mode=       shift;
+  my $input=      shift;
+  my $output=     shift;
+  my $error=      shift;
+  my $spawn_opts= shift;
+
+  if ( $::opt_script_debug )
+  {
+    dtr_report("");
+    dtr_debug("-" x 73);
+    dtr_debug("STDIN  $input") if $input;
+    dtr_debug("STDOUT $output") if $output;
+    dtr_debug("STDERR $error") if $error;
+    dtr_debug("$mode: $path ", join(" ",@$arg_list_t));
+    dtr_debug("spawn options:");
+    if ($spawn_opts)
+    {
+      foreach my $key (sort keys %{$spawn_opts})
+      {
+        dtr_debug("  - $key: $spawn_opts->{$key}");
+      }
+    }
+    else
+    {
+      dtr_debug("  none");
+    }
+    dtr_debug("-" x 73);
+    dtr_report("");
+  }
+
+  dtr_error("Can't spawn with empty \"path\"") unless defined $path;
+
+
+ FORK:
+  {
+    my $pid= fork();
+
+    if ( ! defined $pid )
+    {
+      if ( $! == $!{EAGAIN} )           # See "perldoc Errno"
+      {
+        dtr_warning("Got EAGAIN from fork(), sleep 1 second and redo");
+        sleep(1);
+        redo FORK;
+      }
+
+      dtr_error("$path ($pid) can't be forked, error: $!");
+
+    }
+
+    if ( $pid )
+    {
+      select(STDOUT) if $::glob_win32_perl;
+      return spawn_parent_impl($pid,$mode,$path);
+    }
+    else
+    {
+      # Child, redirect output and exec
+
+      $SIG{INT}= 'DEFAULT';         # Parent do some stuff, we don't
+
+      my $log_file_open_mode = '>';
+
+      if ($spawn_opts and $spawn_opts->{'append_log_file'})
+      {
+        $log_file_open_mode = '>>';
+      }
+
+      if ( $output )
+      {
+	if ( $::glob_win32_perl )
+	{
+	  # Don't redirect stdout on ActiveState perl since this is
+          # just another thread in the same process.
+	}
+        elsif ( ! open(STDOUT,$log_file_open_mode,$output) )
+        {
+          dtr_child_error("can't redirect STDOUT to \"$output\": $!");
+        }
+      }
+
+      if ( $error )
+      {
+        if ( !$::glob_win32_perl and $output eq $error )
+        {
+          if ( ! open(STDERR,">&STDOUT") )
+          {
+            dtr_child_error("can't dup STDOUT: $!");
+          }
+        }
+        else
+        {
+          if ( ! open(STDERR,$log_file_open_mode,$error) )
+          {
+            dtr_child_error("can't redirect STDERR to \"$error\": $!");
+          }
+        }
+      }
+
+      if ( $input )
+      {
+        if ( ! open(STDIN,"<",$input) )
+        {
+          dtr_child_error("can't redirect STDIN to \"$input\": $!");
+        }
+      }
+
+      if ( ! exec($path,@$arg_list_t) )
+      {
+        dtr_child_error("failed to execute \"$path\": $!");
+      }
+      dtr_error("Should never come here 1!");
+    }
+    dtr_error("Should never come here 2!");
+  }
+  dtr_error("Should never come here 3!");
+}
+
+
+sub spawn_parent_impl {
+  my $pid=  shift;
+  my $mode= shift;
+  my $path= shift;
+
+  if ( $mode eq 'run' or $mode eq 'test' )
+  {
+    if ( $mode eq 'run' )
+    {
+      # Simple run of command, wait blocking for it to return
+      my $ret_pid= waitpid($pid,0);
+      if ( $ret_pid != $pid )
+      {
+	# The "simple" waitpid has failed, print debug info
+	# and try to handle the error
+        dtr_warning("waitpid($pid, 0) returned $ret_pid " .
+		    "when waiting for '$path', error: '$!'");
+	if ( $ret_pid == -1 )
+	{
+	  # waitpid returned -1, that would indicate the process
+	  # no longer exist and waitpid couldn't wait for it.
+	  return 1;
+	}
+	dtr_error("Error handling failed");
+      }
+
+      return dtr_process_exit_status($?);
+    }
+    else
+    {
+      # We run drizzletest and wait for it to return. But we try to
+      # catch dying drizzled processes as well.
+      #
+      # We do blocking waitpid() until we get the return from the
+      # "drizzletest" call. But if a drizzled process dies that we
+      # started, we take this as an error, and kill drizzletest.
+
+
+      my $exit_value= -1;
+      my $saved_exit_value;
+      my $ret_pid;                      # What waitpid() returns
+
+      while ( ($ret_pid= waitpid(-1,0)) != -1 )
+      {
+        # Someone terminated, don't know who. Collect
+        # status info first before $? is lost,
+        # but not $exit_value, this is flagged from
+
+        my $timer_name= dtr_timer_timeout($::glob_timers, $ret_pid);
+        if ( $timer_name )
+        {
+          if ( $timer_name eq "suite" )
+          {
+            # We give up here
+            # FIXME we should only give up the suite, not all of the run?
+            print STDERR "\n";
+            dtr_error("Test suite timeout");
+          }
+          elsif ( $timer_name eq "testcase" )
+          {
+            $saved_exit_value=  63;       # Mark as timeout
+            kill(9, $pid);                # Kill drizzletest
+            next;                         # Go on and catch the termination
+          }
+        }
+
+        if ( $ret_pid == $pid )
+        {
+          # We got termination of drizzletest, we are done
+          $exit_value= dtr_process_exit_status($?);
+          last;
+        }
+
+        # One of the child processes died, unless this was expected
+	# drizzletest should be killed and test aborted
+
+	check_expected_crash_and_restart($ret_pid);
+      }
+
+      if ( $ret_pid != $pid )
+      {
+        # We terminated the waiting because a "drizzled" process died.
+        # Kill the drizzletest process.
+	dtr_verbose("Kill drizzletest because another process died");
+        kill(9,$pid);
+
+        $ret_pid= waitpid($pid,0);
+
+        if ( $ret_pid != $pid )
+        {
+          dtr_error("$path ($pid) got lost somehow");
+        }
+      }
+
+      return $saved_exit_value || $exit_value;
+    }
+  }
+  else
+  {
+    # We spawned a process we don't wait for
+    return $pid;
+  }
+}
+
+
+# ----------------------------------------------------------------------
+# We try to emulate how an Unix shell calculates the exit code
+# ----------------------------------------------------------------------
+
+sub dtr_process_exit_status {
+  my $raw_status= shift;
+
+  if ( $raw_status & 127 )
+  {
+    return ($raw_status & 127) + 128;  # Signal num + 128
+  }
+  else
+  {
+    return $raw_status >> 8;           # Exit code
+  }
+}
+
+
+##############################################################################
+#
+#  Kill processes left from previous runs
+#
+##############################################################################
+
+
+# Kill all processes(drizzled, ndbd, ndb_mgmd and im) that would conflict with
+# this run
+# Make sure to remove the PID file, if any.
+# kill IM manager first, else it will restart the servers
+sub dtr_kill_leftovers () {
+
+  dtr_report("Killing Possible Leftover Processes");
+  dtr_debug("dtr_kill_leftovers(): started.");
+
+  my @kill_pids;
+  my %admin_pids;
+
+  foreach my $srv (@{$::master}, @{$::slave})
+  {
+    dtr_debug("  - drizzled " .
+              "(pid: $srv->{pid}; " .
+              "pid file: '$srv->{path_pid}'; " .
+              "socket: '$srv->{path_sock}'; ".
+              "port: $srv->{port})");
+
+    my $pid= dtr_server_shutdown($srv);
+
+    # Save the pid of the drizzle client process
+    $admin_pids{$pid}= 1;
+
+    push(@kill_pids,{
+		     pid      => $srv->{'pid'},
+		     pidfile  => $srv->{'path_pid'},
+		     sockfile => $srv->{'path_sock'},
+		     port     => $srv->{'port'},
+		    });
+    $srv->{'pid'}= 0; # Assume we are done with it
+  }
+
+  # Wait for all the admin processes to complete
+  dtr_wait_blocking(\%admin_pids);
+
+  # If we trusted "drizzleadmin --shutdown_timeout= ..." we could just
+  # terminate now, but we don't (FIXME should be debugged).
+  # So we try again to ping and at least wait the same amount of time
+  # drizzleadmin would for all to die.
+
+  dtr_ping_with_timeout(\@kill_pids);
+
+  # We now have tried to terminate nice. We have waited for the listen
+  # port to be free, but can't really tell if the drizzled process died
+  # or not. We now try to find the process PID from the PID file, and
+  # send a kill to that process. Note that Perl let kill(0,@pids) be
+  # a way to just return the numer of processes the kernel can send
+  # signals to. So this can be used (except on Cygwin) to determine
+  # if there are processes left running that we cound out might exists.
+  #
+  # But still after all this work, all we know is that we have
+  # the ports free.
+
+  # We scan the "var/run/" directory for other process id's to kill
+
+  my $rundir= "$::opt_vardir/run";
+
+  dtr_debug("Processing PID files in directory '$rundir'...");
+
+  if ( -d $rundir )
+  {
+    opendir(RUNDIR, $rundir)
+      or dtr_error("can't open directory \"$rundir\": $!");
+
+    my @pids;
+
+    while ( my $elem= readdir(RUNDIR) )
+    {
+      # Only read pid from files that end with .pid
+      if ( $elem =~ /.*[.]pid$/)
+      {
+	my $pidfile= "$rundir/$elem";
+
+	if ( -f $pidfile )
+	{
+	  dtr_debug("Processing PID file: '$pidfile'...");
+
+	  my $pid= dtr_get_pid_from_file($pidfile);
+
+	  dtr_debug("Got pid: $pid from file '$pidfile'");
+
+	  if ( $::glob_cygwin_perl or kill(0, $pid) )
+	  {
+	    dtr_debug("There is process with pid $pid -- scheduling for kill.");
+	    push(@pids, $pid);            # We know (cygwin guess) it exists
+	  }
+	  else
+	  {
+	    dtr_debug("There is no process with pid $pid -- skipping.");
+	  }
+	}
+      }
+      else
+      {
+	dtr_warning("Found non pid file $elem in $rundir")
+	  if -f "$rundir/$elem";
+	next;
+      }
+    }
+    closedir(RUNDIR);
+
+    if ( @pids )
+    {
+      dtr_debug("Killing the following processes with PID files: " .
+                join(' ', @pids) . "...");
+
+      start_reap_all();
+
+      if ( $::glob_cygwin_perl )
+      {
+        # We have no (easy) way of knowing the Cygwin controlling
+        # process, in the PID file we only have the Windows process id.
+        system("kill -f " . join(" ",@pids)); # Hope for the best....
+        dtr_debug("Sleep 5 seconds waiting for processes to die");
+        sleep(5);
+      }
+      else
+      {
+        my $retries= 10;                    # 10 seconds
+        do
+        {
+          dtr_debug("Sending SIGKILL to pids: " . join(' ', @pids));
+          kill(9, @pids);
+          dtr_report("Sleep 1 second waiting for processes to die");
+          sleep(1)                      # Wait one second
+        } while ( $retries-- and  kill(0, @pids) );
+
+        if ( kill(0, @pids) )           # Check if some left
+        {
+          dtr_warning("can't kill process(es) " . join(" ", @pids));
+        }
+      }
+
+      stop_reap_all();
+    }
+  }
+  else
+  {
+    dtr_debug("Directory for PID files ($rundir) does not exist.");
+  }
+
+  # We may have failed everything, but we now check again if we have
+  # the listen ports free to use, and if they are free, just go for it.
+
+  dtr_debug("Checking known drizzled servers...");
+
+  foreach my $srv ( @kill_pids )
+  {
+    if ( defined $srv->{'port'} and dtr_ping_port($srv->{'port'}) )
+    {
+      dtr_warning("can't kill old process holding port $srv->{'port'}");
+    }
+  }
+
+  dtr_debug("dtr_kill_leftovers(): finished.");
+}
+
+
+#
+# Check that all processes in "spec" are shutdown gracefully
+# else kill them off hard
+#
+sub dtr_check_stop_servers ($) {
+  my $spec=  shift;
+
+  # Return if no processes are defined
+  return if ! @$spec;
+
+  dtr_verbose("dtr_check_stop_servers");
+
+  # ----------------------------------------------------------------------
+  # Wait until servers in "spec" has stopped listening
+  # to their ports or timeout occurs
+  # ----------------------------------------------------------------------
+  dtr_ping_with_timeout(\@$spec);
+
+  # ----------------------------------------------------------------------
+  # Use waitpid() nonblocking for a little while, to see how
+  # many process's will exit sucessfully.
+  # This is the normal case.
+  # ----------------------------------------------------------------------
+  my $wait_counter= 10; # Max number of times to redo the loop
+  foreach my $srv ( @$spec )
+  {
+    my $pid= $srv->{'pid'};
+    my $ret_pid;
+    if ( $pid )
+    {
+      $ret_pid= waitpid($pid,&WNOHANG);
+      if ($ret_pid == $pid)
+      {
+	dtr_verbose("Caught exit of process $ret_pid");
+	$srv->{'pid'}= 0;
+      }
+      elsif ($ret_pid == 0)
+      {
+	dtr_verbose("Process $pid is still alive");
+	if ($wait_counter-- > 0)
+	{
+	  # Give the processes more time to exit
+	  select(undef, undef, undef, (1));
+	  redo;
+	}
+      }
+      else
+      {
+	dtr_warning("caught exit of unknown child $ret_pid");
+      }
+    }
+  }
+
+  # ----------------------------------------------------------------------
+  # The processes that haven't yet exited need to
+  # be killed hard, put them in "kill_pids" hash
+  # ----------------------------------------------------------------------
+  my %kill_pids;
+  foreach my $srv ( @$spec )
+  {
+    my $pid= $srv->{'pid'};
+    if ( $pid )
+    {
+      # Server is still alive, put it in list to be hard killed
+      if ($::glob_win32_perl)
+      {
+	# Kill the real process if it's known
+	$pid= $srv->{'real_pid'} if ($srv->{'real_pid'});
+      }
+      $kill_pids{$pid}= 1;
+
+      # Write a message to the process's error log (if it has one)
+      # that it's being killed hard.
+      if ( defined $srv->{'errfile'} )
+      {
+	dtr_tofile($srv->{'errfile'}, "Note: Forcing kill of process $pid\n");
+      }
+      dtr_warning("Forcing kill of process $pid");
+
+    }
+    else
+    {
+      # Server is dead, remove the pidfile if it exists
+      #
+      # Race, could have been removed between test with -f
+      # and the unlink() below, so better check again with -f
+      if ( -f $srv->{'pidfile'} and ! unlink($srv->{'pidfile'}) and
+           -f $srv->{'pidfile'} )
+      {
+        dtr_error("can't remove $srv->{'pidfile'}");
+      }
+    }
+  }
+
+  if ( ! keys %kill_pids )
+  {
+    # All processes has exited gracefully
+    return;
+  }
+
+  dtr_kill_processes(\%kill_pids);
+
+  # ----------------------------------------------------------------------
+  # All processes are killed, cleanup leftover files
+  # ----------------------------------------------------------------------
+  {
+    my $errors= 0;
+    foreach my $srv ( @$spec )
+    {
+      if ( $srv->{'pid'} )
+      {
+	# Server has been hard killed, clean it's resources
+	foreach my $file ($srv->{'pidfile'}, $srv->{'sockfile'})
+        {
+	  # Know it is dead so should be no race, careful anyway
+	  if ( defined $file and -f $file and ! unlink($file) and -f $file )
+          {
+	    $errors++;
+	    dtr_warning("couldn't delete $file");
+	  }
+	}
+
+	if ($::glob_win32_perl and $srv->{'real_pid'})
+	{
+	  # Wait for the pseudo pid - if the real_pid was known
+	  # the pseudo pid has not been waited for yet, wai blocking
+	  # since it's "such a simple program"
+	  dtr_verbose("Wait for pseudo process $srv->{'pid'}");
+	  my $ret_pid= waitpid($srv->{'pid'}, 0);
+	  dtr_verbose("Pseudo process $ret_pid died");
+	}
+
+	$srv->{'pid'}= 0;
+      }
+    }
+    if ( $errors )
+    {
+      # There where errors killing processes
+      # do one last attempt to ping the servers
+      # and if they can't be pinged, assume they are dead
+      if ( ! dtr_ping_with_timeout( \@$spec ) )
+      {
+	dtr_error("we could not kill or clean up all processes");
+      }
+      else
+      {
+	dtr_verbose("All ports were free, continuing");
+      }
+    }
+  }
+}
+
+
+# Wait for all the process in the list to terminate
+sub dtr_wait_blocking($) {
+  my $admin_pids= shift;
+
+
+  # Return if no processes defined
+  return if ! %$admin_pids;
+
+  dtr_verbose("dtr_wait_blocking");
+
+  # Wait for all the started processes to exit
+  # As drizzleadmin is such a simple program, we trust it to terminate itself.
+  # I.e. we wait blocking, and wait for them all before we go on.
+  foreach my $pid (keys %{$admin_pids})
+  {
+    my $ret_pid= waitpid($pid,0);
+
+  }
+}
+
+sub dtr_server_shutdown($) {
+  my $srv= shift;
+  my $args;
+
+  dtr_init_args(\$args);
+  dtr_add_arg($args, "--shutdown");
+  dtr_add_arg($args, "--user=%s", $::opt_user);
+  dtr_add_arg($args, "--password=");
+  dtr_add_arg($args, "--silent");
+
+  if ( -e $srv->{'path_sock'} )
+  {
+    dtr_add_arg($args, "--socket=%s", $srv->{'path_sock'});
+  }
+
+  if ( $srv->{'port'} )
+  {
+    dtr_add_arg($args, "--port=%s", $srv->{'port'});
+  }
+
+  dtr_add_arg($args, "--connect_timeout=5");
+
+  my $pid= dtr_spawn($::exe_drizzle, $args,
+                     "", "", "", "", { append_log_file => 1 });
+  dtr_verbose("dtr_server_shutdown, pid: $pid");
+  return $pid;
+}
+
+# Start "ndb_mgm shutdown" for a specific cluster, it will
+# shutdown all data nodes and leave the ndb_mgmd running
+sub dtr_ndbmgm_start($$) {
+  my $cluster= shift;
+  my $command= shift;
+
+  my $args;
+
+  dtr_init_args(\$args);
+
+  dtr_add_arg($args, "--no-defaults");
+  dtr_add_arg($args, "--core");
+  dtr_add_arg($args, "--try-reconnect=1");
+  dtr_add_arg($args, "--ndb_connectstring=%s", $cluster->{'connect_string'});
+  dtr_add_arg($args, "-e");
+  dtr_add_arg($args, "$command");
+
+  my $pid= dtr_spawn($::exe_ndb_mgm, $args,
+		     "", "/dev/null", "/dev/null", "",
+		     {});
+  dtr_verbose("dtr_ndbmgm_start, pid: $pid");
+  return $pid;
+
+}
+
+
+# Ping all servers in list, exit when none of them answers
+# or when timeout has passed
+sub dtr_ping_with_timeout($) {
+  my $spec= shift;
+  my $timeout= 200;                     # 20 seconds max
+  my $res= 1;                           # If we just fall through, we are done
+                                        # in the sense that the servers don't
+                                        # listen to their ports any longer
+
+  dtr_debug("Waiting for drizzled servers to stop...");
+
+ TIME:
+  while ( $timeout-- )
+  {
+    foreach my $srv ( @$spec )
+    {
+      $res= 1;                          # We are optimistic
+      if ( $srv->{'pid'} and defined $srv->{'port'} )
+      {
+	if ( dtr_ping_port($srv->{'port'}) )
+	{
+	  dtr_verbose("waiting for process $srv->{'pid'} to stop ".
+		      "using port $srv->{'port'}");
+
+	  # Millisceond sleep emulated with select
+	  select(undef, undef, undef, (0.1));
+	  $res= 0;
+	  next TIME;
+	}
+	else
+	{
+	  # Process was not using port
+	}
+      }
+    }
+    last;                               # If we got here, we are done
+  }
+
+  if ($res)
+  {
+    dtr_debug("dtr_ping_with_timeout(): All drizzled instances are down.");
+  }
+  else
+  {
+    dtr_report("dtr_ping_with_timeout(): At least one server is alive.");
+  }
+
+  return $res;
+}
+
+
+#
+# Loop through our list of processes and look for and entry
+# with the provided pid
+# Set the pid of that process to 0 if found
+#
+sub mark_process_dead($)
+{
+  my $ret_pid= shift;
+
+  foreach my $drizzled (@{$::master}, @{$::slave})
+  {
+    if ( $drizzled->{'pid'} eq $ret_pid )
+    {
+      dtr_verbose("$drizzled->{'type'} $drizzled->{'idx'} exited, pid: $ret_pid");
+      $drizzled->{'pid'}= 0;
+      return;
+    }
+  }
+
+  foreach my $cluster (@{$::clusters})
+  {
+    if ( $cluster->{'pid'} eq $ret_pid )
+    {
+      dtr_verbose("$cluster->{'name'} cluster ndb_mgmd exited, pid: $ret_pid");
+      $cluster->{'pid'}= 0;
+      return;
+    }
+
+    foreach my $ndbd (@{$cluster->{'ndbds'}})
+    {
+      if ( $ndbd->{'pid'} eq $ret_pid )
+      {
+	dtr_verbose("$cluster->{'name'} cluster ndbd exited, pid: $ret_pid");
+	$ndbd->{'pid'}= 0;
+	return;
+      }
+    }
+  }
+  dtr_warning("mark_process_dead couldn't find an entry for pid: $ret_pid");
+
+}
+
+#
+# Loop through our list of processes and look for and entry
+# with the provided pid, if found check for the file indicating
+# expected crash and restart it.
+#
+sub check_expected_crash_and_restart($)
+{
+  my $ret_pid= shift;
+
+  foreach my $drizzled (@{$::master}, @{$::slave})
+  {
+    if ( $drizzled->{'pid'} eq $ret_pid )
+    {
+      dtr_verbose("$drizzled->{'type'} $drizzled->{'idx'} exited, pid: $ret_pid");
+      $drizzled->{'pid'}= 0;
+
+      # Check if crash expected and restart if it was
+      my $expect_file= "$::opt_vardir/tmp/" . "$drizzled->{'type'}" .
+	"$drizzled->{'idx'}" . ".expect";
+      if ( -f $expect_file )
+      {
+	dtr_verbose("Crash was expected, file $expect_file exists");
+	drizzled_start($drizzled, $drizzled->{'start_opts'},
+		     $drizzled->{'start_slave_master_info'});
+	unlink($expect_file);
+      }
+
+      return;
+    }
+  }
+
+  foreach my $cluster (@{$::clusters})
+  {
+    if ( $cluster->{'pid'} eq $ret_pid )
+    {
+      dtr_verbose("$cluster->{'name'} cluster ndb_mgmd exited, pid: $ret_pid");
+      $cluster->{'pid'}= 0;
+
+      # Check if crash expected and restart if it was
+      my $expect_file= "$::opt_vardir/tmp/ndb_mgmd_" . "$cluster->{'type'}" .
+	".expect";
+      if ( -f $expect_file )
+      {
+	dtr_verbose("Crash was expected, file $expect_file exists");
+	ndbmgmd_start($cluster);
+	unlink($expect_file);
+      }
+      return;
+    }
+
+    foreach my $ndbd (@{$cluster->{'ndbds'}})
+    {
+      if ( $ndbd->{'pid'} eq $ret_pid )
+      {
+	dtr_verbose("$cluster->{'name'} cluster ndbd exited, pid: $ret_pid");
+	$ndbd->{'pid'}= 0;
+
+	# Check if crash expected and restart if it was
+	my $expect_file= "$::opt_vardir/tmp/ndbd_" . "$cluster->{'type'}" .
+	  "$ndbd->{'idx'}" . ".expect";
+	if ( -f $expect_file )
+	{
+	  dtr_verbose("Crash was expected, file $expect_file exists");
+	  ndbd_start($cluster, $ndbd->{'idx'},
+		     $ndbd->{'start_extra_args'});
+	  unlink($expect_file);
+	}
+	return;
+      }
+    }
+  }
+
+  if ($::instance_manager->{'spawner_pid'} eq $ret_pid)
+  {
+    return;
+  }
+
+  dtr_warning("check_expected_crash_and_restart couldn't find an entry for pid: $ret_pid");
+
+}
+
+##############################################################################
+#
+#  The operating system will keep information about dead children, 
+#  we read this information here, and if we have records the process
+#  is alive, we mark it as dead.
+#
+##############################################################################
+
+sub dtr_record_dead_children () {
+
+  my $process_died= 0;
+  my $ret_pid;
+
+  # Wait without blockinng to see if any processes had died
+  # -1 or 0 means there are no more procesess to wait for
+  while ( ($ret_pid= waitpid(-1,&WNOHANG)) != 0 and $ret_pid != -1)
+  {
+    dtr_warning("dtr_record_dead_children: $ret_pid");
+    mark_process_dead($ret_pid);
+    $process_died= 1;
+  }
+  return $process_died;
+}
+
+sub start_reap_all {
+  # This causes terminating processes to not become zombies, avoiding
+  # the need for (or possibility of) explicit waitpid().
+  $SIG{CHLD}= 'IGNORE';
+
+  # On some platforms (Linux, QNX, OSX, ...) there is potential race
+  # here. If a process terminated before setting $SIG{CHLD} (but after
+  # any attempt to waitpid() it), it will still be a zombie. So we
+  # have to handle any such process here.
+  my $pid;
+  while(($pid= waitpid(-1, &WNOHANG)) != 0 and $pid != -1)
+  {
+    dtr_warning("start_reap_all pid: $pid");
+    mark_process_dead($pid);
+  };
+}
+
+sub stop_reap_all {
+  $SIG{CHLD}= 'DEFAULT';
+}
+
+
+sub dtr_ping_port ($) {
+  my $port= shift;
+
+  dtr_verbose("dtr_ping_port: $port");
+
+  my $remote= "localhost";
+  my $iaddr=  inet_aton($remote);
+  if ( ! $iaddr )
+  {
+    dtr_error("can't find IP number for $remote");
+  }
+  my $paddr=  sockaddr_in($port, $iaddr);
+  my $proto=  getprotobyname('tcp');
+  if ( ! socket(SOCK, PF_INET, SOCK_STREAM, $proto) )
+  {
+    dtr_error("can't create socket: $!");
+  }
+
+  dtr_debug("Pinging server (port: $port)...");
+
+  if ( connect(SOCK, $paddr) )
+  {
+    close(SOCK);                        # FIXME check error?
+    dtr_verbose("USED");
+    return 1;
+  }
+  else
+  {
+    dtr_verbose("FREE");
+    return 0;
+  }
+}
+
+##############################################################################
+#
+#  Wait for a file to be created
+#
+##############################################################################
+
+# FIXME check that the pidfile contains the expected pid!
+
+sub sleep_until_file_created ($$$) {
+  my $pidfile= shift;
+  my $timeout= shift;
+  my $pid=     shift;
+  my $sleeptime= 100; # Milliseconds
+  my $loops= ($timeout * 1000) / $sleeptime;
+
+  for ( my $loop= 1; $loop <= $loops; $loop++ )
+  {
+    if ( -r $pidfile )
+    {
+      return 1;
+    }
+
+    # Check if it died after the fork() was successful
+    if ( $pid != 0 && waitpid($pid,&WNOHANG) == $pid )
+    {
+      dtr_warning("Process $pid died");
+      return 0;
+    }
+
+    dtr_debug("Sleep $sleeptime milliseconds waiting for $pidfile");
+
+    # Print extra message every 60 seconds
+    my $seconds= ($loop * $sleeptime) / 1000;
+    if ( $seconds > 1 and int($seconds * 10) % 600 == 0 )
+    {
+      my $left= $timeout - $seconds;
+      dtr_warning("Waited $seconds seconds for $pidfile to be created, " .
+                  "still waiting for $left seconds...");
+    }
+
+    # Millisceond sleep emulated with select
+    select(undef, undef, undef, ($sleeptime/1000));
+  }
+
+  return 0;
+}
+
+
+sub dtr_kill_processes ($) {
+  my $pids = shift;
+
+  dtr_verbose("dtr_kill_processes (" . join(" ", keys %{$pids}) . ")");
+
+  foreach my $pid (keys %{$pids})
+  {
+
+    if ($pid <= 0)
+    {
+      dtr_warning("Trying to kill illegal pid: $pid");
+      next;
+    }
+
+    my $signaled_procs= kill(9, $pid);
+    if ($signaled_procs == 0)
+    {
+      # No such process existed, assume it's killed
+      dtr_verbose("killed $pid(no such process)");
+    }
+    else
+    {
+      my $ret_pid= waitpid($pid,0);
+      if ($ret_pid == $pid)
+      {
+	dtr_verbose("killed $pid(got the pid)");
+      }
+      elsif ($ret_pid == -1)
+      {
+	dtr_verbose("killed $pid(got -1)");
+      }
+    }
+  }
+  dtr_verbose("done killing processes");
+}
+
+
+##############################################################################
+#
+#  When we exit, we kill off all children
+#
+##############################################################################
+
+sub dtr_exit ($) {
+  my $code= shift;
+  dtr_timer_stop_all($::glob_timers);
+  local $SIG{HUP} = 'IGNORE';
+  # ToDo: Signalling -$$ will only work if we are the process group
+  # leader (in fact on QNX it will signal our session group leader,
+  # which might be Do-compile or Pushbuild, causing tests to be
+  # aborted). So we only do it if we are the group leader. We might
+  # set ourselves as the group leader at startup (with
+  # POSIX::setpgrp(0,0)), but then care must be needed to always do
+  # proper child process cleanup.
+  POSIX::kill(SIGHUP, -$$) if !$::glob_win32_perl and $$ == getpgrp();
+
+  exit($code);
+}
+
+###########################################################################
+
+1;

=== added file 'tests/lib/dtr_report.pl'
--- tests/lib/dtr_report.pl	1970-01-01 00:00:00 +0000
+++ tests/lib/dtr_report.pl	2010-10-07 19:35:15 +0000
@@ -0,0 +1,383 @@
+# -*- cperl -*-
+# Copyright (C) 2004-2006 MySQL AB
+# 
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; version 2 of the License.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+# This is a library file used by the Perl version of drizzle-test-run,
+# and is part of the translation of the Bourne shell script with the
+# same name.
+
+use strict;
+use warnings;
+
+sub dtr_report_test_name($);
+sub dtr_report_test_passed($);
+sub dtr_report_test_failed($);
+sub dtr_report_test_skipped($);
+sub dtr_report_test_not_skipped_though_disabled($);
+
+sub dtr_report_stats ($);
+sub dtr_print_line ();
+sub dtr_print_thick_line ();
+sub dtr_print_header ();
+sub dtr_report (@);
+sub dtr_warning (@);
+sub dtr_error (@);
+sub dtr_child_error (@);
+sub dtr_debug (@);
+sub dtr_verbose (@);
+
+my $tot_real_time= 0;
+
+
+
+##############################################################################
+#
+#  
+#
+##############################################################################
+
+sub dtr_report_test_name ($) {
+  my $tinfo= shift;
+  my $tname= $tinfo->{name};
+
+  $tname.= " '$tinfo->{combination}'"
+    if defined $tinfo->{combination};
+
+  _dtr_log($tname);
+  if ($::opt_subunit) {
+    printf "test: $tname\n";
+  } else {
+    printf "%-60s ", $tname;
+  }
+}
+
+sub dtr_report_test_skipped ($) {
+  my $tinfo= shift;
+  my $tname= $tinfo->{name};
+  my $cause= "";
+
+  $tinfo->{'result'}= 'DTR_RES_SKIPPED';
+  if ( $tinfo->{'disable'} )
+  {
+    $cause.= "disable";
+  }
+  else
+  {
+    $cause.= "skipped";
+  }
+  if ( $tinfo->{'comment'} )
+  {
+    if ($::opt_subunit) {
+      dtr_report("skip: $tname [\ncause: $cause\n$tinfo->{'comment'}\n]");
+    } else { 
+      dtr_report("[ $cause ]   $tinfo->{'comment'}");
+    }
+  }
+  else
+  {
+    if ($::opt_subunit) {
+      dtr_report("skip: $tname");
+    } else {
+      dtr_report("[ $cause ]");
+    }
+  }
+}
+
+sub dtr_report_tests_not_skipped_though_disabled ($) {
+  my $tests= shift;
+
+  if ( $::opt_enable_disabled )
+  {
+    my @disabled_tests= grep {$_->{'dont_skip_though_disabled'}} @$tests;
+    if ( @disabled_tests )
+    {
+      print "\nTest(s) which will be run though they are marked as disabled:\n";
+      foreach my $tinfo ( sort {$a->{'name'} cmp $b->{'name'}} @disabled_tests )
+      {
+        printf "  %-20s : %s\n", $tinfo->{'name'}, $tinfo->{'comment'};
+      }
+    }
+  }
+}
+
+sub dtr_report_test_passed ($) {
+  my $tinfo= shift;
+  my $tname= $tinfo->{name};
+
+  my $timer=  "";
+  if ( $::opt_timer and -f "$::opt_vardir/log/timer" )
+  {
+    $timer= dtr_fromfile("$::opt_vardir/log/timer");
+    $tot_real_time += ($timer/1000);
+    $timer= sprintf "%7s", $timer;
+    ### XXX: How to format this as iso6801 datetime?
+  }
+  $tinfo->{'result'}= 'dtr_RES_PASSED';
+  if ($::opt_subunit) {
+    dtr_report("success: $tname");
+  } else {
+    dtr_report("[ pass ] $timer");
+  }
+}
+
+sub dtr_report_test_failed ($) {
+  my $tinfo= shift;
+  my $tname= $tinfo->{name};
+  my $comment= "";
+
+  $tinfo->{'result'}= 'dtr_RES_FAILED';
+  if ( defined $tinfo->{'timeout'} )
+  {
+    $comment.= "timeout";
+  }
+  elsif ( $tinfo->{'comment'} )
+  {
+    # The test failure has been detected by drizzle-test-run.pl
+    # when starting the servers or due to other error, the reason for
+    # failing the test is saved in "comment"
+    $comment.= "$tinfo->{'comment'}";
+  }
+  elsif ( -f $::path_timefile )
+  {
+    # Test failure was detected by test tool and it's report
+    # about what failed has been saved to file. Display the report.
+    $comment.= dtr_fromfile($::path_timefile);
+  }
+  else
+  {
+    # Neither this script or the test tool has recorded info
+    # about why the test has failed. Should be debugged.
+    $comment.= "Unexpected termination, probably when starting drizzled";
+  }
+  if ($::opt_subunit) {
+    dtr_report("failure: $tname [\n$comment\n]");
+  } else {
+    dtr_report("[ fail ]\n$comment");
+  }
+}
+
+sub dtr_report_stats ($) {
+  my $tests= shift;
+
+  # ----------------------------------------------------------------------
+  # Find out how we where doing
+  # ----------------------------------------------------------------------
+
+  my $tot_skiped= 0;
+  my $tot_passed= 0;
+  my $tot_failed= 0;
+  my $tot_tests=  0;
+  my $tot_restarts= 0;
+  my $found_problems= 0; # Some warnings in the logfiles are errors...
+
+  foreach my $tinfo (@$tests)
+  {
+    if ( $tinfo->{'result'} eq 'DTR_RES_SKIPPED' )
+    {
+      $tot_skiped++;
+    }
+    elsif ( $tinfo->{'result'} eq 'DTR_RES_PASSED' )
+    {
+      $tot_tests++;
+      $tot_passed++;
+    }
+    elsif ( $tinfo->{'result'} eq 'DTR_RES_FAILED' )
+    {
+      $tot_tests++;
+      $tot_failed++;
+    }
+    if ( $tinfo->{'restarted'} )
+    {
+      $tot_restarts++;
+    }
+  }
+
+  # ----------------------------------------------------------------------
+  # Print out a summary report to screen
+  # ----------------------------------------------------------------------
+
+  if ( ! $tot_failed )
+  {
+    print "All $tot_tests tests were successful.\n";
+  }
+  else
+  {
+    my $ratio=  $tot_passed * 100 / $tot_tests;
+    print "Failed $tot_failed/$tot_tests tests, ";
+    printf("%.2f", $ratio);
+    print "\% were successful.\n\n";
+    print
+      "The log files in var/log may give you some hint\n",
+      "of what went wrong.\n",
+      "If you want to report this error, go to:\n",
+      "\thttp://bugs.launchpad.net/drizzle\n";
+  }
+  if (!$::opt_extern)
+  {
+    print "The servers were restarted $tot_restarts times\n";
+  }
+
+  if ( $::opt_timer )
+  {
+    use English;
+
+    dtr_report("Spent", sprintf("%.3f", $tot_real_time),"of",
+	       time - $BASETIME, "seconds executing testcases");
+  }
+
+  print "\n";
+
+  # Print a list of testcases that failed
+  if ( $tot_failed != 0 )
+  {
+    my $test_mode= join(" ", @::glob_test_mode) || "default";
+    print "drizzle-test-run in $test_mode mode: *** Failing the test(s):";
+
+    foreach my $tinfo (@$tests)
+    {
+      if ( $tinfo->{'result'} eq 'DTR_RES_FAILED' )
+      {
+        print " $tinfo->{'name'}";
+      }
+    }
+    print "\n";
+
+  }
+
+  # Print a list of check_testcases that failed(if any)
+  if ( $::opt_check_testcases )
+  {
+    my @check_testcases= ();
+
+    foreach my $tinfo (@$tests)
+    {
+      if ( defined $tinfo->{'check_testcase_failed'} )
+      {
+	push(@check_testcases, $tinfo->{'name'});
+      }
+    }
+
+    if ( @check_testcases )
+    {
+      print "Check of testcase failed for: ";
+      print join(" ", @check_testcases);
+      print "\n\n";
+    }
+  }
+
+  if ( $tot_failed != 0 || $found_problems)
+  {
+    dtr_error("there were failing test cases");
+  }
+}
+
+##############################################################################
+#
+#  Text formatting
+#
+##############################################################################
+
+sub dtr_print_line () {
+  print '-' x 80, "\n";
+}
+
+sub dtr_print_thick_line () {
+  print '=' x 80, "\n";
+}
+
+sub dtr_print_header () {
+  print "DEFAULT STORAGE ENGINE: $::opt_engine\n";
+  if ( $::opt_timer )
+  {
+    printf "%-61s%-9s%10s\n","TEST","RESULT","TIME (ms)";
+  }
+  else
+  {
+    print "TEST                           RESULT\n";
+  }
+  dtr_print_line();
+  print "\n";
+}
+
+
+##############################################################################
+#
+#  Log and reporting functions
+#
+##############################################################################
+
+use IO::File;
+
+my $log_file_ref= undef;
+
+sub dtr_log_init ($) {
+  my ($filename)= @_;
+
+  dtr_error("Log is already open") if defined $log_file_ref;
+
+  $log_file_ref= IO::File->new($filename, "a") or
+    dtr_warning("Could not create logfile $filename: $!");
+}
+
+sub _dtr_log (@) {
+  print $log_file_ref join(" ", @_),"\n"
+    if defined $log_file_ref;
+}
+
+sub dtr_report (@) {
+  # Print message to screen and log
+  _dtr_log(@_);
+  print join(" ", @_),"\n";
+}
+
+sub dtr_warning (@) {
+  # Print message to screen and log
+  _dtr_log("WARNING: ", @_);
+  print STDERR "drizzle-test-run: WARNING: ",join(" ", @_),"\n";
+}
+
+sub dtr_error (@) {
+  # Print message to screen and log
+  _dtr_log("ERROR: ", @_);
+  print STDERR "drizzle-test-run: *** ERROR: ",join(" ", @_),"\n";
+  dtr_exit(1);
+}
+
+sub dtr_child_error (@) {
+  # Print message to screen and log
+  _dtr_log("ERROR(child): ", @_);
+  print STDERR "drizzle-test-run: *** ERROR(child): ",join(" ", @_),"\n";
+  exit(1);
+}
+
+sub dtr_debug (@) {
+  # Only print if --script-debug is used
+  if ( $::opt_script_debug )
+  {
+    _dtr_log("###: ", @_);
+    print STDERR "####: ",join(" ", @_),"\n";
+  }
+}
+
+sub dtr_verbose (@) {
+  # Always print to log, print to screen only when --verbose is used
+  _dtr_log("> ",@_);
+  if ( $::opt_verbose )
+  {
+    print STDERR "> ",join(" ", @_),"\n";
+  }
+}
+
+1;

=== added file 'tests/lib/dtr_stress.pl'
--- tests/lib/dtr_stress.pl	1970-01-01 00:00:00 +0000
+++ tests/lib/dtr_stress.pl	2010-10-07 19:35:15 +0000
@@ -0,0 +1,191 @@
+# -*- cperl -*-
+# Copyright (C) 2006 MySQL AB
+# 
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; version 2 of the License.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+# This is a library file used by the Perl version of drizzle-test-run,
+# and is part of the translation of the Bourne shell script with the
+# same name.
+
+use strict;
+use File::Spec;
+
+# These are not to be prefixed with "dtr_"
+
+sub run_stress_test ();
+
+##############################################################################
+#
+#  Run tests in the stress mode
+#
+##############################################################################
+
+sub run_stress_test () 
+{
+
+  my $args;
+  my $stress_suitedir;
+
+  dtr_report("Starting stress testing\n");
+
+  if ( ! $::glob_use_embedded_server )
+  {
+    if ( ! drizzled_start($::master->[0],[],[]) )
+    {
+      dtr_error("Can't start the drizzled server");
+    }
+  }
+
+  my $stress_basedir=File::Spec->catdir($::opt_vardir, "stress");
+  
+  #Clean up stress dir 
+  if ( -d $stress_basedir )
+  {
+    rdtree($stress_basedir);
+  }
+  mkpath($stress_basedir);
+ 
+  if ($::opt_stress_suite ne 'main' && $::opt_stress_suite ne 'default' )
+  {
+    $stress_suitedir=File::Spec->catdir($::glob_drizzle_test_dir, "suite", 
+                                         $::opt_stress_suite);
+  }
+  else
+  {
+    $stress_suitedir=$::glob_drizzle_test_dir;
+  }
+
+  if ( -d $stress_suitedir )
+  {
+    #$stress_suite_t_dir=File::Spec->catdir($stress_suitedir, "t");
+    #$stress_suite_r_dir=File::Spec->catdir($stress_suitedir, "r");    
+    #FIXME: check dirs above for existence to ensure that test suite 
+    #       contains tests and results dirs
+  }
+  else
+  {
+    dtr_error("Specified test suite $::opt_stress_suite doesn't exist");
+  }
+ 
+  if ( @::opt_cases )
+  {
+    $::opt_stress_test_file=File::Spec->catfile($stress_basedir, "stress_tests.txt");
+    open(STRESS_FILE, ">$::opt_stress_test_file");
+    print STRESS_FILE join("\n",@::opt_cases),"\n";
+    close(STRESS_FILE);
+  }
+  elsif ( $::opt_stress_test_file )
+  {
+    $::opt_stress_test_file=File::Spec->catfile($stress_suitedir, 
+                                              $::opt_stress_test_file);
+    if ( ! -f $::opt_stress_test_file )
+    {
+      dtr_error("Specified file $::opt_stress_test_file with list of tests does not exist\n",
+                "Please ensure that file exists and has proper permissions");
+    }
+  }
+  else
+  {
+    $::opt_stress_test_file=File::Spec->catfile($stress_suitedir, 
+                                              "stress_tests.txt");
+    if ( ! -f $::opt_stress_test_file )
+    {
+      dtr_error("Default file $::opt_stress_test_file with list of tests does not exist\n",
+          "Please use --stress-test-file option to specify custom one or you can\n",
+          "just specify name of test for testing as last argument in command line");
+
+    }    
+  }
+
+  if ( $::opt_stress_init_file )
+  {
+    $::opt_stress_init_file=File::Spec->catfile($stress_suitedir, 
+                                              $::opt_stress_init_file);
+    if ( ! -f $::opt_stress_init_file )
+    {
+      dtr_error("Specified file $::opt_stress_init_file with list of tests does not exist\n",
+                "Please ensure that file exists and has proper permissions");
+    }
+  }
+  else
+  {
+    $::opt_stress_init_file=File::Spec->catfile($stress_suitedir, 
+                                              "stress_init.txt");
+    if ( ! -f $::opt_stress_init_file )
+    {
+      $::opt_stress_init_file='';
+    }
+  }  
+  
+  if ( $::opt_stress_mode ne 'random' && $::opt_stress_mode ne 'seq' )
+  {
+    dtr_error("You specified wrong mode $::opt_stress_mode for stress test\n",
+              "Correct values are 'random' or 'seq'");
+  }
+
+  dtr_init_args(\$args);
+  
+  dtr_add_arg($args, "--server-socket=%s", $::master->[0]->{'path_sock'});
+  dtr_add_arg($args, "--server-user=%s", $::opt_user);
+  dtr_add_arg($args, "--server-database=%s", "test");  
+  dtr_add_arg($args, "--stress-suite-basedir=%s", $::glob_drizzle_test_dir);  
+  dtr_add_arg($args, "--suite=%s", $::opt_stress_suite);
+  dtr_add_arg($args, "--stress-tests-file=%s", $::opt_stress_test_file);      
+  dtr_add_arg($args, "--stress-basedir=%s", $stress_basedir);
+  dtr_add_arg($args, "--server-logs-dir=%s", $stress_basedir);
+  dtr_add_arg($args, "--stress-mode=%s", $::opt_stress_mode);
+  dtr_add_arg($args, "--drizzletest=%s", $::exe_drizzletest);
+  dtr_add_arg($args, "--threads=%s", $::opt_stress_threads);
+  dtr_add_arg($args, "--verbose");
+  dtr_add_arg($args, "--cleanup");
+  dtr_add_arg($args, "--log-error-details");
+  dtr_add_arg($args, "--abort-on-error");
+
+  if ( $::opt_stress_init_file )
+  {
+    dtr_add_arg($args, "--stress-init-file=%s", $::opt_stress_init_file);
+  }
+
+  if ( !$::opt_stress_loop_count && !$::opt_stress_test_count &&
+       !$::opt_stress_test_duration )
+  {
+    #Limit stress testing with 20 loops in case when any limit parameter 
+    #was specified 
+    $::opt_stress_test_count=20;
+  }
+
+  if ( $::opt_stress_loop_count )
+  {
+    dtr_add_arg($args, "--loop-count=%s", $::opt_stress_loop_count);
+  }
+
+  if ( $::opt_stress_test_count )
+  {
+    dtr_add_arg($args, "--test-count=%s", $::opt_stress_test_count);
+  }
+
+  if ( $::opt_stress_test_duration )
+  {
+    dtr_add_arg($args, "--test-duration=%s", $::opt_stress_test_duration);
+  }
+
+  #Run stress test
+  dtr_run("$::glob_drizzle_test_dir/drizzle-stress-test.pl", $args, "", "", "", "");
+  if ( ! $::glob_use_embedded_server )
+  {
+    stop_all_servers();
+  }
+}
+
+1;

=== added file 'tests/lib/dtr_timer.pl'
--- tests/lib/dtr_timer.pl	1970-01-01 00:00:00 +0000
+++ tests/lib/dtr_timer.pl	2010-10-07 19:35:15 +0000
@@ -0,0 +1,158 @@
+# -*- cperl -*-
+# Copyright (C) 2005-2006 MySQL AB
+# 
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; version 2 of the License.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+# This is a library file used by the Perl version of drizzle-test-run,
+# and is part of the translation of the Bourne shell script with the
+# same name.
+
+use Errno;
+use strict;
+
+sub dtr_init_timers ();
+sub dtr_timer_start($$$);
+sub dtr_timer_stop($$);
+sub dtr_timer_stop_all($);
+
+
+##############################################################################
+#
+#  Initiate the structure shared by all timers
+#
+##############################################################################
+
+sub dtr_init_timers () {
+  my $timers = { timers => {}, pids => {}};
+  return $timers;
+}
+
+
+##############################################################################
+#
+#  Start, stop and poll a timer
+#
+#  As alarm() isn't portable to Windows, we use separate processes to
+#  implement timers.
+#
+##############################################################################
+
+sub dtr_timer_start($$$) {
+  my ($timers,$name,$duration)= @_;
+
+  if ( exists $timers->{'timers'}->{$name} )
+  {
+    # We have an old running timer, kill it
+    dtr_warning("There is an old timer running");
+    dtr_timer_stop($timers,$name);
+  }
+
+ FORK:
+  {
+    my $tpid= fork();
+
+    if ( ! defined $tpid )
+    {
+      if ( $! == $!{EAGAIN} )           # See "perldoc Errno"
+      {
+        dtr_warning("Got EAGAIN from fork(), sleep 1 second and redo");
+        sleep(1);
+        redo FORK;
+      }
+      else
+      {
+        dtr_error("can't fork timer, error: $!");
+      }
+    }
+
+    if ( $tpid )
+    {
+      # Parent, record the information
+      dtr_verbose("Starting timer for '$name',",
+		  "duration: $duration, pid: $tpid");
+      $timers->{'timers'}->{$name}->{'pid'}= $tpid;
+      $timers->{'timers'}->{$name}->{'duration'}= $duration;
+      $timers->{'pids'}->{$tpid}= $name;
+    }
+    else
+    {
+      # Child, install signal handlers and sleep for "duration"
+
+      # Don't do the ^C cleanup in the timeout child processes!
+      # There is actually a race here, if we get ^C after fork(), but before
+      # clearing the signal handler.
+      $SIG{INT}= 'DEFAULT';
+
+      $SIG{TERM}= sub {
+	dtr_verbose("timer $$ woke up, exiting!");
+	exit(0);
+      };
+
+      $0= "dtr_timer(timers,$name,$duration)";
+      sleep($duration);
+      dtr_verbose("timer $$ expired after $duration seconds");
+      exit(0);
+    }
+  }
+}
+
+
+sub dtr_timer_stop ($$) {
+  my ($timers,$name)= @_;
+
+  if ( exists $timers->{'timers'}->{$name} )
+  {
+    my $tpid= $timers->{'timers'}->{$name}->{'pid'};
+    dtr_verbose("Stopping timer for '$name' with pid $tpid");
+
+    # FIXME as Cygwin reuses pids fast, maybe check that is
+    # the expected process somehow?!
+    kill(15, $tpid);
+
+    # As the timers are so simple programs, we trust them to terminate,
+    # and use blocking wait for it. We wait just to avoid a zombie.
+    waitpid($tpid,0);
+
+    delete $timers->{'timers'}->{$name}; # Remove the timer information
+    delete $timers->{'pids'}->{$tpid};   # and PID reference
+
+    return 1;
+  }
+
+  dtr_error("Asked to stop timer '$name' not started");
+}
+
+
+sub dtr_timer_stop_all ($) {
+  my $timers= shift;
+
+  foreach my $name ( keys %{$timers->{'timers'}} )
+  {
+    dtr_timer_stop($timers, $name);
+  }
+  return 1;
+}
+
+
+sub dtr_timer_timeout ($$) {
+  my ($timers,$pid)= @_;
+
+  return "" unless exists $timers->{'pids'}->{$pid};
+
+  # Got a timeout(the process with $pid is recorded as being a timer)
+  # return the name of the timer
+  return $timers->{'pids'}->{$pid};
+}
+
+1;

=== added file 'tests/lib/dtr_unique.pl'
--- tests/lib/dtr_unique.pl	1970-01-01 00:00:00 +0000
+++ tests/lib/dtr_unique.pl	2010-10-07 19:35:15 +0000
@@ -0,0 +1,178 @@
+# -*- cperl -*-
+# Copyright (C) 2006 MySQL AB
+# 
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; version 2 of the License.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+#
+# This file is used from drizzle-test-run.pl when choosing
+# port numbers and directories to use for running drizzled.
+#
+
+use strict;
+use Fcntl ':flock';
+
+#
+# Requested IDs are stored in a hash and released upon END.
+#
+my %dtr_unique_assigned_ids = ();
+my $dtr_unique_pid;
+BEGIN {
+	$dtr_unique_pid = $$ unless defined $dtr_unique_pid;
+}
+END { 
+	if($dtr_unique_pid == $$) {
+		while(my ($id,$file) = each(%dtr_unique_assigned_ids)) {
+			print "Autoreleasing $file:$id\n";
+			dtr_release_unique_id($file, $id);
+		}
+	}
+}
+
+#
+# Require a unique, numerical ID, given a file name (where all
+# requested IDs are stored), a minimum and a maximum value.
+#
+# We use flock to implement locking for the ID file and ignore
+# possible problems arising from lack of support for it on 
+# some platforms (it should work on most, and the possible
+# race condition would occur rarely). The proper solution for
+# this is a daemon that manages IDs, of course.
+#
+# If no unique ID within the specified parameters can be 
+# obtained, return undef.
+#
+sub dtr_require_unique_id($$$) {
+	my $file = shift;
+	my $min = shift;
+	my $max = shift;
+	my $ret = undef;
+	my $changed = 0;
+
+	my $can_use_ps = `ps -e | grep '^[ ]*$$ '`;
+
+	if(eval("readlink '$file'") || eval("readlink '$file.sem'")) {
+		die 'lock file is a symbolic link';
+	}
+
+	chmod 0777, "$file.sem";
+	open SEM, ">", "$file.sem" or die "can't write to $file.sem";
+	flock SEM, LOCK_EX or die "can't lock $file.sem";
+	if(! -e $file) {
+		open FILE, ">", $file or die "can't create $file";
+		close FILE;
+	}
+
+	if(eval("readlink '$file'") || eval("readlink '$file.sem'")) {
+		die 'lock file is a symbolic link';
+	}
+
+	chmod 0777, $file;
+	open FILE, "+<", $file or die "can't open $file";
+	select undef,undef,undef,0.2;
+	seek FILE, 0, 0;
+	my %taken = ();
+	while(<FILE>) {
+		chomp;
+		my ($id, $pid) = split / /;
+		$taken{$id} = $pid;
+		if($can_use_ps) {
+			my $res = `ps -e | grep '^[ ]*$pid '`;
+			if(!$res) {
+				print "Ignoring slot $id used by missing process $pid.\n";
+				delete $taken{$id};
+				++$changed;
+			}
+		}
+	}
+	for(my $i=$min; $i<=$max; ++$i) {
+		if(! exists $taken{$i}) {
+			$ret = $i;
+			$taken{$i} = $$;
+			++$changed;
+			last;
+		}
+	}
+	if($changed) {
+		seek FILE, 0, 0;
+		truncate FILE, 0 or die "can't truncate $file";
+		for my $k (keys %taken) {
+			print FILE $k . ' ' . $taken{$k} . "\n";
+		}
+	}
+	close FILE;
+	flock SEM, LOCK_UN or warn "can't unlock $file.sem";
+	close SEM;
+	$dtr_unique_assigned_ids{$ret} = $file if defined $ret;
+	return $ret;
+}
+
+#
+# Require a unique ID like above, but sleep if no ID can be
+# obtained immediately.
+#
+sub dtr_require_unique_id_and_wait($$$) {
+	my $ret = dtr_require_unique_id($_[0],$_[1],$_[2]);
+	while(! defined $ret) {
+		sleep 30;
+		$ret = dtr_require_unique_id($_[0],$_[1],$_[2]);
+		print "Waiting for unique id to become available...\n" unless $ret;
+	}
+	return $ret;
+}
+
+#
+# Release a unique ID.
+#
+sub dtr_release_unique_id($$) {
+	my $file = shift;
+	my $myid = shift;
+
+	if(eval("readlink '$file'") || eval("readlink '$file.sem'")) {
+		die 'lock file is a symbolic link';
+	}
+
+	open SEM, ">", "$file.sem" or die "can't write to $file.sem";
+	flock SEM, LOCK_EX or die "can't lock $file.sem";
+
+	if(eval("readlink '$file'") || eval("readlink '$file.sem'")) {
+		die 'lock file is a symbolic link';
+	}
+
+	if(! -e $file) {
+		open FILE, ">", $file or die "can't create $file";
+		close FILE;
+	}
+	open FILE, "+<", $file or die "can't open $file";
+	select undef,undef,undef,0.2;
+	seek FILE, 0, 0;
+	my %taken = ();
+	while(<FILE>) {
+		chomp;
+		my ($id, $pid) = split / /;
+		$taken{$id} = $pid;
+	}
+	delete $taken{$myid};
+	seek FILE, 0, 0;
+	truncate FILE, 0 or die "can't truncate $file";
+	for my $k (keys %taken) {
+		print FILE $k . ' ' . $taken{$k} . "\n";
+	}
+	close FILE;
+	flock SEM, LOCK_UN or warn "can't unlock $file.sem";
+	close SEM;
+	delete $dtr_unique_assigned_ids{$myid};
+}
+
+1;
+

=== removed file 'tests/lib/mtr_cases.pl'
--- tests/lib/mtr_cases.pl	2010-07-07 14:32:14 +0000
+++ tests/lib/mtr_cases.pl	1970-01-01 00:00:00 +0000
@@ -1,906 +0,0 @@
-# -*- cperl -*-
-# Copyright (C) 2005-2006 MySQL AB
-# 
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
-# 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-# This is a library file used by the Perl version of mysql-test-run,
-# and is part of the translation of the Bourne shell script with the
-# same name.
-
-use File::Basename;
-use IO::File();
-use strict;
-
-use My::Config;
-
-sub collect_test_cases ($);
-sub collect_one_suite ($);
-sub collect_one_test_case ($$$$$$$$$);
-
-sub mtr_options_from_test_file($$);
-
-my $do_test;
-my $skip_test;
-
-sub init_pattern {
-  my ($from, $what)= @_;
-  if ( $from =~ /^[a-z0-9]$/ ) {
-    # Does not contain any regex, make the pattern match
-    # beginning of string
-    $from= "^$from";
-  }
-  # Check that pattern is a valid regex
-  eval { "" =~/$from/; 1 } or
-    mtr_error("Invalid regex '$from' passed to $what\nPerl says: $@");
-  return $from;
-}
-
-
-
-##############################################################################
-#
-#  Collect information about test cases we are to run
-#
-##############################################################################
-
-sub collect_test_cases ($) {
-  $do_test= init_pattern($::opt_do_test, "--do-test");
-  $skip_test= init_pattern($::opt_skip_test, "--skip-test");
-
-  my $suites= shift; # Semicolon separated list of test suites
-  my $cases = [];    # Array of hash
-
-  foreach my $suite (split(",", $suites))
-  {
-    push(@$cases, collect_one_suite($suite));
-  }
-
-
-  if ( @::opt_cases )
-  {
-    # Check that the tests specified was found
-    # in at least one suite
-    foreach my $test_name_spec ( @::opt_cases )
-    {
-      my $found= 0;
-      my ($sname, $tname, $extension)= split_testname($test_name_spec);
-      foreach my $test ( @$cases )
-      {
-	# test->{name} is always in suite.name format
-	if ( $test->{name} =~ /.*\.$tname/ )
-	{
-	  $found= 1;
-	}
-      }
-      if ( not $found )
-      {
-	mtr_error("Could not find $tname in any suite");
-      }
-    }
-  }
-
-  if ( $::opt_reorder )
-  {
-    # Reorder the test cases in an order that will make them faster to run
-    my %sort_criteria;
-
-    # Make a mapping of test name to a string that represents how that test
-    # should be sorted among the other tests.  Put the most important criterion
-    # first, then a sub-criterion, then sub-sub-criterion, et c.
-    foreach my $tinfo (@$cases)
-    {
-      my @criteria = ();
-
-      # Look for tests that muct be in run in a defined order
-      # that is defined by test having the same name except for
-      # the ending digit
-
-      # Put variables into hash
-      my $test_name= $tinfo->{'name'};
-      my $depend_on_test_name;
-      if ( $test_name =~ /^([\D]+)([0-9]{1})$/ )
-      {
-	my $base_name= $1;
-	my $idx= $2;
-	mtr_verbose("$test_name =>  $base_name idx=$idx");
-	if ( $idx > 1 )
-	{
-	  $idx-= 1;
-	  $base_name= "$base_name$idx";
-	  mtr_verbose("New basename $base_name");
-	}
-
-	foreach my $tinfo2 (@$cases)
-	{
-	  if ( $tinfo2->{'name'} eq $base_name )
-	  {
-	    mtr_verbose("found dependent test $tinfo2->{'name'}");
-	    $depend_on_test_name=$base_name;
-	  }
-	}
-      }
-
-      if ( defined $depend_on_test_name )
-      {
-	mtr_verbose("Giving $test_name same critera as $depend_on_test_name");
-	$sort_criteria{$test_name} = $sort_criteria{$depend_on_test_name};
-      }
-      else
-      {
-	#
-	# Append the criteria for sorting, in order of importance.
-	#
-	# Group test with equal options together.
-	# Ending with "~" makes empty sort later than filled
-	push(@criteria, join("!", sort @{$tinfo->{'master_opt'}}) . "~");
-
-	$sort_criteria{$test_name} = join(" ", @criteria);
-      }
-    }
-
-    @$cases = sort {
-      $sort_criteria{$a->{'name'}} . $a->{'name'} cmp
-	$sort_criteria{$b->{'name'}} . $b->{'name'}; } @$cases;
-
-    if ( $::opt_script_debug )
-    {
-      # For debugging the sort-order
-      foreach my $tinfo (@$cases)
-      {
-	print("$sort_criteria{$tinfo->{'name'}} -> \t$tinfo->{'name'}\n");
-      }
-    }
-  }
-
-  return $cases;
-
-}
-
-# Valid extensions and their corresonding component id
-my %exts = ( 'test' => 'mysqld',
-	     'imtest' => 'im'
-	   );
-
-
-# Returns (suitename, testname, extension)
-sub split_testname {
-  my ($test_name)= @_;
-
-  # Get rid of directory part and split name on .'s
-  my @parts= split(/\./, basename($test_name));
-
-  if (@parts == 1){
-    # Only testname given, ex: alias
-    return (undef , $parts[0], undef);
-  } elsif (@parts == 2) {
-    # Either testname.test or suite.testname given
-    # Ex. main.alias or alias.test
-
-    if (defined $exts{$parts[1]})
-    {
-      return (undef , $parts[0], $parts[1]);
-    }
-    else
-    {
-      return ($parts[0], $parts[1], undef);
-    }
-
-  } elsif (@parts == 3) {
-    # Fully specified suitename.testname.test
-    # ex main.alias.test
-    return ( $parts[0], $parts[1], $parts[2]);
-  }
-
-  mtr_error("Illegal format of test name: $test_name");
-}
-
-
-sub collect_one_suite($)
-{
-  my $suite= shift;  # Test suite name
-  my @cases;  # Array of hash
-
-  mtr_verbose("Collecting: $suite");
-
-  my $suitepath= "$::glob_suite_path";
-  my $suitedir= "$::glob_mysql_test_dir"; # Default
-  if ( $suite ne "main" )
-  {
-    $suitedir= mtr_path_exists(
-             "$suitepath/$suite/drizzle-tests",
-             "$suitepath/$suite/tests",
-             "$suitedir/suite/$suite",
-			       "$suitedir/$suite");
-    mtr_verbose("suitedir: $suitedir");
-  }
-
-  my $testdir= "$suitedir/t";
-  my $resdir=  "$suitedir/r";
-
-  # ----------------------------------------------------------------------
-  # Build a hash of disabled testcases for this suite
-  # ----------------------------------------------------------------------
-  my %disabled;
-  if ( open(DISABLED, "$testdir/disabled.def" ) )
-  {
-    while ( <DISABLED> )
-      {
-        chomp;
-        if ( /^\s*(\S+)\s*:\s*(.*?)\s*$/ )
-          {
-            $disabled{$1}= $2;
-          }
-      }
-    close DISABLED;
-  }
-
-  # Read suite.opt file
-  my $suite_opt_file=  "$testdir/suite.opt";
-  my $suite_opts= [];
-  if ( -f $suite_opt_file )
-  {
-    $suite_opts= mtr_get_opts_from_file($suite_opt_file);
-  }
-
-  if ( @::opt_cases )
-  {
-    # Collect in specified order
-    foreach my $test_name_spec ( @::opt_cases )
-    {
-      my ($sname, $tname, $extension)= split_testname($test_name_spec);
-
-      # The test name parts have now been defined
-      #print "  suite_name: $sname\n";
-      #print "  tname:      $tname\n";
-      #print "  extension:  $extension\n";
-
-      # Check cirrect suite if suitename is defined
-      next if (defined $sname and $suite ne $sname);
-
-      my $component_id;
-      if ( defined $extension )
-      {
-	my $full_name= "$testdir/$tname.$extension";
-	# Extension was specified, check if the test exists
-        if ( ! -f $full_name)
-        {
-	  # This is only an error if suite was specified, otherwise it
-	  # could exist in another suite
-          mtr_error("Test '$full_name' was not found in suite '$sname'")
-	    if $sname;
-
-	  next;
-        }
-	$component_id= $exts{$extension};
-      }
-      else
-      {
-	# No extension was specified
-	my ($ext, $component);
-	while (($ext, $component)= each %exts) {
-	  my $full_name= "$testdir/$tname.$ext";
-
-	  if ( ! -f $full_name ) {
-	    next;
-	  }
-	  $component_id= $component;
-	  $extension= $ext;
-	}
-	# Test not found here, could exist in other suite
-	next unless $component_id;
-      }
-
-      collect_one_test_case($testdir,$resdir,$suite,$tname,
-                            "$tname.$extension",\@cases,\%disabled,
-			    $component_id,$suite_opts);
-    }
-  }
-  else
-  {
-    opendir(TESTDIR, $testdir) or mtr_error("Can't open dir \"$testdir\": $!");
-
-    foreach my $elem ( sort readdir(TESTDIR) )
-    {
-      my $component_id= undef;
-      my $tname= undef;
-
-      if ($tname= mtr_match_extension($elem, 'test'))
-      {
-        $component_id = 'mysqld';
-      }
-      elsif ($tname= mtr_match_extension($elem, 'imtest'))
-      {
-        $component_id = 'im';
-      }
-      else
-      {
-        next;
-      }
-
-      # Skip tests that does not match the --do-test= filter
-      next if ($do_test and not $tname =~ /$do_test/o);
-
-      collect_one_test_case($testdir,$resdir,$suite,$tname,
-                            $elem,\@cases,\%disabled,$component_id,
-			    $suite_opts);
-    }
-    closedir TESTDIR;
-  }
-
-
-  #  Return empty list if no testcases found
-  return if (@cases == 0);
-
-  # ----------------------------------------------------------------------
-  # Read combinations for this suite and build testcases x combinations
-  # if any combinations exists
-  # ----------------------------------------------------------------------
-  if ( ! $::opt_skip_combination )
-  {
-    my @combinations;
-    my $combination_file= "$suitedir/combinations";
-    #print "combination_file: $combination_file\n";
-    if (@::opt_combinations)
-    {
-      # take the combination from command-line
-      mtr_verbose("Take the combination from command line");
-      foreach my $combination (@::opt_combinations) {
-	my $comb= {};
-	$comb->{name}= $combination;
-	push(@{$comb->{comb_opt}}, $combination);
-	push(@combinations, $comb);
-      }
-    }
-    elsif (-f $combination_file )
-    {
-      # Read combinations file in my.cnf format
-      mtr_verbose("Read combinations file");
-      my $config= My::Config->new($combination_file);
-
-      foreach my $group ($config->groups()) {
-	my $comb= {};
-	$comb->{name}= $group->name();
-        foreach my $option ( $group->options() ) {
-	  push(@{$comb->{comb_opt}}, $option->name()."=".$option->value());
-	}
-	push(@combinations, $comb);
-      }
-    }
-
-    if (@combinations)
-    {
-      print " - adding combinations\n";
-      #print_testcases(@cases);
-
-      my @new_cases;
-      foreach my $comb (@combinations)
-      {
-	foreach my $test (@cases)
-	{
-	  #print $test->{name}, " ", $comb, "\n";
-	  my $new_test= {};
-
-	  while (my ($key, $value) = each(%$test)) {
-	    if (ref $value eq "ARRAY") {
-	      push(@{$new_test->{$key}}, @$value);
-	    } else {
-	      $new_test->{$key}= $value;
-	    }
-	  }
-
-	  # Append the combination options to master_opt and slave_opt
-	  push(@{$new_test->{master_opt}}, @{$comb->{comb_opt}});
-	  push(@{$new_test->{slave_opt}}, @{$comb->{comb_opt}});
-
-	  # Add combination name shrt name
-	  $new_test->{combination}= $comb->{name};
-
-	  # Add the new test to new test cases list
-	  push(@new_cases, $new_test);
-	}
-      }
-      #print_testcases(@new_cases);
-      @cases= @new_cases;
-      #print_testcases(@cases);
-    }
-  }
-
-  optimize_cases(\@cases);
-  #print_testcases(@cases);
-
-  return @cases;
-}
-
-
-#
-# Loop through all test cases
-# - optimize which test to run by skipping unnecessary ones
-# - update settings if necessary
-#
-sub optimize_cases {
-  my ($cases)= @_;
-
-  foreach my $tinfo ( @$cases )
-  {
-    # Skip processing if already marked as skipped
-    next if $tinfo->{skip};
-
-    # Replication test needs an adjustment of binlog format
-    if (mtr_match_prefix($tinfo->{'name'}, "rpl"))
-    {
-
-      # =======================================================
-      # Get binlog-format used by this test from master_opt
-      # =======================================================
-      my $test_binlog_format;
-      foreach my $opt ( @{$tinfo->{master_opt}} ) {
-	$test_binlog_format= $test_binlog_format ||
-	  mtr_match_prefix($opt, "--binlog-format=");
-      }
-      # print $tinfo->{name}." uses ".$test_binlog_format."\n";
-
-      # =======================================================
-      # If a special binlog format was selected with
-      # --mysqld=--binlog-format=x, skip all test with different
-      # binlog-format
-      # =======================================================
-      if (defined $::used_binlog_format and
-	  $test_binlog_format and
-	  $::used_binlog_format ne $test_binlog_format)
-      {
-	$tinfo->{'skip'}= 1;
-	$tinfo->{'comment'}= "Requires --binlog-format='$test_binlog_format'";
-	next;
-      }
-
-      # =======================================================
-      # Check that testcase supports the designated binlog-format
-      # =======================================================
-      if ($test_binlog_format and defined $tinfo->{'sup_binlog_formats'} )
-      {
-	my $supported=
-	  grep { $_ eq $test_binlog_format } @{$tinfo->{'sup_binlog_formats'}};
-	if ( !$supported )
-	{
-	  $tinfo->{'skip'}= 1;
-	  $tinfo->{'comment'}=
-	    "Doesn't support --binlog-format='$test_binlog_format'";
-	  next;
-	}
-      }
-
-      # =======================================================
-      # Use dynamic switching of binlog-format if mtr started
-      # w/o --mysqld=--binlog-format=xxx and combinations.
-      # =======================================================
-      if (!defined $tinfo->{'combination'} and
-          !defined $::used_binlog_format)
-      {
-        $test_binlog_format= $tinfo->{'sup_binlog_formats'}->[0];
-      }
-
-      # Save binlog format for dynamic switching
-      $tinfo->{binlog_format}= $test_binlog_format;
-    }
-  }
-}
-
-
-##############################################################################
-#
-#  Collect information about a single test case
-#
-##############################################################################
-
-
-sub collect_one_test_case($$$$$$$$$) {
-  my $testdir= shift;
-  my $resdir=  shift;
-  my $suite=   shift;
-  my $tname=   shift;
-  my $elem=    shift;
-  my $cases=   shift;
-  my $disabled=shift;
-  my $component_id= shift;
-  my $suite_opts= shift;
-
-  my $path= "$testdir/$elem";
-
-  # ----------------------------------------------------------------------
-  # Skip some tests silently
-  # ----------------------------------------------------------------------
-
-  if ( $::opt_start_from and $tname lt $::opt_start_from )
-  {
-    return;
-  }
-
-
-  my $tinfo= {};
-  $tinfo->{'name'}= basename($suite) . ".$tname";
-  if ( -f "$resdir/$::opt_engine/$tname.result")
-  {
-    $tinfo->{'result_file'}= "$resdir/$::opt_engine/$tname.result";
-  }
-  else
-  {
-    $tinfo->{'result_file'}= "$resdir/$tname.result";
-  }
-  $tinfo->{'component_id'} = $component_id;
-  push(@$cases, $tinfo);
-
-  # ----------------------------------------------------------------------
-  # Skip some tests but include in list, just mark them to skip
-  # ----------------------------------------------------------------------
-
-  if ( $skip_test and $tname =~ /$skip_test/o )
-  {
-    $tinfo->{'skip'}= 1;
-    return;
-  }
-
-  # ----------------------------------------------------------------------
-  # Collect information about test case
-  # ----------------------------------------------------------------------
-
-  $tinfo->{'path'}= $path;
-  $tinfo->{'timezone'}= "GMT-3"; # for UNIX_TIMESTAMP tests to work
-
-  $tinfo->{'slave_num'}= 0; # Default, no slave
-  $tinfo->{'master_num'}= 1; # Default, 1 master
-  if ( defined mtr_match_prefix($tname,"rpl") )
-  {
-    if ( $::opt_skip_rpl )
-    {
-      $tinfo->{'skip'}= 1;
-      $tinfo->{'comment'}= "No replication tests(--skip-rpl)";
-      return;
-    }
-
-    $tinfo->{'slave_num'}= 1; # Default for rpl* tests, use one slave
-
-  }
-
-  if ( defined mtr_match_prefix($tname,"federated") )
-  {
-    # Default, federated uses the first slave as it's federated database
-    $tinfo->{'slave_num'}= 1;
-  }
-
-  my $global_master_opt_file= "$testdir/master.opt";
-  my $test_master_opt_file= "$testdir/$tname-master.opt";
-  my $slave_opt_file=  "$testdir/$tname-slave.opt";
-  my $slave_mi_file=   "$testdir/$tname.slave-mi";
-  my $master_sh=       "$testdir/$tname-master.sh";
-  my $slave_sh=        "$testdir/$tname-slave.sh";
-  my $disabled_file=   "$testdir/$tname.disabled";
-  my $im_opt_file=     "$testdir/$tname-im.opt";
-
-  $tinfo->{'master_opt'}= [];
-  $tinfo->{'slave_opt'}=  [];
-  $tinfo->{'slave_mi'}=   [];
-
-
-  # Add suite opts
-  foreach my $opt ( @$suite_opts )
-  {
-    mtr_verbose($opt);
-    push(@{$tinfo->{'master_opt'}}, $opt);
-    push(@{$tinfo->{'slave_opt'}}, $opt);
-  }
-
-  foreach  my $master_opt_file ($global_master_opt_file, $test_master_opt_file)
-  {
-    # Add master opts
-    if ( -f $master_opt_file )
-    {
-
-      my $master_opt= mtr_get_opts_from_file($master_opt_file);
-
-      foreach my $opt ( @$master_opt )
-      {
-        my $value;
-
-        # The opt file is used both to send special options to the mysqld
-        # as well as pass special test case specific options to this
-        # script
-
-        $value= mtr_match_prefix($opt, "--timezone=");
-        if ( defined $value )
-        {
-          $tinfo->{'timezone'}= $value;
-          next;
-        }
-
-        $value= mtr_match_prefix($opt, "--slave-num=");
-        if ( defined $value )
-        {
-          $tinfo->{'slave_num'}= $value;
-          next;
-        }
-
-        $value= mtr_match_prefix($opt, "--result-file=");
-        if ( defined $value )
-        {
-          # Specifies the file mysqltest should compare
-          # output against
-          if ( -f "r/$::opt_engine/$value.result")
-          {
-            $tinfo->{'result_file'}= "r/$::opt_engine/$value.result";
-          }
-          else
-          {
-            $tinfo->{'result_file'}= "r/$value.result";
-          }
-
-          next;
-        }
-
-        # If we set default time zone, remove the one we have
-        $value= mtr_match_prefix($opt, "--default-time-zone=");
-        if ( defined $value )
-        {
-          # Set timezone for this test case to something different
-          $tinfo->{'timezone'}= "GMT-8";
-          # Fallthrough, add the --default-time-zone option
-        }
-
-        # The --restart option forces a restart even if no special
-        # option is set. If the options are the same as next testcase
-        # there is no need to restart after the testcase
-        # has completed
-        if ( $opt eq "--force-restart" )
-        {
-          $tinfo->{'force_restart'}= 1;
-          next;
-        }
-
-        # Ok, this was a real option, add it
-        push(@{$tinfo->{'master_opt'}}, $opt);
-      }
-    }
-  }
-
-  # Add slave opts
-  if ( -f $slave_opt_file )
-  {
-    my $slave_opt= mtr_get_opts_from_file($slave_opt_file);
-
-    foreach my $opt ( @$slave_opt )
-    {
-      # If we set default time zone, remove the one we have
-      my $value= mtr_match_prefix($opt, "--default-time-zone=");
-      $tinfo->{'slave_opt'}= [] if defined $value;
-    }
-    push(@{$tinfo->{'slave_opt'}}, @$slave_opt);
-  }
-
-  if ( -f $slave_mi_file )
-  {
-    $tinfo->{'slave_mi'}= mtr_get_opts_from_file($slave_mi_file);
-  }
-
-  if ( -f $master_sh )
-  {
-    if ( $::glob_win32_perl )
-    {
-      $tinfo->{'skip'}= 1;
-      $tinfo->{'comment'}= "No tests with sh scripts on Windows";
-      return;
-    }
-    else
-    {
-      $tinfo->{'master_sh'}= $master_sh;
-    }
-  }
-
-  if ( -f $slave_sh )
-  {
-    if ( $::glob_win32_perl )
-    {
-      $tinfo->{'skip'}= 1;
-      $tinfo->{'comment'}= "No tests with sh scripts on Windows";
-      return;
-    }
-    else
-    {
-      $tinfo->{'slave_sh'}= $slave_sh;
-    }
-  }
-
-  if ( -f $im_opt_file )
-  {
-    $tinfo->{'im_opts'} = mtr_get_opts_from_file($im_opt_file);
-  }
-  else
-  {
-    $tinfo->{'im_opts'} = [];
-  }
-
-  # FIXME why this late?
-  my $marked_as_disabled= 0;
-  if ( $disabled->{$tname} )
-  {
-    $marked_as_disabled= 1;
-    $tinfo->{'comment'}= $disabled->{$tname};
-  }
-
-  if ( -f $disabled_file )
-  {
-    $marked_as_disabled= 1;
-    $tinfo->{'comment'}= mtr_fromfile($disabled_file);
-  }
-
-  # If test was marked as disabled, either opt_enable_disabled is off and then
-  # we skip this test, or it is on and then we run this test but warn
-
-  if ( $marked_as_disabled )
-  {
-    if ( $::opt_enable_disabled )
-    {
-      $tinfo->{'dont_skip_though_disabled'}= 1;
-    }
-    else
-    {
-      $tinfo->{'skip'}= 1;
-      $tinfo->{'disable'}= 1;   # Sub type of 'skip'
-      return;
-    }
-  }
-
-  if ( $component_id eq 'im' )
-  {
-    if ( $::glob_use_embedded_server )
-    {
-      $tinfo->{'skip'}= 1;
-      $tinfo->{'comment'}= "No IM with embedded server";
-      return;
-    }
-    elsif ( $::opt_ps_protocol )
-    {
-      $tinfo->{'skip'}= 1;
-      $tinfo->{'comment'}= "No IM with --ps-protocol";
-      return;
-    }
-    elsif ( $::opt_skip_im )
-    {
-      $tinfo->{'skip'}= 1;
-      $tinfo->{'comment'}= "No IM tests(--skip-im)";
-      return;
-    }
-  }
-  else
-  {
-    mtr_options_from_test_file($tinfo,"$testdir/${tname}.test");
-
-    if ( defined $::used_default_engine )
-    {
-      # Different default engine is used
-      # tag test to require that engine
-      $tinfo->{'ndb_test'}= 1
-	if ( $::used_default_engine =~ /^ndb/i );
-
-      $tinfo->{'innodb_test'}= 1
-	if ( $::used_default_engine =~ /^innodb/i );
-    }
-
-    if ( $tinfo->{'ndb_extra'} and ! $::opt_ndb_extra_test )
-    {
-      $tinfo->{'skip'}= 1;
-      $tinfo->{'comment'}= "Test need 'ndb_extra' option";
-      return;
-    }
-
-    if ( $tinfo->{'require_manager'} )
-    {
-      $tinfo->{'skip'}= 1;
-      $tinfo->{'comment'}= "Test need the _old_ manager(to be removed)";
-      return;
-    }
-
-    if ( $tinfo->{'need_debug'} && ! $::debug_compiled_binaries )
-    {
-      $tinfo->{'skip'}= 1;
-      $tinfo->{'comment'}= "Test need debug binaries";
-      return;
-    }
-  }
-}
-
-
-# List of tags in the .test files that if found should set
-# the specified value in "tinfo"
-our @tags=
-(
- ["include/have_innodb.inc", "innodb_test", 1],
- ["include/have_binlog_format_row.inc", "sup_binlog_formats", ["row"]],
- ["include/have_log_bin.inc", "need_binlog", 1],
- ["include/have_binlog_format_statement.inc",
-  "sup_binlog_formats", ["statement"]],
- ["include/have_binlog_format_mixed.inc", "sup_binlog_formats", ["mixed"]],
- ["include/have_binlog_format_mixed_or_row.inc",
-  "sup_binlog_formats", ["mixed","row"]],
- ["include/have_binlog_format_mixed_or_statement.inc",
-  "sup_binlog_formats", ["mixed","statement"]],
- ["include/have_binlog_format_row_or_statement.inc",
-  "sup_binlog_formats", ["row","statement"]],
- ["include/have_debug.inc", "need_debug", 1],
- ["require_manager", "require_manager", 1],
-);
-
-sub mtr_options_from_test_file($$) {
-  my $tinfo= shift;
-  my $file= shift;
-  #mtr_verbose("$file");
-  my $F= IO::File->new($file) or mtr_error("can't open file \"$file\": $!");
-
-  while ( my $line= <$F> )
-  {
-
-    # Skip line if it start's with #
-    next if ( $line =~ /^#/ );
-
-    # Match this line against tag in "tags" array
-    foreach my $tag (@tags)
-    {
-      if ( index($line, $tag->[0]) >= 0 )
-      {
-    	  # Tag matched, assign value to "tinfo"
-        $tinfo->{"$tag->[1]"}= $tag->[2];
-      }
-    }
-
-    # If test sources another file, open it as well
-    if ( $line =~ /^\-\-([[:space:]]*)source(.*)$/ or
-	 $line =~ /^([[:space:]]*)source(.*);$/ )
-    {
-      my $value= $2;
-      $value =~ s/^\s+//;  # Remove leading space
-      $value =~ s/[[:space:]]+$//;  # Remove ending space
-
-      my $sourced_file= "$::glob_mysql_test_dir/$value";
-      if ( -f $sourced_file )
-      {
-	# Only source the file if it exists, we may get
-	# false positives in the regexes above if someone
-	# writes "source nnnn;" in a test case(such as mysqltest.test)
-	mtr_options_from_test_file($tinfo, $sourced_file);
-      }
-    }
-  }
-}
-
-
-sub print_testcases {
-  my (@cases)= @_;
-
-  print "=" x 60, "\n";
-  foreach my $test (@cases){
-    print "[", $test->{name}, "]", "\n";
-    while ((my ($key, $value)) = each(%$test)) {
-      print " ", $key, "=";
-      if (ref $value eq "ARRAY") {
-	print join(", ", @$value);
-      } else {
-	print $value;
-      }
-      print "\n";
-    }
-    print "\n";
-  }
-  print "=" x 60, "\n";
-}
-
-
-1;

=== removed file 'tests/lib/mtr_diff.pl'
--- tests/lib/mtr_diff.pl	2008-06-25 05:29:13 +0000
+++ tests/lib/mtr_diff.pl	1970-01-01 00:00:00 +0000
@@ -1,297 +0,0 @@
-# -*- cperl -*-
-# Copyright (C) 2005 MySQL AB
-# 
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
-# 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-# This is a library file used by the Perl version of mysql-test-run,
-# and is part of the translation of the Bourne shell script with the
-# same name.
-
-#use Data::Dumper;
-use strict;
-
-# $Data::Dumper::Indent= 1;
-
-sub mtr_diff($$);
-
-##############################################################################
-#
-#  This is a simplified unified diff, with some special handling
-#  of unsorted result sets
-#
-##############################################################################
-
-# FIXME replace die with mtr_error
-
-#require "mtr_report.pl";
-#mtr_diff("a.txt","b.txt");
-
-sub mtr_diff ($$) {
-  my $file1 = shift;
-  my $file2 = shift;
-
-  # ----------------------------------------------------------------------
-  # We read in all of the files at once
-  # ----------------------------------------------------------------------
-
-  unless ( open(FILE1, $file1) )
-  {
-    mtr_warning("can't open \"$file1\": $!");
-    return;
-  }
-
-  unless ( open(FILE2, $file2) )
-  {
-    mtr_warning("can't open \"$file2\": $!");
-    return;
-  }
-
-  my $lines1= collect_lines(<FILE1>);
-  my $lines2= collect_lines(<FILE2>);
-  close FILE1;
-  close FILE2;
-
-#  print Dumper($lines1);
-#  print Dumper($lines2);
-
-  # ----------------------------------------------------------------------
-  # We compare line by line, but don't shift off elements until we know
-  # what to do. This way we use the "restart" method, do simple change
-  # and restart by entering the diff loop from the beginning again.
-  # ----------------------------------------------------------------------
-
-  my @context;
-  my @info;                     # Collect information, and output later
-  my $lno1= 1;
-  my $lno2= 1;
-
-  while ( @$lines1 or @$lines2 )
-  {
-    unless ( @$lines1 )
-    {
-      push(@info, map {['+',$lno1,$lno2++,$_]} @$lines2);
-      last;
-    }
-    unless ( @$lines2 )
-    {
-      push(@info, map {['-',$lno1++,$lno2,$_]} @$lines1);
-      last;
-    }
-
-    # ----------------------------------------------------------------------
-    # We know both have lines
-    # ----------------------------------------------------------------------
-
-    if ( $lines1->[0] eq $lines2->[0] )
-    {
-      # Simple case, first line match and all is well
-      push(@info, ['',$lno1++,$lno2++,$lines1->[0]]);
-      shift @$lines1;
-      shift @$lines2;
-      next;
-    }
-
-    # ----------------------------------------------------------------------
-    # Now, we know they differ
-    # ----------------------------------------------------------------------
-
-    # How far in the other one, is there a match?
-
-    my $idx2= find_next_match($lines1->[0], $lines2);
-    my $idx1= find_next_match($lines2->[0], $lines1);
-
-    # Here we could test "if ( !defined $idx2 or !defined $idx1 )" and
-    # use a more complicated diff algorithm in the case both contains
-    # each others lines, just dislocated. But for this application, there
-    # should be no need.
-
-    if ( !defined $idx2 )
-    {
-      push(@info, ['-',$lno1++,$lno2,$lines1->[0]]);
-      shift @$lines1;
-    }
-    else
-    {
-      push(@info, ['+',$lno1,$lno2++,$lines2->[0]]);
-      shift @$lines2;
-    }
-  }
-
-  # ----------------------------------------------------------------------
-  # Try to output nicely
-  # ----------------------------------------------------------------------
-
-#  print Dumper(\@info);
-
-  # We divide into "chunks" to output
-  # We want at least three lines of context
-
-  my @chunks;
-  my @chunk;
-  my $state= 'pre';          # 'pre', 'in' and 'post' difference
-  my $post_count= 0;
-
-  foreach my $info ( @info )
-  {
-    if ( $info->[0] eq '' and $state eq 'pre' )
-    {
-      # Collect no more than three lines of context before diff
-      push(@chunk, $info);
-      shift(@chunk) if @chunk > 3;
-      next;
-    }
-
-    if ( $info->[0] =~ /(\+|\-)/ and $state =~ /(pre|in)/ )
-    {
-      # Start/continue collecting diff
-      $state= 'in';
-      push(@chunk, $info);
-      next;
-    }
-
-    if ( $info->[0] eq '' and $state eq 'in' )
-    {
-      # Stop collecting diff, and collect context after diff
-      $state= 'post';
-      $post_count= 1;
-      push(@chunk, $info);
-      next;
-    }
-
-    if ( $info->[0] eq '' and $state eq 'post' and $post_count < 6 )
-    {
-      # We might find a new diff sequence soon, continue to collect
-      # non diffs but five up on 6.
-      $post_count++;
-      push(@chunk, $info);
-      next;
-    }
-
-    if ( $info->[0] eq '' and $state eq 'post' )
-    {
-      # We put an end to this, giving three non diff lines to
-      # the old chunk, and three to the new one.
-      my @left= splice(@chunk, -3, 3);
-      push(@chunks, [@chunk]);
-      $state= 'pre';
-      $post_count= 0;
-      @chunk= @left;
-      next;
-    }
-
-    if ( $info->[0] =~ /(\+|\-)/ and $state eq 'post' )
-    {
-      # We didn't split, continue collect diff
-      $state= 'in';
-      push(@chunk, $info);
-      next;
-    }
-
-  }
-
-  if ( $post_count > 3 )
-  {
-    $post_count -= 3;
-    splice(@chunk, -$post_count, $post_count);
-  }
-  push(@chunks, [@chunk]) if @chunk and $state ne 'pre';
-
-  foreach my $chunk ( @chunks )
-  {
-    my $from_file_start=  $chunk->[0]->[1];
-    my $to_file_start=    $chunk->[0]->[2];
-    my $from_file_offset= $chunk->[$#$chunk]->[1] - $from_file_start;
-    my $to_file_offset=   $chunk->[$#$chunk]->[2] - $to_file_start;
-    print "\@\@ -$from_file_start,$from_file_offset ",
-          "+$to_file_start,$to_file_offset \@\@\n";
-
-    foreach my $info ( @$chunk )
-    {
-      if ( $info->[0] eq '' )
-      {
-        print "  $info->[3]\n";
-      }
-      elsif ( $info->[0] eq '-' )
-      {
-        print "- $info->[3]\n";
-      }
-      elsif ( $info->[0] eq '+' )
-      {
-        print "+ $info->[3]\n";
-      }
-    }
-  }
-
-#  print Dumper(\@chunks);
-  
-}
-
-
-##############################################################################
-#  Find if the string is found in the array, return the index if found,
-#  if not found, return "undef"
-##############################################################################
-
-sub find_next_match {
-  my $line= shift;
-  my $lines= shift;
-
-  for ( my $idx= 0; $idx < @$lines; $idx++ )
-  {
-    return $idx if $lines->[$idx] eq $line;
-  }
-
-  return undef;                 # No match found
-}
-
-
-##############################################################################
-#  Just read the lines, but handle "sets" of lines that are unordered
-##############################################################################
-
-sub collect_lines {
-
-  my @recordset;
-  my @lines;
-
-  while (@_)
-  {
-    my $line= shift @_;
-    chomp($line);
-
-    if ( $line =~ /^\Q%unordered%\E\t/ )
-    {
-      push(@recordset, $line);
-    }
-    elsif ( @recordset )
-    {
-      push(@lines, sort @recordset);
-      @recordset= ();         # Clear it
-    }
-    else
-    {
-      push(@lines, $line);
-    }
-  }
-
-  if ( @recordset )
-  {
-    push(@lines, sort @recordset);
-    @recordset= ();         # Clear it
-  }
-
-  return \@lines;
-}
-
-1;

=== removed file 'tests/lib/mtr_gcov.pl'
--- tests/lib/mtr_gcov.pl	2009-12-01 17:50:17 +0000
+++ tests/lib/mtr_gcov.pl	1970-01-01 00:00:00 +0000
@@ -1,74 +0,0 @@
-# -*- cperl -*-
-# Copyright (C) 2004, 2006 MySQL AB
-# 
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
-# 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-# This is a library file used by the Perl version of mysql-test-run,
-# and is part of the translation of the Bourne shell script with the
-# same name.
-
-use strict;
-
-# These are not to be prefixed with "mtr_"
-
-sub gcov_prepare ();
-sub gcov_collect ();
-
-##############################################################################
-#
-#  
-#
-##############################################################################
-
-sub gcov_prepare () {
-
-  `find $::glob_basedir -name \*.gcov \
-    -or -name \*.da | xargs rm`;
-}
-
-# Used by gcov
-our @mysqld_src_dirs=
-  (
-   "strings",
-   "mysys",
-   "include",
-   "extra",
-   "regex",
-   "isam",
-   "merge",
-   "myisam",
-   "myisammrg",
-   "MEMORY",
-   "sql",
-  );
-
-sub gcov_collect () {
-
-  print "Collecting source coverage info...\n";
-  -f $::opt_gcov_msg and unlink($::opt_gcov_msg);
-  -f $::opt_gcov_err and unlink($::opt_gcov_err);
-  foreach my $d ( @mysqld_src_dirs )
-  {
-    chdir("$::glob_basedir/$d");
-    foreach my $f ( (glob("*.h"), glob("*.cc"), glob("*.c")) )
-    {
-      `$::opt_gcov $f 2>>$::opt_gcov_err  >>$::opt_gcov_msg`;
-    }
-    chdir($::glob_mysql_test_dir);
-  }
-  print "gcov info in $::opt_gcov_msg, errors in $::opt_gcov_err\n";
-}
-
-
-1;

=== removed file 'tests/lib/mtr_gprof.pl'
--- tests/lib/mtr_gprof.pl	2008-06-25 05:29:13 +0000
+++ tests/lib/mtr_gprof.pl	1970-01-01 00:00:00 +0000
@@ -1,64 +0,0 @@
-# -*- cperl -*-
-# Copyright (C) 2004 MySQL AB
-# 
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
-# 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-# This is a library file used by the Perl version of mysql-test-run,
-# and is part of the translation of the Bourne shell script with the
-# same name.
-
-use strict;
-
-# These are not to be prefixed with "mtr_"
-
-sub gprof_prepare ();
-sub gprof_collect ();
-
-##############################################################################
-#
-#  
-#
-##############################################################################
-
-sub gprof_prepare () {
-
-  rmtree($::opt_gprof_dir);
-  mkdir($::opt_gprof_dir);
-}
-
-# FIXME what about master1 and slave1?!
-sub gprof_collect () {
-
-  if ( -f "$::master->[0]->{'path_myddir'}/gmon.out" )
-  {
-    # FIXME check result code?!
-    mtr_run("gprof",
-            [$::exe_master_mysqld,
-             "$::master->[0]->{'path_myddir'}/gmon.out"],
-            $::opt_gprof_master, "", "", "");
-    print "Master execution profile has been saved in $::opt_gprof_master\n";
-  }
-  if ( -f "$::slave->[0]->{'path_myddir'}/gmon.out" )
-  {
-    # FIXME check result code?!
-    mtr_run("gprof",
-            [$::exe_slave_mysqld,
-             "$::slave->[0]->{'path_myddir'}/gmon.out"],
-            $::opt_gprof_slave, "", "", "");
-    print "Slave execution profile has been saved in $::opt_gprof_slave\n";
-  }
-}
-
-
-1;

=== removed file 'tests/lib/mtr_im.pl'
--- tests/lib/mtr_im.pl	2008-06-25 05:29:13 +0000
+++ tests/lib/mtr_im.pl	1970-01-01 00:00:00 +0000
@@ -1,775 +0,0 @@
-# -*- cperl -*-
-# Copyright (C) 2006 MySQL AB
-# 
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
-# 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-# This is a library file used by the Perl version of mysql-test-run,
-# and is part of the translation of the Bourne shell script with the
-# same name.
-
-use strict;
-
-# Private IM-related operations.
-
-sub mtr_im_kill_process ($$$$);
-sub mtr_im_load_pids ($);
-sub mtr_im_terminate ($);
-sub mtr_im_check_alive ($);
-sub mtr_im_check_main_alive ($);
-sub mtr_im_check_angel_alive ($);
-sub mtr_im_check_mysqlds_alive ($);
-sub mtr_im_check_mysqld_alive ($);
-sub mtr_im_cleanup ($);
-sub mtr_im_rm_file ($);
-sub mtr_im_errlog ($);
-sub mtr_im_kill ($);
-sub mtr_im_wait_for_connection ($$$);
-sub mtr_im_wait_for_mysqld($$$);
-
-# Public IM-related operations.
-
-sub mtr_im_start ($$);
-sub mtr_im_stop ($);
-
-##############################################################################
-#
-#  Private operations.
-#
-##############################################################################
-
-sub mtr_im_kill_process ($$$$) {
-  my $pid_lst= shift;
-  my $signal= shift;
-  my $total_retries= shift;
-  my $timeout= shift;
-
-  my %pids;
-
-  foreach my $pid ( @{$pid_lst} )
-  {
-    $pids{$pid}= 1;
-  }
-
-  for ( my $cur_attempt= 1; $cur_attempt <= $total_retries; ++$cur_attempt )
-  {
-    foreach my $pid ( keys %pids )
-    {
-      mtr_debug("Sending $signal to $pid...");
-
-      kill($signal, $pid);
-
-      unless ( kill (0, $pid) )
-      {
-        mtr_debug("Process $pid died.");
-        delete $pids{$pid};
-      }
-    }
-
-    return if scalar keys %pids == 0;
-
-    mtr_debug("Sleeping $timeout second(s) waiting for processes to die...");
-
-    sleep($timeout);
-  }
-
-  mtr_debug("Process(es) " .
-            join(' ', keys %pids) .
-            " is still alive after $total_retries " .
-            "of sending signal $signal.");
-}
-
-###########################################################################
-
-sub mtr_im_load_pids($) {
-  my $im= shift;
-
-  mtr_debug("Loading PID files...");
-
-  # Obtain mysqld-process pids.
-
-  my $instances = $im->{'instances'};
-
-  for ( my $idx= 0; $idx < 2; ++$idx )
-  {
-    mtr_debug("IM-guarded mysqld[$idx] PID file: '" .
-              $instances->[$idx]->{'path_pid'} . "'.");
-
-    my $mysqld_pid;
-
-    if ( -r $instances->[$idx]->{'path_pid'} )
-    {
-      $mysqld_pid= mtr_get_pid_from_file($instances->[$idx]->{'path_pid'});
-      mtr_debug("IM-guarded mysqld[$idx] PID: $mysqld_pid.");
-    }
-    else
-    {
-      $mysqld_pid= undef;
-      mtr_debug("IM-guarded mysqld[$idx]: no PID file.");
-    }
-
-    $instances->[$idx]->{'pid'}= $mysqld_pid;
-  }
-
-  # Re-read Instance Manager PIDs from the file, since during tests Instance
-  # Manager could have been restarted, so its PIDs could have been changed.
-
-  #   - IM-main
-
-  mtr_debug("IM-main PID file: '$im->{path_pid}'.");
-
-  if ( -f $im->{'path_pid'} )
-  {
-    $im->{'pid'} =
-      mtr_get_pid_from_file($im->{'path_pid'});
-
-    mtr_debug("IM-main PID: $im->{pid}.");
-  }
-  else
-  {
-    mtr_debug("IM-main: no PID file.");
-    $im->{'pid'}= undef;
-  }
-
-  #   - IM-angel
-
-  mtr_debug("IM-angel PID file: '$im->{path_angel_pid}'.");
-
-  if ( -f $im->{'path_angel_pid'} )
-  {
-    $im->{'angel_pid'} =
-      mtr_get_pid_from_file($im->{'path_angel_pid'});
-
-    mtr_debug("IM-angel PID: $im->{'angel_pid'}.");
-  }
-  else
-  {
-    mtr_debug("IM-angel: no PID file.");
-    $im->{'angel_pid'} = undef;
-  }
-}
-
-###########################################################################
-
-sub mtr_im_terminate($) {
-  my $im= shift;
-
-  # Load pids from pid-files. We should do it first of all, because IM deletes
-  # them on shutdown.
-
-  mtr_im_load_pids($im);
-
-  mtr_debug("Shutting Instance Manager down...");
-
-  # Ignoring SIGCHLD so that all children could rest in peace.
-
-  start_reap_all();
-
-  # Send SIGTERM to IM-main.
-
-  if ( defined $im->{'pid'} )
-  {
-    mtr_debug("IM-main pid: $im->{pid}.");
-    mtr_debug("Stopping IM-main...");
-
-    mtr_im_kill_process([ $im->{'pid'} ], 'TERM', 10, 1);
-  }
-  else
-  {
-    mtr_debug("IM-main pid: n/a.");
-  }
-
-  # If IM-angel was alive, wait for it to die.
-
-  if ( defined $im->{'angel_pid'} )
-  {
-    mtr_debug("IM-angel pid: $im->{'angel_pid'}.");
-    mtr_debug("Waiting for IM-angel to die...");
-
-    my $total_attempts= 10;
-
-    for ( my $cur_attempt=1; $cur_attempt <= $total_attempts; ++$cur_attempt )
-    {
-      unless ( kill (0, $im->{'angel_pid'}) )
-      {
-        mtr_debug("IM-angel died.");
-        last;
-      }
-
-      sleep(1);
-    }
-  }
-  else
-  {
-    mtr_debug("IM-angel pid: n/a.");
-  }
-
-  stop_reap_all();
-
-  # Re-load PIDs.
-
-  mtr_im_load_pids($im);
-}
-
-###########################################################################
-
-sub mtr_im_check_alive($) {
-  my $im= shift;
-
-  mtr_debug("Checking whether IM-components are alive...");
-
-  return 1 if mtr_im_check_main_alive($im);
-
-  return 1 if mtr_im_check_angel_alive($im);
-
-  return 1 if mtr_im_check_mysqlds_alive($im);
-
-  return 0;
-}
-
-###########################################################################
-
-sub mtr_im_check_main_alive($) {
-  my $im= shift;
-
-  # Check that the process, that we know to be IM's, is dead.
-
-  if ( defined $im->{'pid'} )
-  {
-    if ( kill (0, $im->{'pid'}) )
-    {
-      mtr_debug("IM-main (PID: $im->{pid}) is alive.");
-      return 1;
-    }
-    else
-    {
-      mtr_debug("IM-main (PID: $im->{pid}) is dead.");
-    }
-  }
-  else
-  {
-    mtr_debug("No PID file for IM-main.");
-  }
-
-  # Check that IM does not accept client connections.
-
-  if ( mtr_ping_port($im->{'port'}) )
-  {
-    mtr_debug("IM-main (port: $im->{port}) " .
-              "is accepting connections.");
-
-    mtr_im_errlog("IM-main is accepting connections on port " .
-                  "$im->{port}, but there is no " .
-                  "process information.");
-    return 1;
-  }
-  else
-  {
-    mtr_debug("IM-main (port: $im->{port}) " .
-              "does not accept connections.");
-    return 0;
-  }
-}
-
-###########################################################################
-
-sub mtr_im_check_angel_alive($) {
-  my $im= shift;
-
-  # Check that the process, that we know to be the Angel, is dead.
-
-  if ( defined $im->{'angel_pid'} )
-  {
-    if ( kill (0, $im->{'angel_pid'}) )
-    {
-      mtr_debug("IM-angel (PID: $im->{angel_pid}) is alive.");
-      return 1;
-    }
-    else
-    {
-      mtr_debug("IM-angel (PID: $im->{angel_pid}) is dead.");
-      return 0;
-    }
-  }
-  else
-  {
-    mtr_debug("No PID file for IM-angel.");
-    return 0;
-  }
-}
-
-###########################################################################
-
-sub mtr_im_check_mysqlds_alive($) {
-  my $im= shift;
-
-  mtr_debug("Checking for IM-guarded mysqld instances...");
-
-  my $instances = $im->{'instances'};
-
-  for ( my $idx= 0; $idx < 2; ++$idx )
-  {
-    mtr_debug("Checking mysqld[$idx]...");
-
-    return 1
-      if mtr_im_check_mysqld_alive($instances->[$idx]);
-  }
-}
-
-###########################################################################
-
-sub mtr_im_check_mysqld_alive($) {
-  my $mysqld_instance= shift;
-
-  # Check that the process is dead.
-
-  if ( defined $mysqld_instance->{'pid'} )
-  {
-    if ( kill (0, $mysqld_instance->{'pid'}) )
-    {
-      mtr_debug("Mysqld instance (PID: $mysqld_instance->{pid}) is alive.");
-      return 1;
-    }
-    else
-    {
-      mtr_debug("Mysqld instance (PID: $mysqld_instance->{pid}) is dead.");
-    }
-  }
-  else
-  {
-    mtr_debug("No PID file for mysqld instance.");
-  }
-
-  # Check that mysqld does not accept client connections.
-
-  if ( mtr_ping_port($mysqld_instance->{'port'}) )
-  {
-    mtr_debug("Mysqld instance (port: $mysqld_instance->{port}) " .
-              "is accepting connections.");
-
-    mtr_im_errlog("Mysqld is accepting connections on port " .
-                  "$mysqld_instance->{port}, but there is no " .
-                  "process information.");
-    return 1;
-  }
-  else
-  {
-    mtr_debug("Mysqld instance (port: $mysqld_instance->{port}) " .
-              "does not accept connections.");
-    return 0;
-  }
-}
-
-###########################################################################
-
-sub mtr_im_cleanup($) {
-  my $im= shift;
-
-  mtr_im_rm_file($im->{'path_pid'});
-  mtr_im_rm_file($im->{'path_sock'});
-
-  mtr_im_rm_file($im->{'path_angel_pid'});
-
-  for ( my $idx= 0; $idx < 2; ++$idx )
-  {
-    mtr_im_rm_file($im->{'instances'}->[$idx]->{'path_pid'});
-    mtr_im_rm_file($im->{'instances'}->[$idx]->{'path_sock'});
-  }
-}
-
-###########################################################################
-
-sub mtr_im_rm_file($)
-{
-  my $file_path= shift;
-
-  if ( -f $file_path )
-  {
-    mtr_debug("Removing '$file_path'...");
-
-    unless ( unlink($file_path) )
-    {
-      mtr_warning("Can not remove '$file_path'.")
-    }
-  }
-  else
-  {
-    mtr_debug("File '$file_path' does not exist already.");
-  }
-}
-
-###########################################################################
-
-sub mtr_im_errlog($) {
-  my $msg= shift;
-
-  # Complain in error log so that a warning will be shown.
-  # 
-  # TODO: unless BUG#20761 is fixed, we will print the warning to stdout, so
-  # that it can be seen on console and does not produce pushbuild error.
-
-  # my $errlog= "$opt_vardir/log/mysql-test-run.pl.err";
-  # 
-  # open (ERRLOG, ">>$errlog") ||
-  #   mtr_error("Can not open error log ($errlog)");
-  # 
-  # my $ts= localtime();
-  # print ERRLOG
-  #   "Warning: [$ts] $msg\n";
-  # 
-  # close ERRLOG;
-
-  my $ts= localtime();
-  print "Warning: [$ts] $msg\n";
-}
-
-###########################################################################
-
-sub mtr_im_kill($) {
-  my $im= shift;
-
-  # Re-load PIDs. That can be useful because some processes could have been
-  # restarted.
-
-  mtr_im_load_pids($im);
-
-  # Ignoring SIGCHLD so that all children could rest in peace.
-
-  start_reap_all();
-
-  # Kill IM-angel first of all.
-
-  if ( defined $im->{'angel_pid'} )
-  {
-    mtr_debug("Killing IM-angel (PID: $im->{angel_pid})...");
-    mtr_im_kill_process([ $im->{'angel_pid'} ], 'KILL', 10, 1)
-  }
-  else
-  {
-    mtr_debug("IM-angel is dead.");
-  }
-
-  # Re-load PIDs again.
-
-  mtr_im_load_pids($im);
-
-  # Kill IM-main.
-  
-  if ( defined $im->{'pid'} )
-  {
-    mtr_debug("Killing IM-main (PID: $im->pid})...");
-    mtr_im_kill_process([ $im->{'pid'} ], 'KILL', 10, 1);
-  }
-  else
-  {
-    mtr_debug("IM-main is dead.");
-  }
-
-  # Re-load PIDs again.
-
-  mtr_im_load_pids($im);
-
-  # Kill guarded mysqld instances.
-
-  my @mysqld_pids;
-
-  mtr_debug("Collecting PIDs of mysqld instances to kill...");
-
-  for ( my $idx= 0; $idx < 2; ++$idx )
-  {
-    my $pid= $im->{'instances'}->[$idx]->{'pid'};
-
-    unless ( defined $pid )
-    {
-      next;
-    }
-
-    mtr_debug("  - IM-guarded mysqld[$idx] PID: $pid.");
-
-    push (@mysqld_pids, $pid);
-  }
-
-  if ( scalar @mysqld_pids > 0 )
-  {
-    mtr_debug("Killing IM-guarded mysqld instances...");
-    mtr_im_kill_process(\@mysqld_pids, 'KILL', 10, 1);
-  }
-
-  # That's all.
-
-  stop_reap_all();
-}
-
-##############################################################################
-
-sub mtr_im_wait_for_connection($$$) {
-  my $im= shift;
-  my $total_attempts= shift;
-  my $connect_timeout= shift;
-
-  mtr_debug("Waiting for IM on port $im->{port} " .
-            "to start accepting connections...");
-
-  for ( my $cur_attempt= 1; $cur_attempt <= $total_attempts; ++$cur_attempt )
-  {
-    mtr_debug("Trying to connect to IM ($cur_attempt of $total_attempts)...");
-
-    if ( mtr_ping_port($im->{'port'}) )
-    {
-      mtr_debug("IM is accepting connections " .
-                "on port $im->{port}.");
-      return 1;
-    }
-
-    mtr_debug("Sleeping $connect_timeout...");
-    sleep($connect_timeout);
-  }
-
-  mtr_debug("IM does not accept connections " .
-            "on port $im->{port} after " .
-            ($total_attempts * $connect_timeout) . " seconds.");
-
-  return 0;
-}
-
-##############################################################################
-
-sub mtr_im_wait_for_mysqld($$$) {
-  my $mysqld= shift;
-  my $total_attempts= shift;
-  my $connect_timeout= shift;
-
-  mtr_debug("Waiting for IM-guarded mysqld on port $mysqld->{port} " .
-            "to start accepting connections...");
-
-  for ( my $cur_attempt= 1; $cur_attempt <= $total_attempts; ++$cur_attempt )
-  {
-    mtr_debug("Trying to connect to mysqld " .
-              "($cur_attempt of $total_attempts)...");
-
-    if ( mtr_ping_port($mysqld->{'port'}) )
-    {
-      mtr_debug("Mysqld is accepting connections " .
-                "on port $mysqld->{port}.");
-      return 1;
-    }
-
-    mtr_debug("Sleeping $connect_timeout...");
-    sleep($connect_timeout);
-  }
-
-  mtr_debug("Mysqld does not accept connections " .
-            "on port $mysqld->{port} after " .
-            ($total_attempts * $connect_timeout) . " seconds.");
-
-  return 0;
-}
-
-##############################################################################
-#
-#  Public operations.
-#
-##############################################################################
-
-sub mtr_im_start($$) {
-  my $im = shift;
-  my $opts = shift;
-
-  mtr_debug("Starting Instance Manager...");
-
-  my $args;
-  mtr_init_args(\$args);
-  mtr_add_arg($args, "--defaults-file=%s", $im->{'defaults_file'});
-
-  foreach my $opt ( @{$opts} )
-  {
-    mtr_add_arg($args, $opt);
-  }
-
-  $im->{'spawner_pid'} =
-    mtr_spawn(
-      $::exe_im,                        # path to the executable
-      $args,                            # cmd-line args
-      '',                               # stdin
-      $im->{'path_log'},                # stdout
-      $im->{'path_err'},                # stderr
-      '',                               # pid file path (not used)
-      { append_log_file => 1 }          # append log files
-      );
-
-  unless ( $im->{'spawner_pid'} )
-  {
-    mtr_error('Could not start Instance Manager.')
-  }
-
-  # Instance Manager can be run in daemon mode. In this case, it creates
-  # several processes and the parent process, created by mtr_spawn(), exits just
-  # after start. So, we have to obtain Instance Manager PID from the PID file.
-
-  mtr_debug("Waiting for IM to create PID file (" .
-            "path: '$im->{path_pid}'; " .
-            "timeout: $im->{start_timeout})...");
-
-  unless ( sleep_until_file_created($im->{'path_pid'},
-                                    $im->{'start_timeout'},
-                                    -1) ) # real PID is still unknown
-  {
-    mtr_debug("IM has not created PID file in $im->{start_timeout} secs.");
-    mtr_debug("Aborting test suite...");
-
-    mtr_kill_leftovers();
-
-    mtr_report("IM has not created PID file in $im->{start_timeout} secs.");
-    return 0;
-  }
-
-  $im->{'pid'}= mtr_get_pid_from_file($im->{'path_pid'});
-
-  mtr_debug("Instance Manager started. PID: $im->{pid}.");
-
-  # Wait until we can connect to IM.
-
-  my $IM_CONNECT_TIMEOUT= 30;
-
-  unless ( mtr_im_wait_for_connection($im,
-                                      $IM_CONNECT_TIMEOUT, 1) )
-  {
-    mtr_debug("Can not connect to Instance Manager " .
-              "in $IM_CONNECT_TIMEOUT seconds after start.");
-    mtr_debug("Aborting test suite...");
-
-    mtr_kill_leftovers();
-
-    mtr_report("Can not connect to Instance Manager " .
-               "in $IM_CONNECT_TIMEOUT seconds after start.");
-    return 0;
-  }
-
-  # Wait for IM to start guarded instances:
-  #   - wait for PID files;
-
-  mtr_debug("Waiting for guarded mysqlds instances to create PID files...");
-
-  for ( my $idx= 0; $idx < 2; ++$idx )
-  {
-    my $mysqld= $im->{'instances'}->[$idx];
-
-    if ( exists $mysqld->{'nonguarded'} )
-    {
-      next;
-    }
-
-    mtr_debug("Waiting for mysqld[$idx] to create PID file (" .
-              "path: '$mysqld->{path_pid}'; " .
-              "timeout: $mysqld->{start_timeout})...");
-
-    unless ( sleep_until_file_created($mysqld->{'path_pid'},
-                                      $mysqld->{'start_timeout'},
-                                      -1) ) # real PID is still unknown
-    {
-      mtr_debug("mysqld[$idx] has not created PID file in " .
-                 "$mysqld->{start_timeout} secs.");
-      mtr_debug("Aborting test suite...");
-
-      mtr_kill_leftovers();
-
-      mtr_report("mysqld[$idx] has not created PID file in " .
-                 "$mysqld->{start_timeout} secs.");
-      return 0;
-    }
-
-    mtr_debug("PID file for mysqld[$idx] ($mysqld->{path_pid} created.");
-  }
-
-  # Wait until we can connect to guarded mysqld-instances
-  # (in other words -- wait for IM to start guarded instances).
-
-  mtr_debug("Waiting for guarded mysqlds to start accepting connections...");
-
-  for ( my $idx= 0; $idx < 2; ++$idx )
-  {
-    my $mysqld= $im->{'instances'}->[$idx];
-
-    if ( exists $mysqld->{'nonguarded'} )
-    {
-      next;
-    }
-
-    mtr_debug("Waiting for mysqld[$idx] to accept connection...");
-
-    unless ( mtr_im_wait_for_mysqld($mysqld, 30, 1) )
-    {
-      mtr_debug("Can not connect to mysqld[$idx] " .
-                "in $IM_CONNECT_TIMEOUT seconds after start.");
-      mtr_debug("Aborting test suite...");
-
-      mtr_kill_leftovers();
-
-      mtr_report("Can not connect to mysqld[$idx] " .
-                 "in $IM_CONNECT_TIMEOUT seconds after start.");
-      return 0;
-    }
-
-    mtr_debug("mysqld[$idx] started.");
-  }
-
-  mtr_debug("Instance Manager and its components are up and running.");
-
-  return 1;
-}
-
-##############################################################################
-
-sub mtr_im_stop($) {
-  my $im= shift;
-
-  mtr_debug("Stopping Instance Manager...");
-
-  # Try graceful shutdown.
-
-  mtr_im_terminate($im);
-
-  # Check that all processes died.
-
-  unless ( mtr_im_check_alive($im) )
-  {
-    mtr_debug("Instance Manager has been stopped successfully.");
-    mtr_im_cleanup($im);
-    return 1;
-  }
-
-  # Instance Manager don't want to die. We should kill it.
-
-  mtr_im_errlog("Instance Manager did not shutdown gracefully.");
-
-  mtr_im_kill($im);
-
-  # Check again that all IM-related processes have been killed.
-
-  my $im_is_alive= mtr_im_check_alive($im);
-
-  mtr_im_cleanup($im);
-
-  if ( $im_is_alive )
-  {
-    mtr_debug("Can not kill Instance Manager or its children.");
-    return 0;
-  }
-
-  mtr_debug("Instance Manager has been killed successfully.");
-  return 1;
-}
-
-###########################################################################
-
-1;

=== removed file 'tests/lib/mtr_io.pl'
--- tests/lib/mtr_io.pl	2008-06-25 05:29:13 +0000
+++ tests/lib/mtr_io.pl	1970-01-01 00:00:00 +0000
@@ -1,218 +0,0 @@
-# -*- cperl -*-
-# Copyright (C) 2004-2006 MySQL AB
-# 
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
-# 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-# This is a library file used by the Perl version of mysql-test-run,
-# and is part of the translation of the Bourne shell script with the
-# same name.
-
-use strict;
-
-sub mtr_get_pid_from_file ($);
-sub mtr_get_opts_from_file ($);
-sub mtr_fromfile ($);
-sub mtr_tofile ($@);
-sub mtr_tonewfile($@);
-sub mtr_lastlinefromfile($);
-sub mtr_appendfile_to_file ($$);
-sub mtr_grab_file($);
-
-
-##############################################################################
-#
-#  
-#
-##############################################################################
-
-sub mtr_get_pid_from_file ($) {
-  my $pid_file_path=  shift;
-  my $TOTAL_ATTEMPTS= 30;
-  my $timeout= 1;
-
-  # We should read from the file until we get correct pid. As it is
-  # stated in BUG#21884, pid file can be empty at some moment. So, we should
-  # read it until we get valid data.
-
-  for (my $cur_attempt= 1; $cur_attempt <= $TOTAL_ATTEMPTS; ++$cur_attempt)
-  {
-    mtr_debug("Reading pid file '$pid_file_path' " .
-              "($cur_attempt of $TOTAL_ATTEMPTS)...");
-
-    open(FILE, '<', $pid_file_path)
-      or mtr_error("can't open file \"$pid_file_path\": $!");
-
-    # Read pid number from file
-    my $pid= <FILE>;
-    chomp $pid;
-    close FILE;
-
-    return $pid if $pid=~ /^(\d+)/;
-
-    mtr_debug("Pid file '$pid_file_path' does not yet contain pid number.\n" .
-              "Sleeping $timeout second(s) more...");
-
-    sleep($timeout);
-  }
-
-  mtr_error("Pid file '$pid_file_path' is corrupted. " .
-            "Can not retrieve PID in " .
-            ($timeout * $TOTAL_ATTEMPTS) . " seconds.");
-}
-
-sub mtr_get_opts_from_file ($) {
-  my $file=  shift;
-
-  open(FILE,"<",$file) or mtr_error("can't open file \"$file\": $!");
-  my @args;
-  while ( <FILE> )
-  {
-    chomp;
-
-    #    --set-variable=init_connect=set @a='a\\0c'
-    s/^\s+//;                           # Remove leading space
-    s/\s+$//;                           # Remove ending space
-
-    # This is strange, but we need to fill whitespace inside
-    # quotes with something, to remove later. We do this to
-    # be able to split on space. Else, we have trouble with
-    # options like 
-    #
-    #   --someopt="--insideopt1 --insideopt2"
-    #
-    # But still with this, we are not 100% sure it is right,
-    # we need a shell to do it right.
-
-#    print STDERR "\n";
-#    print STDERR "AAA: $_\n";
-
-    s/\'([^\'\"]*)\'/unspace($1,"\x0a")/ge;
-    s/\"([^\'\"]*)\"/unspace($1,"\x0b")/ge;
-    s/\'([^\'\"]*)\'/unspace($1,"\x0a")/ge;
-    s/\"([^\'\"]*)\"/unspace($1,"\x0b")/ge;
-
-#    print STDERR "BBB: $_\n";
-
-#    foreach my $arg (/(--?\w.*?)(?=\s+--?\w|$)/)
-
-    # FIXME ENV vars should be expanded!!!!
-
-    foreach my $arg (split(/[ \t]+/))
-    {
-      $arg =~ tr/\x11\x0a\x0b/ \'\"/;     # Put back real chars
-      # The outermost quotes has to go
-      $arg =~ s/^([^\'\"]*)\'(.*)\'([^\'\"]*)$/$1$2$3/
-        or $arg =~ s/^([^\'\"]*)\"(.*)\"([^\'\"]*)$/$1$2$3/;
-      $arg =~ s/\\\\/\\/g;
-
-      $arg =~ s/\$\{(\w+)\}/envsubst($1)/ge;
-      $arg =~ s/\$(\w+)/envsubst($1)/ge;
-
-#      print STDERR "ARG: $arg\n";
-      # Do not pass empty string since my_getopt is not capable to handle it.
-      if (length($arg))
-      {
-        push(@args, $arg)
-      }
-    }
-  }
-  close FILE;
-  return \@args;
-}
-
-sub envsubst {
-  my $string= shift;
-
-  if ( ! defined $ENV{$string} )
-  {
-    mtr_error("opt file referense \$$string that is unknown");
-  }
-
-  return $ENV{$string};
-}
-
-sub unspace {
-  my $string= shift;
-  my $quote=  shift;
-  $string =~ s/[ \t]/\x11/g;
-  return "$quote$string$quote";
-}
-
-# Read a whole file, stripping leading and trailing whitespace.
-sub mtr_fromfile ($) {
-  my $file=  shift;
-
-  open(FILE,"<",$file) or mtr_error("can't open file \"$file\": $!");
-  my $text= join('', <FILE>);
-  close FILE;
-  $text =~ s/^\s+//;                    # Remove starting space, incl newlines
-  $text =~ s/\s+$//;                    # Remove ending space, incl newlines
-  return $text;
-}
-
-sub mtr_lastlinefromfile ($) {
-  my $file=  shift;
-  my $text;
-
-  open(FILE,"<",$file) or mtr_error("can't open file \"$file\": $!");
-  while (my $line= <FILE>)
-  {
-    $text= $line;
-  }
-  close FILE;
-  return $text;
-}
-
-
-sub mtr_tofile ($@) {
-  my $file=  shift;
-
-  open(FILE,">>",$file) or mtr_error("can't open file \"$file\": $!");
-  print FILE join("", @_);
-  close FILE;
-}
-
-sub mtr_tonewfile ($@) {
-  my $file=  shift;
-
-  open(FILE,">",$file) or mtr_error("can't open file \"$file\": $!");
-  print FILE join("", @_);
-  close FILE;
-}
-
-sub mtr_appendfile_to_file ($$) {
-  my $from_file=  shift;
-  my $to_file=  shift;
-
-  open(TOFILE,">>",$to_file) or mtr_error("can't open file \"$to_file\": $!");
-  open(FROMFILE,"<",$from_file)
-    or mtr_error("can't open file \"$from_file\": $!");
-  print TOFILE while (<FROMFILE>);
-  close FROMFILE;
-  close TOFILE;
-}
-
-# Read a whole file verbatim.
-sub mtr_grab_file($) {
-  my $file= shift;
-  open(FILE, '<', $file)
-    or return undef;
-  local $/= undef;
-  my $data= scalar(<FILE>);
-  close FILE;
-  return $data;
-}
-
-
-1;

=== removed file 'tests/lib/mtr_match.pl'
--- tests/lib/mtr_match.pl	2008-06-25 05:29:13 +0000
+++ tests/lib/mtr_match.pl	1970-01-01 00:00:00 +0000
@@ -1,98 +0,0 @@
-# -*- cperl -*-
-# Copyright (C) 2004-2006 MySQL AB
-# 
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
-# 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-# This is a library file used by the Perl version of mysql-test-run,
-# and is part of the translation of the Bourne shell script with the
-# same name.
-
-use strict;
-
-sub mtr_match_prefix ($$);
-sub mtr_match_extension ($$);
-sub mtr_match_any_exact ($$);
-
-##############################################################################
-#
-#  
-#
-##############################################################################
-
-# Match a prefix and return what is after the prefix
-
-sub mtr_match_prefix ($$) {
-  my $string= shift;
-  my $prefix= shift;
-
-  if ( $string =~ /^\Q$prefix\E(.*)$/ ) # strncmp
-  {
-    return $1;
-  }
-  else
-  {
-    return undef;		# NULL
-  }
-}
-
-
-# Match extension and return the name without extension
-
-sub mtr_match_extension ($$) {
-  my $file= shift;
-  my $ext=  shift;
-
-  if ( $file =~ /^(.*)\.\Q$ext\E$/ ) # strchr+strcmp or something
-  {
-    return $1;
-  }
-  else
-  {
-    return undef;                       # NULL
-  }
-}
-
-
-# Match a substring anywere in a string
-
-sub mtr_match_substring ($$) {
-  my $string= shift;
-  my $substring= shift;
-
-  if ( $string =~ /(.*)\Q$substring\E(.*)$/ ) # strncmp
-  {
-    return $1;
-  }
-  else
-  {
-    return undef;		# NULL
-  }
-}
-
-
-sub mtr_match_any_exact ($$) {
-  my $string= shift;
-  my $mlist=  shift;
-
-  foreach my $m (@$mlist)
-  {
-    if ( $string eq $m )
-    {
-      return 1;
-    }
-  }
-  return 0;
-}
-
-1;

=== removed file 'tests/lib/mtr_misc.pl'
--- tests/lib/mtr_misc.pl	2008-06-25 05:29:13 +0000
+++ tests/lib/mtr_misc.pl	1970-01-01 00:00:00 +0000
@@ -1,312 +0,0 @@
-# -*- cperl -*-
-# Copyright (C) 2004-2006 MySQL AB
-# 
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
-# 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-# This is a library file used by the Perl version of mysql-test-run,
-# and is part of the translation of the Bourne shell script with the
-# same name.
-
-use strict;
-use File::Find;
-
-sub mtr_native_path($);
-sub mtr_init_args ($);
-sub mtr_add_arg ($$@);
-sub mtr_path_exists(@);
-sub mtr_script_exists(@);
-sub mtr_file_exists(@);
-sub mtr_exe_exists(@);
-sub mtr_exe_maybe_exists(@);
-sub mtr_copy_dir($$);
-sub mtr_rmtree($);
-sub mtr_same_opts($$);
-sub mtr_cmp_opts($$);
-
-##############################################################################
-#
-#  Misc
-#
-##############################################################################
-
-# Convert path to OS native format
-sub mtr_native_path($)
-{
-  my $path= shift;
-
-  # MySQL version before 5.0 still use cygwin, no need
-  # to convert path
-  return $path
-    if ($::mysql_version_id < 50000);
-
-  $path=~ s/\//\\/g
-    if ($::glob_win32);
-  return $path;
-}
-
-
-# FIXME move to own lib
-
-sub mtr_init_args ($) {
-  my $args = shift;
-  $$args = [];                            # Empty list
-}
-
-sub mtr_add_arg ($$@) {
-  my $args=   shift;
-  my $format= shift;
-  my @fargs = @_;
-
-  push(@$args, sprintf($format, @fargs));
-}
-
-##############################################################################
-
-#
-# NOTE! More specific paths should be given before less specific.
-# For example /client/debug should be listed before /client
-#
-sub mtr_path_exists (@) {
-  foreach my $path ( @_ )
-  {
-    return $path if -e $path;
-  }
-  if ( @_ == 1 )
-  {
-    mtr_error("Could not find $_[0]");
-  }
-  else
-  {
-    mtr_error("Could not find any of " . join(" ", @_));
-  }
-}
-
-
-#
-# NOTE! More specific paths should be given before less specific.
-# For example /client/debug should be listed before /client
-#
-sub mtr_script_exists (@) {
-  foreach my $path ( @_ )
-  {
-    if($::glob_win32)
-    {
-      return $path if -f $path;
-    }
-    else
-    {
-      return $path if -x $path;
-    }
-  }
-  if ( @_ == 1 )
-  {
-    mtr_error("Could not find $_[0]");
-  }
-  else
-  {
-    mtr_error("Could not find any of " . join(" ", @_));
-  }
-}
-
-
-#
-# NOTE! More specific paths should be given before less specific.
-# For example /client/debug should be listed before /client
-#
-sub mtr_file_exists (@) {
-  foreach my $path ( @_ )
-  {
-    return $path if -e $path;
-  }
-  return "";
-}
-
-
-#
-# NOTE! More specific paths should be given before less specific.
-# For example /client/debug should be listed before /client
-#
-sub mtr_exe_maybe_exists (@) {
-  my @path= @_;
-
-  map {$_.= ".exe"} @path if $::glob_win32;
-  map {$_.= ".nlm"} @path if $::glob_netware;
-  foreach my $path ( @path )
-  {
-    if($::glob_win32)
-    {
-      return $path if -f $path;
-    }
-    else
-    {
-      return $path if -x $path;
-    }
-  }
-  return "";
-}
-
-
-#
-# NOTE! More specific paths should be given before less specific.
-# For example /client/debug should be listed before /client
-#
-sub mtr_exe_exists (@) {
-  my @path= @_;
-  if (my $path= mtr_exe_maybe_exists(@path))
-  {
-    return $path;
-  }
-  # Could not find exe, show error
-  if ( @path == 1 )
-  {
-    mtr_error("Could not find $path[0]");
-  }
-  else
-  {
-    mtr_error("Could not find any of " . join(" ", @path));
-  }
-}
-
-
-sub mtr_copy_dir($$) {
-  my $from_dir= shift;
-  my $to_dir= shift;
-
-  # mtr_verbose("Copying from $from_dir to $to_dir");
-
-  mkpath("$to_dir");
-  opendir(DIR, "$from_dir")
-    or mtr_error("Can't find $from_dir$!");
-  for(readdir(DIR)) {
-    next if "$_" eq "." or "$_" eq "..";
-    if ( -d "$from_dir/$_" )
-    {
-      mtr_copy_dir("$from_dir/$_", "$to_dir/$_");
-      next;
-    }
-    copy("$from_dir/$_", "$to_dir/$_");
-  }
-  closedir(DIR);
-
-}
-
-
-sub mtr_rmtree($) {
-  my ($dir)= @_;
-  mtr_verbose("mtr_rmtree: $dir");
-
-  # Try to use File::Path::rmtree. Recent versions
-  # handles removal of directories and files that don't
-  # have full permissions, while older versions
-  # may have a problem with that and we use our own version
-
-  eval { rmtree($dir); };
-  if ( $@ ) {
-    mtr_warning("rmtree($dir) failed, trying with File::Find...");
-
-    my $errors= 0;
-
-    # chmod
-    find( {
-	   no_chdir => 1,
-	   wanted => sub {
-	     chmod(0777, $_)
-	       or mtr_warning("couldn't chmod(0777, $_): $!") and $errors++;
-	   }
-	  },
-	  $dir
-	);
-
-    # rm
-    finddepth( {
-	   no_chdir => 1,
-	   wanted => sub {
-	     my $file= $_;
-	     # Use special underscore (_) filehandle, caches stat info
-	     if (!-l $file and -d _ ) {
-	       rmdir($file) or
-		 mtr_warning("couldn't rmdir($file): $!") and $errors++;
-	     } else {
-	       unlink($file)
-		 or mtr_warning("couldn't unlink($file): $!") and $errors++;
-	     }
-	   }
-	  },
-	  $dir
-	);
-
-    mtr_error("Failed to remove '$dir'") if $errors;
-
-    mtr_report("OK, that worked!");
-  }
-}
-
-
-sub mtr_same_opts ($$) {
-  my $l1= shift;
-  my $l2= shift;
-  return mtr_cmp_opts($l1,$l2) == 0;
-}
-
-sub mtr_cmp_opts ($$) {
-  my $l1= shift;
-  my $l2= shift;
-
-  my @l1= @$l1;
-  my @l2= @$l2;
-
-  return -1 if @l1 < @l2;
-  return  1 if @l1 > @l2;
-
-  while ( @l1 )                         # Same length
-  {
-    my $e1= shift @l1;
-    my $e2= shift @l2;
-    my $cmp= ($e1 cmp $e2);
-    return $cmp if $cmp != 0;
-  }
-
-  return 0;                             # They are the same
-}
-
-#
-# Compare two arrays and put all unequal elements into a new one
-#
-sub mtr_diff_opts ($$) {
-  my $l1= shift;
-  my $l2= shift;
-  my $f;
-  my $l= [];
-  foreach my $e1 (@$l1) 
-  {    
-    $f= undef;
-    foreach my $e2 (@$l2) 
-    {
-      $f= 1 unless ($e1 ne $e2);
-    }
-    push(@$l, $e1) unless (defined $f);
-  }
-  foreach my $e2 (@$l2) 
-  {
-    $f= undef;
-    foreach my $e1 (@$l1) 
-    {
-      $f= 1 unless ($e1 ne $e2);
-    }
-    push(@$l, $e2) unless (defined $f);
-  }
-  return $l;
-}
-
-1;

=== removed file 'tests/lib/mtr_process.pl'
--- tests/lib/mtr_process.pl	2010-05-26 23:33:06 +0000
+++ tests/lib/mtr_process.pl	1970-01-01 00:00:00 +0000
@@ -1,1091 +0,0 @@
-# -*- cperl -*-
-# Copyright (C) 2004-2006 MySQL AB
-# 
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
-# 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-# This is a library file used by the Perl version of mysql-test-run,
-# and is part of the translation of the Bourne shell script with the
-# same name.
-
-use Socket;
-use Errno;
-use strict;
-
-use POSIX qw(WNOHANG SIGHUP);
-
-sub mtr_run ($$$$$$;$);
-sub mtr_spawn ($$$$$$;$);
-sub mtr_check_stop_servers ($);
-sub mtr_kill_leftovers ();
-sub mtr_wait_blocking ($);
-sub mtr_record_dead_children ();
-sub mtr_ndbmgm_start($$);
-sub mtr_exit ($);
-sub sleep_until_file_created ($$$);
-sub mtr_kill_processes ($);
-sub mtr_ping_with_timeout($);
-sub mtr_ping_port ($);
-
-# Local function
-sub spawn_impl ($$$$$$$);
-
-##############################################################################
-#
-#  Execute an external command
-#
-##############################################################################
-
-sub mtr_run ($$$$$$;$) {
-  my $path=       shift;
-  my $arg_list_t= shift;
-  my $input=      shift;
-  my $output=     shift;
-  my $error=      shift;
-  my $pid_file=   shift; # Not used
-  my $spawn_opts= shift;
-
-  return spawn_impl($path,$arg_list_t,'run',$input,$output,$error,
-    $spawn_opts);
-}
-
-sub mtr_run_test ($$$$$$;$) {
-  my $path=       shift;
-  my $arg_list_t= shift;
-  my $input=      shift;
-  my $output=     shift;
-  my $error=      shift;
-  my $pid_file=   shift; # Not used
-  my $spawn_opts= shift;
-
-  return spawn_impl($path,$arg_list_t,'test',$input,$output,$error,
-    $spawn_opts);
-}
-
-sub mtr_spawn ($$$$$$;$) {
-  my $path=       shift;
-  my $arg_list_t= shift;
-  my $input=      shift;
-  my $output=     shift;
-  my $error=      shift;
-  my $pid_file=   shift; # Not used
-  my $spawn_opts= shift;
-
-  return spawn_impl($path,$arg_list_t,'spawn',$input,$output,$error,
-    $spawn_opts);
-}
-
-
-
-sub spawn_impl ($$$$$$$) {
-  my $path=       shift;
-  my $arg_list_t= shift;
-  my $mode=       shift;
-  my $input=      shift;
-  my $output=     shift;
-  my $error=      shift;
-  my $spawn_opts= shift;
-
-  if ( $::opt_script_debug )
-  {
-    mtr_report("");
-    mtr_debug("-" x 73);
-    mtr_debug("STDIN  $input") if $input;
-    mtr_debug("STDOUT $output") if $output;
-    mtr_debug("STDERR $error") if $error;
-    mtr_debug("$mode: $path ", join(" ",@$arg_list_t));
-    mtr_debug("spawn options:");
-    if ($spawn_opts)
-    {
-      foreach my $key (sort keys %{$spawn_opts})
-      {
-        mtr_debug("  - $key: $spawn_opts->{$key}");
-      }
-    }
-    else
-    {
-      mtr_debug("  none");
-    }
-    mtr_debug("-" x 73);
-    mtr_report("");
-  }
-
-  mtr_error("Can't spawn with empty \"path\"") unless defined $path;
-
-
- FORK:
-  {
-    my $pid= fork();
-
-    if ( ! defined $pid )
-    {
-      if ( $! == $!{EAGAIN} )           # See "perldoc Errno"
-      {
-        mtr_warning("Got EAGAIN from fork(), sleep 1 second and redo");
-        sleep(1);
-        redo FORK;
-      }
-
-      mtr_error("$path ($pid) can't be forked, error: $!");
-
-    }
-
-    if ( $pid )
-    {
-      select(STDOUT) if $::glob_win32_perl;
-      return spawn_parent_impl($pid,$mode,$path);
-    }
-    else
-    {
-      # Child, redirect output and exec
-
-      $SIG{INT}= 'DEFAULT';         # Parent do some stuff, we don't
-
-      my $log_file_open_mode = '>';
-
-      if ($spawn_opts and $spawn_opts->{'append_log_file'})
-      {
-        $log_file_open_mode = '>>';
-      }
-
-      if ( $output )
-      {
-	if ( $::glob_win32_perl )
-	{
-	  # Don't redirect stdout on ActiveState perl since this is
-          # just another thread in the same process.
-	}
-        elsif ( ! open(STDOUT,$log_file_open_mode,$output) )
-        {
-          mtr_child_error("can't redirect STDOUT to \"$output\": $!");
-        }
-      }
-
-      if ( $error )
-      {
-        if ( !$::glob_win32_perl and $output eq $error )
-        {
-          if ( ! open(STDERR,">&STDOUT") )
-          {
-            mtr_child_error("can't dup STDOUT: $!");
-          }
-        }
-        else
-        {
-          if ( ! open(STDERR,$log_file_open_mode,$error) )
-          {
-            mtr_child_error("can't redirect STDERR to \"$error\": $!");
-          }
-        }
-      }
-
-      if ( $input )
-      {
-        if ( ! open(STDIN,"<",$input) )
-        {
-          mtr_child_error("can't redirect STDIN to \"$input\": $!");
-        }
-      }
-
-      if ( ! exec($path,@$arg_list_t) )
-      {
-        mtr_child_error("failed to execute \"$path\": $!");
-      }
-      mtr_error("Should never come here 1!");
-    }
-    mtr_error("Should never come here 2!");
-  }
-  mtr_error("Should never come here 3!");
-}
-
-
-sub spawn_parent_impl {
-  my $pid=  shift;
-  my $mode= shift;
-  my $path= shift;
-
-  if ( $mode eq 'run' or $mode eq 'test' )
-  {
-    if ( $mode eq 'run' )
-    {
-      # Simple run of command, wait blocking for it to return
-      my $ret_pid= waitpid($pid,0);
-      if ( $ret_pid != $pid )
-      {
-	# The "simple" waitpid has failed, print debug info
-	# and try to handle the error
-        mtr_warning("waitpid($pid, 0) returned $ret_pid " .
-		    "when waiting for '$path', error: '$!'");
-	if ( $ret_pid == -1 )
-	{
-	  # waitpid returned -1, that would indicate the process
-	  # no longer exist and waitpid couldn't wait for it.
-	  return 1;
-	}
-	mtr_error("Error handling failed");
-      }
-
-      return mtr_process_exit_status($?);
-    }
-    else
-    {
-      # We run mysqltest and wait for it to return. But we try to
-      # catch dying mysqld processes as well.
-      #
-      # We do blocking waitpid() until we get the return from the
-      # "mysqltest" call. But if a mysqld process dies that we
-      # started, we take this as an error, and kill mysqltest.
-
-
-      my $exit_value= -1;
-      my $saved_exit_value;
-      my $ret_pid;                      # What waitpid() returns
-
-      while ( ($ret_pid= waitpid(-1,0)) != -1 )
-      {
-        # Someone terminated, don't know who. Collect
-        # status info first before $? is lost,
-        # but not $exit_value, this is flagged from
-
-        my $timer_name= mtr_timer_timeout($::glob_timers, $ret_pid);
-        if ( $timer_name )
-        {
-          if ( $timer_name eq "suite" )
-          {
-            # We give up here
-            # FIXME we should only give up the suite, not all of the run?
-            print STDERR "\n";
-            mtr_error("Test suite timeout");
-          }
-          elsif ( $timer_name eq "testcase" )
-          {
-            $saved_exit_value=  63;       # Mark as timeout
-            kill(9, $pid);                # Kill mysqltest
-            next;                         # Go on and catch the termination
-          }
-        }
-
-        if ( $ret_pid == $pid )
-        {
-          # We got termination of mysqltest, we are done
-          $exit_value= mtr_process_exit_status($?);
-          last;
-        }
-
-        # One of the child processes died, unless this was expected
-	# mysqltest should be killed and test aborted
-
-	check_expected_crash_and_restart($ret_pid);
-      }
-
-      if ( $ret_pid != $pid )
-      {
-        # We terminated the waiting because a "mysqld" process died.
-        # Kill the mysqltest process.
-	mtr_verbose("Kill mysqltest because another process died");
-        kill(9,$pid);
-
-        $ret_pid= waitpid($pid,0);
-
-        if ( $ret_pid != $pid )
-        {
-          mtr_error("$path ($pid) got lost somehow");
-        }
-      }
-
-      return $saved_exit_value || $exit_value;
-    }
-  }
-  else
-  {
-    # We spawned a process we don't wait for
-    return $pid;
-  }
-}
-
-
-# ----------------------------------------------------------------------
-# We try to emulate how an Unix shell calculates the exit code
-# ----------------------------------------------------------------------
-
-sub mtr_process_exit_status {
-  my $raw_status= shift;
-
-  if ( $raw_status & 127 )
-  {
-    return ($raw_status & 127) + 128;  # Signal num + 128
-  }
-  else
-  {
-    return $raw_status >> 8;           # Exit code
-  }
-}
-
-
-##############################################################################
-#
-#  Kill processes left from previous runs
-#
-##############################################################################
-
-
-# Kill all processes(mysqld, ndbd, ndb_mgmd and im) that would conflict with
-# this run
-# Make sure to remove the PID file, if any.
-# kill IM manager first, else it will restart the servers
-sub mtr_kill_leftovers () {
-
-  mtr_report("Killing Possible Leftover Processes");
-  mtr_debug("mtr_kill_leftovers(): started.");
-
-  my @kill_pids;
-  my %admin_pids;
-
-  foreach my $srv (@{$::master}, @{$::slave})
-  {
-    mtr_debug("  - mysqld " .
-              "(pid: $srv->{pid}; " .
-              "pid file: '$srv->{path_pid}'; " .
-              "socket: '$srv->{path_sock}'; ".
-              "port: $srv->{port})");
-
-    my $pid= mtr_server_shutdown($srv);
-
-    # Save the pid of the drizzle client process
-    $admin_pids{$pid}= 1;
-
-    push(@kill_pids,{
-		     pid      => $srv->{'pid'},
-		     pidfile  => $srv->{'path_pid'},
-		     sockfile => $srv->{'path_sock'},
-		     port     => $srv->{'port'},
-		    });
-    $srv->{'pid'}= 0; # Assume we are done with it
-  }
-
-  # Wait for all the admin processes to complete
-  mtr_wait_blocking(\%admin_pids);
-
-  # If we trusted "mysqladmin --shutdown_timeout= ..." we could just
-  # terminate now, but we don't (FIXME should be debugged).
-  # So we try again to ping and at least wait the same amount of time
-  # mysqladmin would for all to die.
-
-  mtr_ping_with_timeout(\@kill_pids);
-
-  # We now have tried to terminate nice. We have waited for the listen
-  # port to be free, but can't really tell if the mysqld process died
-  # or not. We now try to find the process PID from the PID file, and
-  # send a kill to that process. Note that Perl let kill(0,@pids) be
-  # a way to just return the numer of processes the kernel can send
-  # signals to. So this can be used (except on Cygwin) to determine
-  # if there are processes left running that we cound out might exists.
-  #
-  # But still after all this work, all we know is that we have
-  # the ports free.
-
-  # We scan the "var/run/" directory for other process id's to kill
-
-  my $rundir= "$::opt_vardir/run";
-
-  mtr_debug("Processing PID files in directory '$rundir'...");
-
-  if ( -d $rundir )
-  {
-    opendir(RUNDIR, $rundir)
-      or mtr_error("can't open directory \"$rundir\": $!");
-
-    my @pids;
-
-    while ( my $elem= readdir(RUNDIR) )
-    {
-      # Only read pid from files that end with .pid
-      if ( $elem =~ /.*[.]pid$/)
-      {
-	my $pidfile= "$rundir/$elem";
-
-	if ( -f $pidfile )
-	{
-	  mtr_debug("Processing PID file: '$pidfile'...");
-
-	  my $pid= mtr_get_pid_from_file($pidfile);
-
-	  mtr_debug("Got pid: $pid from file '$pidfile'");
-
-	  if ( $::glob_cygwin_perl or kill(0, $pid) )
-	  {
-	    mtr_debug("There is process with pid $pid -- scheduling for kill.");
-	    push(@pids, $pid);            # We know (cygwin guess) it exists
-	  }
-	  else
-	  {
-	    mtr_debug("There is no process with pid $pid -- skipping.");
-	  }
-	}
-      }
-      else
-      {
-	mtr_warning("Found non pid file $elem in $rundir")
-	  if -f "$rundir/$elem";
-	next;
-      }
-    }
-    closedir(RUNDIR);
-
-    if ( @pids )
-    {
-      mtr_debug("Killing the following processes with PID files: " .
-                join(' ', @pids) . "...");
-
-      start_reap_all();
-
-      if ( $::glob_cygwin_perl )
-      {
-        # We have no (easy) way of knowing the Cygwin controlling
-        # process, in the PID file we only have the Windows process id.
-        system("kill -f " . join(" ",@pids)); # Hope for the best....
-        mtr_debug("Sleep 5 seconds waiting for processes to die");
-        sleep(5);
-      }
-      else
-      {
-        my $retries= 10;                    # 10 seconds
-        do
-        {
-          mtr_debug("Sending SIGKILL to pids: " . join(' ', @pids));
-          kill(9, @pids);
-          mtr_report("Sleep 1 second waiting for processes to die");
-          sleep(1)                      # Wait one second
-        } while ( $retries-- and  kill(0, @pids) );
-
-        if ( kill(0, @pids) )           # Check if some left
-        {
-          mtr_warning("can't kill process(es) " . join(" ", @pids));
-        }
-      }
-
-      stop_reap_all();
-    }
-  }
-  else
-  {
-    mtr_debug("Directory for PID files ($rundir) does not exist.");
-  }
-
-  # We may have failed everything, but we now check again if we have
-  # the listen ports free to use, and if they are free, just go for it.
-
-  mtr_debug("Checking known mysqld servers...");
-
-  foreach my $srv ( @kill_pids )
-  {
-    if ( defined $srv->{'port'} and mtr_ping_port($srv->{'port'}) )
-    {
-      mtr_warning("can't kill old process holding port $srv->{'port'}");
-    }
-  }
-
-  mtr_debug("mtr_kill_leftovers(): finished.");
-}
-
-
-#
-# Check that all processes in "spec" are shutdown gracefully
-# else kill them off hard
-#
-sub mtr_check_stop_servers ($) {
-  my $spec=  shift;
-
-  # Return if no processes are defined
-  return if ! @$spec;
-
-  mtr_verbose("mtr_check_stop_servers");
-
-  # ----------------------------------------------------------------------
-  # Wait until servers in "spec" has stopped listening
-  # to their ports or timeout occurs
-  # ----------------------------------------------------------------------
-  mtr_ping_with_timeout(\@$spec);
-
-  # ----------------------------------------------------------------------
-  # Use waitpid() nonblocking for a little while, to see how
-  # many process's will exit sucessfully.
-  # This is the normal case.
-  # ----------------------------------------------------------------------
-  my $wait_counter= 10; # Max number of times to redo the loop
-  foreach my $srv ( @$spec )
-  {
-    my $pid= $srv->{'pid'};
-    my $ret_pid;
-    if ( $pid )
-    {
-      $ret_pid= waitpid($pid,&WNOHANG);
-      if ($ret_pid == $pid)
-      {
-	mtr_verbose("Caught exit of process $ret_pid");
-	$srv->{'pid'}= 0;
-      }
-      elsif ($ret_pid == 0)
-      {
-	mtr_verbose("Process $pid is still alive");
-	if ($wait_counter-- > 0)
-	{
-	  # Give the processes more time to exit
-	  select(undef, undef, undef, (1));
-	  redo;
-	}
-      }
-      else
-      {
-	mtr_warning("caught exit of unknown child $ret_pid");
-      }
-    }
-  }
-
-  # ----------------------------------------------------------------------
-  # The processes that haven't yet exited need to
-  # be killed hard, put them in "kill_pids" hash
-  # ----------------------------------------------------------------------
-  my %kill_pids;
-  foreach my $srv ( @$spec )
-  {
-    my $pid= $srv->{'pid'};
-    if ( $pid )
-    {
-      # Server is still alive, put it in list to be hard killed
-      if ($::glob_win32_perl)
-      {
-	# Kill the real process if it's known
-	$pid= $srv->{'real_pid'} if ($srv->{'real_pid'});
-      }
-      $kill_pids{$pid}= 1;
-
-      # Write a message to the process's error log (if it has one)
-      # that it's being killed hard.
-      if ( defined $srv->{'errfile'} )
-      {
-	mtr_tofile($srv->{'errfile'}, "Note: Forcing kill of process $pid\n");
-      }
-      mtr_warning("Forcing kill of process $pid");
-
-    }
-    else
-    {
-      # Server is dead, remove the pidfile if it exists
-      #
-      # Race, could have been removed between test with -f
-      # and the unlink() below, so better check again with -f
-      if ( -f $srv->{'pidfile'} and ! unlink($srv->{'pidfile'}) and
-           -f $srv->{'pidfile'} )
-      {
-        mtr_error("can't remove $srv->{'pidfile'}");
-      }
-    }
-  }
-
-  if ( ! keys %kill_pids )
-  {
-    # All processes has exited gracefully
-    return;
-  }
-
-  mtr_kill_processes(\%kill_pids);
-
-  # ----------------------------------------------------------------------
-  # All processes are killed, cleanup leftover files
-  # ----------------------------------------------------------------------
-  {
-    my $errors= 0;
-    foreach my $srv ( @$spec )
-    {
-      if ( $srv->{'pid'} )
-      {
-	# Server has been hard killed, clean it's resources
-	foreach my $file ($srv->{'pidfile'}, $srv->{'sockfile'})
-        {
-	  # Know it is dead so should be no race, careful anyway
-	  if ( defined $file and -f $file and ! unlink($file) and -f $file )
-          {
-	    $errors++;
-	    mtr_warning("couldn't delete $file");
-	  }
-	}
-
-	if ($::glob_win32_perl and $srv->{'real_pid'})
-	{
-	  # Wait for the pseudo pid - if the real_pid was known
-	  # the pseudo pid has not been waited for yet, wai blocking
-	  # since it's "such a simple program"
-	  mtr_verbose("Wait for pseudo process $srv->{'pid'}");
-	  my $ret_pid= waitpid($srv->{'pid'}, 0);
-	  mtr_verbose("Pseudo process $ret_pid died");
-	}
-
-	$srv->{'pid'}= 0;
-      }
-    }
-    if ( $errors )
-    {
-      # There where errors killing processes
-      # do one last attempt to ping the servers
-      # and if they can't be pinged, assume they are dead
-      if ( ! mtr_ping_with_timeout( \@$spec ) )
-      {
-	mtr_error("we could not kill or clean up all processes");
-      }
-      else
-      {
-	mtr_verbose("All ports were free, continuing");
-      }
-    }
-  }
-}
-
-
-# Wait for all the process in the list to terminate
-sub mtr_wait_blocking($) {
-  my $admin_pids= shift;
-
-
-  # Return if no processes defined
-  return if ! %$admin_pids;
-
-  mtr_verbose("mtr_wait_blocking");
-
-  # Wait for all the started processes to exit
-  # As mysqladmin is such a simple program, we trust it to terminate itself.
-  # I.e. we wait blocking, and wait for them all before we go on.
-  foreach my $pid (keys %{$admin_pids})
-  {
-    my $ret_pid= waitpid($pid,0);
-
-  }
-}
-
-sub mtr_server_shutdown($) {
-  my $srv= shift;
-  my $args;
-
-  mtr_init_args(\$args);
-  mtr_add_arg($args, "--shutdown");
-  mtr_add_arg($args, "--user=%s", $::opt_user);
-  mtr_add_arg($args, "--password=");
-  mtr_add_arg($args, "--silent");
-
-  if ( -e $srv->{'path_sock'} )
-  {
-    mtr_add_arg($args, "--socket=%s", $srv->{'path_sock'});
-  }
-
-  if ( $srv->{'port'} )
-  {
-    mtr_add_arg($args, "--port=%s", $srv->{'port'});
-  }
-
-  mtr_add_arg($args, "--connect_timeout=5");
-
-  my $pid= mtr_spawn($::exe_drizzle, $args,
-                     "", "", "", "", { append_log_file => 1 });
-  mtr_verbose("mtr_server_shutdown, pid: $pid");
-  return $pid;
-}
-
-# Start "ndb_mgm shutdown" for a specific cluster, it will
-# shutdown all data nodes and leave the ndb_mgmd running
-sub mtr_ndbmgm_start($$) {
-  my $cluster= shift;
-  my $command= shift;
-
-  my $args;
-
-  mtr_init_args(\$args);
-
-  mtr_add_arg($args, "--no-defaults");
-  mtr_add_arg($args, "--core");
-  mtr_add_arg($args, "--try-reconnect=1");
-  mtr_add_arg($args, "--ndb_connectstring=%s", $cluster->{'connect_string'});
-  mtr_add_arg($args, "-e");
-  mtr_add_arg($args, "$command");
-
-  my $pid= mtr_spawn($::exe_ndb_mgm, $args,
-		     "", "/dev/null", "/dev/null", "",
-		     {});
-  mtr_verbose("mtr_ndbmgm_start, pid: $pid");
-  return $pid;
-
-}
-
-
-# Ping all servers in list, exit when none of them answers
-# or when timeout has passed
-sub mtr_ping_with_timeout($) {
-  my $spec= shift;
-  my $timeout= 200;                     # 20 seconds max
-  my $res= 1;                           # If we just fall through, we are done
-                                        # in the sense that the servers don't
-                                        # listen to their ports any longer
-
-  mtr_debug("Waiting for mysqld servers to stop...");
-
- TIME:
-  while ( $timeout-- )
-  {
-    foreach my $srv ( @$spec )
-    {
-      $res= 1;                          # We are optimistic
-      if ( $srv->{'pid'} and defined $srv->{'port'} )
-      {
-	if ( mtr_ping_port($srv->{'port'}) )
-	{
-	  mtr_verbose("waiting for process $srv->{'pid'} to stop ".
-		      "using port $srv->{'port'}");
-
-	  # Millisceond sleep emulated with select
-	  select(undef, undef, undef, (0.1));
-	  $res= 0;
-	  next TIME;
-	}
-	else
-	{
-	  # Process was not using port
-	}
-      }
-    }
-    last;                               # If we got here, we are done
-  }
-
-  if ($res)
-  {
-    mtr_debug("mtr_ping_with_timeout(): All mysqld instances are down.");
-  }
-  else
-  {
-    mtr_report("mtr_ping_with_timeout(): At least one server is alive.");
-  }
-
-  return $res;
-}
-
-
-#
-# Loop through our list of processes and look for and entry
-# with the provided pid
-# Set the pid of that process to 0 if found
-#
-sub mark_process_dead($)
-{
-  my $ret_pid= shift;
-
-  foreach my $mysqld (@{$::master}, @{$::slave})
-  {
-    if ( $mysqld->{'pid'} eq $ret_pid )
-    {
-      mtr_verbose("$mysqld->{'type'} $mysqld->{'idx'} exited, pid: $ret_pid");
-      $mysqld->{'pid'}= 0;
-      return;
-    }
-  }
-
-  foreach my $cluster (@{$::clusters})
-  {
-    if ( $cluster->{'pid'} eq $ret_pid )
-    {
-      mtr_verbose("$cluster->{'name'} cluster ndb_mgmd exited, pid: $ret_pid");
-      $cluster->{'pid'}= 0;
-      return;
-    }
-
-    foreach my $ndbd (@{$cluster->{'ndbds'}})
-    {
-      if ( $ndbd->{'pid'} eq $ret_pid )
-      {
-	mtr_verbose("$cluster->{'name'} cluster ndbd exited, pid: $ret_pid");
-	$ndbd->{'pid'}= 0;
-	return;
-      }
-    }
-  }
-  mtr_warning("mark_process_dead couldn't find an entry for pid: $ret_pid");
-
-}
-
-#
-# Loop through our list of processes and look for and entry
-# with the provided pid, if found check for the file indicating
-# expected crash and restart it.
-#
-sub check_expected_crash_and_restart($)
-{
-  my $ret_pid= shift;
-
-  foreach my $mysqld (@{$::master}, @{$::slave})
-  {
-    if ( $mysqld->{'pid'} eq $ret_pid )
-    {
-      mtr_verbose("$mysqld->{'type'} $mysqld->{'idx'} exited, pid: $ret_pid");
-      $mysqld->{'pid'}= 0;
-
-      # Check if crash expected and restart if it was
-      my $expect_file= "$::opt_vardir/tmp/" . "$mysqld->{'type'}" .
-	"$mysqld->{'idx'}" . ".expect";
-      if ( -f $expect_file )
-      {
-	mtr_verbose("Crash was expected, file $expect_file exists");
-	mysqld_start($mysqld, $mysqld->{'start_opts'},
-		     $mysqld->{'start_slave_master_info'});
-	unlink($expect_file);
-      }
-
-      return;
-    }
-  }
-
-  foreach my $cluster (@{$::clusters})
-  {
-    if ( $cluster->{'pid'} eq $ret_pid )
-    {
-      mtr_verbose("$cluster->{'name'} cluster ndb_mgmd exited, pid: $ret_pid");
-      $cluster->{'pid'}= 0;
-
-      # Check if crash expected and restart if it was
-      my $expect_file= "$::opt_vardir/tmp/ndb_mgmd_" . "$cluster->{'type'}" .
-	".expect";
-      if ( -f $expect_file )
-      {
-	mtr_verbose("Crash was expected, file $expect_file exists");
-	ndbmgmd_start($cluster);
-	unlink($expect_file);
-      }
-      return;
-    }
-
-    foreach my $ndbd (@{$cluster->{'ndbds'}})
-    {
-      if ( $ndbd->{'pid'} eq $ret_pid )
-      {
-	mtr_verbose("$cluster->{'name'} cluster ndbd exited, pid: $ret_pid");
-	$ndbd->{'pid'}= 0;
-
-	# Check if crash expected and restart if it was
-	my $expect_file= "$::opt_vardir/tmp/ndbd_" . "$cluster->{'type'}" .
-	  "$ndbd->{'idx'}" . ".expect";
-	if ( -f $expect_file )
-	{
-	  mtr_verbose("Crash was expected, file $expect_file exists");
-	  ndbd_start($cluster, $ndbd->{'idx'},
-		     $ndbd->{'start_extra_args'});
-	  unlink($expect_file);
-	}
-	return;
-      }
-    }
-  }
-
-  if ($::instance_manager->{'spawner_pid'} eq $ret_pid)
-  {
-    return;
-  }
-
-  mtr_warning("check_expected_crash_and_restart couldn't find an entry for pid: $ret_pid");
-
-}
-
-##############################################################################
-#
-#  The operating system will keep information about dead children, 
-#  we read this information here, and if we have records the process
-#  is alive, we mark it as dead.
-#
-##############################################################################
-
-sub mtr_record_dead_children () {
-
-  my $process_died= 0;
-  my $ret_pid;
-
-  # Wait without blockinng to see if any processes had died
-  # -1 or 0 means there are no more procesess to wait for
-  while ( ($ret_pid= waitpid(-1,&WNOHANG)) != 0 and $ret_pid != -1)
-  {
-    mtr_warning("mtr_record_dead_children: $ret_pid");
-    mark_process_dead($ret_pid);
-    $process_died= 1;
-  }
-  return $process_died;
-}
-
-sub start_reap_all {
-  # This causes terminating processes to not become zombies, avoiding
-  # the need for (or possibility of) explicit waitpid().
-  $SIG{CHLD}= 'IGNORE';
-
-  # On some platforms (Linux, QNX, OSX, ...) there is potential race
-  # here. If a process terminated before setting $SIG{CHLD} (but after
-  # any attempt to waitpid() it), it will still be a zombie. So we
-  # have to handle any such process here.
-  my $pid;
-  while(($pid= waitpid(-1, &WNOHANG)) != 0 and $pid != -1)
-  {
-    mtr_warning("start_reap_all pid: $pid");
-    mark_process_dead($pid);
-  };
-}
-
-sub stop_reap_all {
-  $SIG{CHLD}= 'DEFAULT';
-}
-
-
-sub mtr_ping_port ($) {
-  my $port= shift;
-
-  mtr_verbose("mtr_ping_port: $port");
-
-  my $remote= "localhost";
-  my $iaddr=  inet_aton($remote);
-  if ( ! $iaddr )
-  {
-    mtr_error("can't find IP number for $remote");
-  }
-  my $paddr=  sockaddr_in($port, $iaddr);
-  my $proto=  getprotobyname('tcp');
-  if ( ! socket(SOCK, PF_INET, SOCK_STREAM, $proto) )
-  {
-    mtr_error("can't create socket: $!");
-  }
-
-  mtr_debug("Pinging server (port: $port)...");
-
-  if ( connect(SOCK, $paddr) )
-  {
-    close(SOCK);                        # FIXME check error?
-    mtr_verbose("USED");
-    return 1;
-  }
-  else
-  {
-    mtr_verbose("FREE");
-    return 0;
-  }
-}
-
-##############################################################################
-#
-#  Wait for a file to be created
-#
-##############################################################################
-
-# FIXME check that the pidfile contains the expected pid!
-
-sub sleep_until_file_created ($$$) {
-  my $pidfile= shift;
-  my $timeout= shift;
-  my $pid=     shift;
-  my $sleeptime= 100; # Milliseconds
-  my $loops= ($timeout * 1000) / $sleeptime;
-
-  for ( my $loop= 1; $loop <= $loops; $loop++ )
-  {
-    if ( -r $pidfile )
-    {
-      return 1;
-    }
-
-    # Check if it died after the fork() was successful
-    if ( $pid != 0 && waitpid($pid,&WNOHANG) == $pid )
-    {
-      mtr_warning("Process $pid died");
-      return 0;
-    }
-
-    mtr_debug("Sleep $sleeptime milliseconds waiting for $pidfile");
-
-    # Print extra message every 60 seconds
-    my $seconds= ($loop * $sleeptime) / 1000;
-    if ( $seconds > 1 and int($seconds * 10) % 600 == 0 )
-    {
-      my $left= $timeout - $seconds;
-      mtr_warning("Waited $seconds seconds for $pidfile to be created, " .
-                  "still waiting for $left seconds...");
-    }
-
-    # Millisceond sleep emulated with select
-    select(undef, undef, undef, ($sleeptime/1000));
-  }
-
-  return 0;
-}
-
-
-sub mtr_kill_processes ($) {
-  my $pids = shift;
-
-  mtr_verbose("mtr_kill_processes (" . join(" ", keys %{$pids}) . ")");
-
-  foreach my $pid (keys %{$pids})
-  {
-
-    if ($pid <= 0)
-    {
-      mtr_warning("Trying to kill illegal pid: $pid");
-      next;
-    }
-
-    my $signaled_procs= kill(9, $pid);
-    if ($signaled_procs == 0)
-    {
-      # No such process existed, assume it's killed
-      mtr_verbose("killed $pid(no such process)");
-    }
-    else
-    {
-      my $ret_pid= waitpid($pid,0);
-      if ($ret_pid == $pid)
-      {
-	mtr_verbose("killed $pid(got the pid)");
-      }
-      elsif ($ret_pid == -1)
-      {
-	mtr_verbose("killed $pid(got -1)");
-      }
-    }
-  }
-  mtr_verbose("done killing processes");
-}
-
-
-##############################################################################
-#
-#  When we exit, we kill off all children
-#
-##############################################################################
-
-sub mtr_exit ($) {
-  my $code= shift;
-  mtr_timer_stop_all($::glob_timers);
-  local $SIG{HUP} = 'IGNORE';
-  # ToDo: Signalling -$$ will only work if we are the process group
-  # leader (in fact on QNX it will signal our session group leader,
-  # which might be Do-compile or Pushbuild, causing tests to be
-  # aborted). So we only do it if we are the group leader. We might
-  # set ourselves as the group leader at startup (with
-  # POSIX::setpgrp(0,0)), but then care must be needed to always do
-  # proper child process cleanup.
-  POSIX::kill(SIGHUP, -$$) if !$::glob_win32_perl and $$ == getpgrp();
-
-  exit($code);
-}
-
-###########################################################################
-
-1;

=== removed file 'tests/lib/mtr_report.pl'
--- tests/lib/mtr_report.pl	2010-03-31 18:07:24 +0000
+++ tests/lib/mtr_report.pl	1970-01-01 00:00:00 +0000
@@ -1,383 +0,0 @@
-# -*- cperl -*-
-# Copyright (C) 2004-2006 MySQL AB
-# 
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
-# 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-# This is a library file used by the Perl version of mysql-test-run,
-# and is part of the translation of the Bourne shell script with the
-# same name.
-
-use strict;
-use warnings;
-
-sub mtr_report_test_name($);
-sub mtr_report_test_passed($);
-sub mtr_report_test_failed($);
-sub mtr_report_test_skipped($);
-sub mtr_report_test_not_skipped_though_disabled($);
-
-sub mtr_report_stats ($);
-sub mtr_print_line ();
-sub mtr_print_thick_line ();
-sub mtr_print_header ();
-sub mtr_report (@);
-sub mtr_warning (@);
-sub mtr_error (@);
-sub mtr_child_error (@);
-sub mtr_debug (@);
-sub mtr_verbose (@);
-
-my $tot_real_time= 0;
-
-
-
-##############################################################################
-#
-#  
-#
-##############################################################################
-
-sub mtr_report_test_name ($) {
-  my $tinfo= shift;
-  my $tname= $tinfo->{name};
-
-  $tname.= " '$tinfo->{combination}'"
-    if defined $tinfo->{combination};
-
-  _mtr_log($tname);
-  if ($::opt_subunit) {
-    printf "test: $tname\n";
-  } else {
-    printf "%-60s ", $tname;
-  }
-}
-
-sub mtr_report_test_skipped ($) {
-  my $tinfo= shift;
-  my $tname= $tinfo->{name};
-  my $cause= "";
-
-  $tinfo->{'result'}= 'MTR_RES_SKIPPED';
-  if ( $tinfo->{'disable'} )
-  {
-    $cause.= "disable";
-  }
-  else
-  {
-    $cause.= "skipped";
-  }
-  if ( $tinfo->{'comment'} )
-  {
-    if ($::opt_subunit) {
-      mtr_report("skip: $tname [\ncause: $cause\n$tinfo->{'comment'}\n]");
-    } else { 
-      mtr_report("[ $cause ]   $tinfo->{'comment'}");
-    }
-  }
-  else
-  {
-    if ($::opt_subunit) {
-      mtr_report("skip: $tname");
-    } else {
-      mtr_report("[ $cause ]");
-    }
-  }
-}
-
-sub mtr_report_tests_not_skipped_though_disabled ($) {
-  my $tests= shift;
-
-  if ( $::opt_enable_disabled )
-  {
-    my @disabled_tests= grep {$_->{'dont_skip_though_disabled'}} @$tests;
-    if ( @disabled_tests )
-    {
-      print "\nTest(s) which will be run though they are marked as disabled:\n";
-      foreach my $tinfo ( sort {$a->{'name'} cmp $b->{'name'}} @disabled_tests )
-      {
-        printf "  %-20s : %s\n", $tinfo->{'name'}, $tinfo->{'comment'};
-      }
-    }
-  }
-}
-
-sub mtr_report_test_passed ($) {
-  my $tinfo= shift;
-  my $tname= $tinfo->{name};
-
-  my $timer=  "";
-  if ( $::opt_timer and -f "$::opt_vardir/log/timer" )
-  {
-    $timer= mtr_fromfile("$::opt_vardir/log/timer");
-    $tot_real_time += ($timer/1000);
-    $timer= sprintf "%7s", $timer;
-    ### XXX: How to format this as iso6801 datetime?
-  }
-  $tinfo->{'result'}= 'MTR_RES_PASSED';
-  if ($::opt_subunit) {
-    mtr_report("success: $tname");
-  } else {
-    mtr_report("[ pass ] $timer");
-  }
-}
-
-sub mtr_report_test_failed ($) {
-  my $tinfo= shift;
-  my $tname= $tinfo->{name};
-  my $comment= "";
-
-  $tinfo->{'result'}= 'MTR_RES_FAILED';
-  if ( defined $tinfo->{'timeout'} )
-  {
-    $comment.= "timeout";
-  }
-  elsif ( $tinfo->{'comment'} )
-  {
-    # The test failure has been detected by mysql-test-run.pl
-    # when starting the servers or due to other error, the reason for
-    # failing the test is saved in "comment"
-    $comment.= "$tinfo->{'comment'}";
-  }
-  elsif ( -f $::path_timefile )
-  {
-    # Test failure was detected by test tool and it's report
-    # about what failed has been saved to file. Display the report.
-    $comment.= mtr_fromfile($::path_timefile);
-  }
-  else
-  {
-    # Neither this script or the test tool has recorded info
-    # about why the test has failed. Should be debugged.
-    $comment.= "Unexpected termination, probably when starting mysqld";
-  }
-  if ($::opt_subunit) {
-    mtr_report("failure: $tname [\n$comment\n]");
-  } else {
-    mtr_report("[ fail ]\n$comment");
-  }
-}
-
-sub mtr_report_stats ($) {
-  my $tests= shift;
-
-  # ----------------------------------------------------------------------
-  # Find out how we where doing
-  # ----------------------------------------------------------------------
-
-  my $tot_skiped= 0;
-  my $tot_passed= 0;
-  my $tot_failed= 0;
-  my $tot_tests=  0;
-  my $tot_restarts= 0;
-  my $found_problems= 0; # Some warnings in the logfiles are errors...
-
-  foreach my $tinfo (@$tests)
-  {
-    if ( $tinfo->{'result'} eq 'MTR_RES_SKIPPED' )
-    {
-      $tot_skiped++;
-    }
-    elsif ( $tinfo->{'result'} eq 'MTR_RES_PASSED' )
-    {
-      $tot_tests++;
-      $tot_passed++;
-    }
-    elsif ( $tinfo->{'result'} eq 'MTR_RES_FAILED' )
-    {
-      $tot_tests++;
-      $tot_failed++;
-    }
-    if ( $tinfo->{'restarted'} )
-    {
-      $tot_restarts++;
-    }
-  }
-
-  # ----------------------------------------------------------------------
-  # Print out a summary report to screen
-  # ----------------------------------------------------------------------
-
-  if ( ! $tot_failed )
-  {
-    print "All $tot_tests tests were successful.\n";
-  }
-  else
-  {
-    my $ratio=  $tot_passed * 100 / $tot_tests;
-    print "Failed $tot_failed/$tot_tests tests, ";
-    printf("%.2f", $ratio);
-    print "\% were successful.\n\n";
-    print
-      "The log files in var/log may give you some hint\n",
-      "of what went wrong.\n",
-      "If you want to report this error, go to:\n",
-      "\thttp://bugs.launchpad.net/drizzle\n";
-  }
-  if (!$::opt_extern)
-  {
-    print "The servers were restarted $tot_restarts times\n";
-  }
-
-  if ( $::opt_timer )
-  {
-    use English;
-
-    mtr_report("Spent", sprintf("%.3f", $tot_real_time),"of",
-	       time - $BASETIME, "seconds executing testcases");
-  }
-
-  print "\n";
-
-  # Print a list of testcases that failed
-  if ( $tot_failed != 0 )
-  {
-    my $test_mode= join(" ", @::glob_test_mode) || "default";
-    print "mysql-test-run in $test_mode mode: *** Failing the test(s):";
-
-    foreach my $tinfo (@$tests)
-    {
-      if ( $tinfo->{'result'} eq 'MTR_RES_FAILED' )
-      {
-        print " $tinfo->{'name'}";
-      }
-    }
-    print "\n";
-
-  }
-
-  # Print a list of check_testcases that failed(if any)
-  if ( $::opt_check_testcases )
-  {
-    my @check_testcases= ();
-
-    foreach my $tinfo (@$tests)
-    {
-      if ( defined $tinfo->{'check_testcase_failed'} )
-      {
-	push(@check_testcases, $tinfo->{'name'});
-      }
-    }
-
-    if ( @check_testcases )
-    {
-      print "Check of testcase failed for: ";
-      print join(" ", @check_testcases);
-      print "\n\n";
-    }
-  }
-
-  if ( $tot_failed != 0 || $found_problems)
-  {
-    mtr_error("there were failing test cases");
-  }
-}
-
-##############################################################################
-#
-#  Text formatting
-#
-##############################################################################
-
-sub mtr_print_line () {
-  print '-' x 80, "\n";
-}
-
-sub mtr_print_thick_line () {
-  print '=' x 80, "\n";
-}
-
-sub mtr_print_header () {
-  print "DEFAULT STORAGE ENGINE: $::opt_engine\n";
-  if ( $::opt_timer )
-  {
-    printf "%-61s%-9s%10s\n","TEST","RESULT","TIME (ms)";
-  }
-  else
-  {
-    print "TEST                           RESULT\n";
-  }
-  mtr_print_line();
-  print "\n";
-}
-
-
-##############################################################################
-#
-#  Log and reporting functions
-#
-##############################################################################
-
-use IO::File;
-
-my $log_file_ref= undef;
-
-sub mtr_log_init ($) {
-  my ($filename)= @_;
-
-  mtr_error("Log is already open") if defined $log_file_ref;
-
-  $log_file_ref= IO::File->new($filename, "a") or
-    mtr_warning("Could not create logfile $filename: $!");
-}
-
-sub _mtr_log (@) {
-  print $log_file_ref join(" ", @_),"\n"
-    if defined $log_file_ref;
-}
-
-sub mtr_report (@) {
-  # Print message to screen and log
-  _mtr_log(@_);
-  print join(" ", @_),"\n";
-}
-
-sub mtr_warning (@) {
-  # Print message to screen and log
-  _mtr_log("WARNING: ", @_);
-  print STDERR "mysql-test-run: WARNING: ",join(" ", @_),"\n";
-}
-
-sub mtr_error (@) {
-  # Print message to screen and log
-  _mtr_log("ERROR: ", @_);
-  print STDERR "mysql-test-run: *** ERROR: ",join(" ", @_),"\n";
-  mtr_exit(1);
-}
-
-sub mtr_child_error (@) {
-  # Print message to screen and log
-  _mtr_log("ERROR(child): ", @_);
-  print STDERR "mysql-test-run: *** ERROR(child): ",join(" ", @_),"\n";
-  exit(1);
-}
-
-sub mtr_debug (@) {
-  # Only print if --script-debug is used
-  if ( $::opt_script_debug )
-  {
-    _mtr_log("###: ", @_);
-    print STDERR "####: ",join(" ", @_),"\n";
-  }
-}
-
-sub mtr_verbose (@) {
-  # Always print to log, print to screen only when --verbose is used
-  _mtr_log("> ",@_);
-  if ( $::opt_verbose )
-  {
-    print STDERR "> ",join(" ", @_),"\n";
-  }
-}
-
-1;

=== removed file 'tests/lib/mtr_stress.pl'
--- tests/lib/mtr_stress.pl	2008-06-25 05:29:13 +0000
+++ tests/lib/mtr_stress.pl	1970-01-01 00:00:00 +0000
@@ -1,191 +0,0 @@
-# -*- cperl -*-
-# Copyright (C) 2006 MySQL AB
-# 
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
-# 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-# This is a library file used by the Perl version of mysql-test-run,
-# and is part of the translation of the Bourne shell script with the
-# same name.
-
-use strict;
-use File::Spec;
-
-# These are not to be prefixed with "mtr_"
-
-sub run_stress_test ();
-
-##############################################################################
-#
-#  Run tests in the stress mode
-#
-##############################################################################
-
-sub run_stress_test () 
-{
-
-  my $args;
-  my $stress_suitedir;
-
-  mtr_report("Starting stress testing\n");
-
-  if ( ! $::glob_use_embedded_server )
-  {
-    if ( ! mysqld_start($::master->[0],[],[]) )
-    {
-      mtr_error("Can't start the mysqld server");
-    }
-  }
-
-  my $stress_basedir=File::Spec->catdir($::opt_vardir, "stress");
-  
-  #Clean up stress dir 
-  if ( -d $stress_basedir )
-  {
-    rmtree($stress_basedir);
-  }
-  mkpath($stress_basedir);
- 
-  if ($::opt_stress_suite ne 'main' && $::opt_stress_suite ne 'default' )
-  {
-    $stress_suitedir=File::Spec->catdir($::glob_mysql_test_dir, "suite", 
-                                         $::opt_stress_suite);
-  }
-  else
-  {
-    $stress_suitedir=$::glob_mysql_test_dir;
-  }
-
-  if ( -d $stress_suitedir )
-  {
-    #$stress_suite_t_dir=File::Spec->catdir($stress_suitedir, "t");
-    #$stress_suite_r_dir=File::Spec->catdir($stress_suitedir, "r");    
-    #FIXME: check dirs above for existence to ensure that test suite 
-    #       contains tests and results dirs
-  }
-  else
-  {
-    mtr_error("Specified test suite $::opt_stress_suite doesn't exist");
-  }
- 
-  if ( @::opt_cases )
-  {
-    $::opt_stress_test_file=File::Spec->catfile($stress_basedir, "stress_tests.txt");
-    open(STRESS_FILE, ">$::opt_stress_test_file");
-    print STRESS_FILE join("\n",@::opt_cases),"\n";
-    close(STRESS_FILE);
-  }
-  elsif ( $::opt_stress_test_file )
-  {
-    $::opt_stress_test_file=File::Spec->catfile($stress_suitedir, 
-                                              $::opt_stress_test_file);
-    if ( ! -f $::opt_stress_test_file )
-    {
-      mtr_error("Specified file $::opt_stress_test_file with list of tests does not exist\n",
-                "Please ensure that file exists and has proper permissions");
-    }
-  }
-  else
-  {
-    $::opt_stress_test_file=File::Spec->catfile($stress_suitedir, 
-                                              "stress_tests.txt");
-    if ( ! -f $::opt_stress_test_file )
-    {
-      mtr_error("Default file $::opt_stress_test_file with list of tests does not exist\n",
-          "Please use --stress-test-file option to specify custom one or you can\n",
-          "just specify name of test for testing as last argument in command line");
-
-    }    
-  }
-
-  if ( $::opt_stress_init_file )
-  {
-    $::opt_stress_init_file=File::Spec->catfile($stress_suitedir, 
-                                              $::opt_stress_init_file);
-    if ( ! -f $::opt_stress_init_file )
-    {
-      mtr_error("Specified file $::opt_stress_init_file with list of tests does not exist\n",
-                "Please ensure that file exists and has proper permissions");
-    }
-  }
-  else
-  {
-    $::opt_stress_init_file=File::Spec->catfile($stress_suitedir, 
-                                              "stress_init.txt");
-    if ( ! -f $::opt_stress_init_file )
-    {
-      $::opt_stress_init_file='';
-    }
-  }  
-  
-  if ( $::opt_stress_mode ne 'random' && $::opt_stress_mode ne 'seq' )
-  {
-    mtr_error("You specified wrong mode $::opt_stress_mode for stress test\n",
-              "Correct values are 'random' or 'seq'");
-  }
-
-  mtr_init_args(\$args);
-  
-  mtr_add_arg($args, "--server-socket=%s", $::master->[0]->{'path_sock'});
-  mtr_add_arg($args, "--server-user=%s", $::opt_user);
-  mtr_add_arg($args, "--server-database=%s", "test");  
-  mtr_add_arg($args, "--stress-suite-basedir=%s", $::glob_mysql_test_dir);  
-  mtr_add_arg($args, "--suite=%s", $::opt_stress_suite);
-  mtr_add_arg($args, "--stress-tests-file=%s", $::opt_stress_test_file);      
-  mtr_add_arg($args, "--stress-basedir=%s", $stress_basedir);
-  mtr_add_arg($args, "--server-logs-dir=%s", $stress_basedir);
-  mtr_add_arg($args, "--stress-mode=%s", $::opt_stress_mode);
-  mtr_add_arg($args, "--mysqltest=%s", $::exe_mysqltest);
-  mtr_add_arg($args, "--threads=%s", $::opt_stress_threads);
-  mtr_add_arg($args, "--verbose");
-  mtr_add_arg($args, "--cleanup");
-  mtr_add_arg($args, "--log-error-details");
-  mtr_add_arg($args, "--abort-on-error");
-
-  if ( $::opt_stress_init_file )
-  {
-    mtr_add_arg($args, "--stress-init-file=%s", $::opt_stress_init_file);
-  }
-
-  if ( !$::opt_stress_loop_count && !$::opt_stress_test_count &&
-       !$::opt_stress_test_duration )
-  {
-    #Limit stress testing with 20 loops in case when any limit parameter 
-    #was specified 
-    $::opt_stress_test_count=20;
-  }
-
-  if ( $::opt_stress_loop_count )
-  {
-    mtr_add_arg($args, "--loop-count=%s", $::opt_stress_loop_count);
-  }
-
-  if ( $::opt_stress_test_count )
-  {
-    mtr_add_arg($args, "--test-count=%s", $::opt_stress_test_count);
-  }
-
-  if ( $::opt_stress_test_duration )
-  {
-    mtr_add_arg($args, "--test-duration=%s", $::opt_stress_test_duration);
-  }
-
-  #Run stress test
-  mtr_run("$::glob_mysql_test_dir/mysql-stress-test.pl", $args, "", "", "", "");
-  if ( ! $::glob_use_embedded_server )
-  {
-    stop_all_servers();
-  }
-}
-
-1;

=== removed file 'tests/lib/mtr_timer.pl'
--- tests/lib/mtr_timer.pl	2008-06-25 05:29:13 +0000
+++ tests/lib/mtr_timer.pl	1970-01-01 00:00:00 +0000
@@ -1,158 +0,0 @@
-# -*- cperl -*-
-# Copyright (C) 2005-2006 MySQL AB
-# 
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
-# 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-# This is a library file used by the Perl version of mysql-test-run,
-# and is part of the translation of the Bourne shell script with the
-# same name.
-
-use Errno;
-use strict;
-
-sub mtr_init_timers ();
-sub mtr_timer_start($$$);
-sub mtr_timer_stop($$);
-sub mtr_timer_stop_all($);
-
-
-##############################################################################
-#
-#  Initiate the structure shared by all timers
-#
-##############################################################################
-
-sub mtr_init_timers () {
-  my $timers = { timers => {}, pids => {}};
-  return $timers;
-}
-
-
-##############################################################################
-#
-#  Start, stop and poll a timer
-#
-#  As alarm() isn't portable to Windows, we use separate processes to
-#  implement timers.
-#
-##############################################################################
-
-sub mtr_timer_start($$$) {
-  my ($timers,$name,$duration)= @_;
-
-  if ( exists $timers->{'timers'}->{$name} )
-  {
-    # We have an old running timer, kill it
-    mtr_warning("There is an old timer running");
-    mtr_timer_stop($timers,$name);
-  }
-
- FORK:
-  {
-    my $tpid= fork();
-
-    if ( ! defined $tpid )
-    {
-      if ( $! == $!{EAGAIN} )           # See "perldoc Errno"
-      {
-        mtr_warning("Got EAGAIN from fork(), sleep 1 second and redo");
-        sleep(1);
-        redo FORK;
-      }
-      else
-      {
-        mtr_error("can't fork timer, error: $!");
-      }
-    }
-
-    if ( $tpid )
-    {
-      # Parent, record the information
-      mtr_verbose("Starting timer for '$name',",
-		  "duration: $duration, pid: $tpid");
-      $timers->{'timers'}->{$name}->{'pid'}= $tpid;
-      $timers->{'timers'}->{$name}->{'duration'}= $duration;
-      $timers->{'pids'}->{$tpid}= $name;
-    }
-    else
-    {
-      # Child, install signal handlers and sleep for "duration"
-
-      # Don't do the ^C cleanup in the timeout child processes!
-      # There is actually a race here, if we get ^C after fork(), but before
-      # clearing the signal handler.
-      $SIG{INT}= 'DEFAULT';
-
-      $SIG{TERM}= sub {
-	mtr_verbose("timer $$ woke up, exiting!");
-	exit(0);
-      };
-
-      $0= "mtr_timer(timers,$name,$duration)";
-      sleep($duration);
-      mtr_verbose("timer $$ expired after $duration seconds");
-      exit(0);
-    }
-  }
-}
-
-
-sub mtr_timer_stop ($$) {
-  my ($timers,$name)= @_;
-
-  if ( exists $timers->{'timers'}->{$name} )
-  {
-    my $tpid= $timers->{'timers'}->{$name}->{'pid'};
-    mtr_verbose("Stopping timer for '$name' with pid $tpid");
-
-    # FIXME as Cygwin reuses pids fast, maybe check that is
-    # the expected process somehow?!
-    kill(15, $tpid);
-
-    # As the timers are so simple programs, we trust them to terminate,
-    # and use blocking wait for it. We wait just to avoid a zombie.
-    waitpid($tpid,0);
-
-    delete $timers->{'timers'}->{$name}; # Remove the timer information
-    delete $timers->{'pids'}->{$tpid};   # and PID reference
-
-    return 1;
-  }
-
-  mtr_error("Asked to stop timer '$name' not started");
-}
-
-
-sub mtr_timer_stop_all ($) {
-  my $timers= shift;
-
-  foreach my $name ( keys %{$timers->{'timers'}} )
-  {
-    mtr_timer_stop($timers, $name);
-  }
-  return 1;
-}
-
-
-sub mtr_timer_timeout ($$) {
-  my ($timers,$pid)= @_;
-
-  return "" unless exists $timers->{'pids'}->{$pid};
-
-  # Got a timeout(the process with $pid is recorded as being a timer)
-  # return the name of the timer
-  return $timers->{'pids'}->{$pid};
-}
-
-1;

=== removed file 'tests/lib/mtr_unique.pl'
--- tests/lib/mtr_unique.pl	2008-06-25 05:29:13 +0000
+++ tests/lib/mtr_unique.pl	1970-01-01 00:00:00 +0000
@@ -1,178 +0,0 @@
-# -*- cperl -*-
-# Copyright (C) 2006 MySQL AB
-# 
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
-# 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-#
-# This file is used from mysql-test-run.pl when choosing
-# port numbers and directories to use for running mysqld.
-#
-
-use strict;
-use Fcntl ':flock';
-
-#
-# Requested IDs are stored in a hash and released upon END.
-#
-my %mtr_unique_assigned_ids = ();
-my $mtr_unique_pid;
-BEGIN {
-	$mtr_unique_pid = $$ unless defined $mtr_unique_pid;
-}
-END { 
-	if($mtr_unique_pid == $$) {
-		while(my ($id,$file) = each(%mtr_unique_assigned_ids)) {
-			print "Autoreleasing $file:$id\n";
-			mtr_release_unique_id($file, $id);
-		}
-	}
-}
-
-#
-# Require a unique, numerical ID, given a file name (where all
-# requested IDs are stored), a minimum and a maximum value.
-#
-# We use flock to implement locking for the ID file and ignore
-# possible problems arising from lack of support for it on 
-# some platforms (it should work on most, and the possible
-# race condition would occur rarely). The proper solution for
-# this is a daemon that manages IDs, of course.
-#
-# If no unique ID within the specified parameters can be 
-# obtained, return undef.
-#
-sub mtr_require_unique_id($$$) {
-	my $file = shift;
-	my $min = shift;
-	my $max = shift;
-	my $ret = undef;
-	my $changed = 0;
-
-	my $can_use_ps = `ps -e | grep '^[ ]*$$ '`;
-
-	if(eval("readlink '$file'") || eval("readlink '$file.sem'")) {
-		die 'lock file is a symbolic link';
-	}
-
-	chmod 0777, "$file.sem";
-	open SEM, ">", "$file.sem" or die "can't write to $file.sem";
-	flock SEM, LOCK_EX or die "can't lock $file.sem";
-	if(! -e $file) {
-		open FILE, ">", $file or die "can't create $file";
-		close FILE;
-	}
-
-	if(eval("readlink '$file'") || eval("readlink '$file.sem'")) {
-		die 'lock file is a symbolic link';
-	}
-
-	chmod 0777, $file;
-	open FILE, "+<", $file or die "can't open $file";
-	select undef,undef,undef,0.2;
-	seek FILE, 0, 0;
-	my %taken = ();
-	while(<FILE>) {
-		chomp;
-		my ($id, $pid) = split / /;
-		$taken{$id} = $pid;
-		if($can_use_ps) {
-			my $res = `ps -e | grep '^[ ]*$pid '`;
-			if(!$res) {
-				print "Ignoring slot $id used by missing process $pid.\n";
-				delete $taken{$id};
-				++$changed;
-			}
-		}
-	}
-	for(my $i=$min; $i<=$max; ++$i) {
-		if(! exists $taken{$i}) {
-			$ret = $i;
-			$taken{$i} = $$;
-			++$changed;
-			last;
-		}
-	}
-	if($changed) {
-		seek FILE, 0, 0;
-		truncate FILE, 0 or die "can't truncate $file";
-		for my $k (keys %taken) {
-			print FILE $k . ' ' . $taken{$k} . "\n";
-		}
-	}
-	close FILE;
-	flock SEM, LOCK_UN or warn "can't unlock $file.sem";
-	close SEM;
-	$mtr_unique_assigned_ids{$ret} = $file if defined $ret;
-	return $ret;
-}
-
-#
-# Require a unique ID like above, but sleep if no ID can be
-# obtained immediately.
-#
-sub mtr_require_unique_id_and_wait($$$) {
-	my $ret = mtr_require_unique_id($_[0],$_[1],$_[2]);
-	while(! defined $ret) {
-		sleep 30;
-		$ret = mtr_require_unique_id($_[0],$_[1],$_[2]);
-		print "Waiting for unique id to become available...\n" unless $ret;
-	}
-	return $ret;
-}
-
-#
-# Release a unique ID.
-#
-sub mtr_release_unique_id($$) {
-	my $file = shift;
-	my $myid = shift;
-
-	if(eval("readlink '$file'") || eval("readlink '$file.sem'")) {
-		die 'lock file is a symbolic link';
-	}
-
-	open SEM, ">", "$file.sem" or die "can't write to $file.sem";
-	flock SEM, LOCK_EX or die "can't lock $file.sem";
-
-	if(eval("readlink '$file'") || eval("readlink '$file.sem'")) {
-		die 'lock file is a symbolic link';
-	}
-
-	if(! -e $file) {
-		open FILE, ">", $file or die "can't create $file";
-		close FILE;
-	}
-	open FILE, "+<", $file or die "can't open $file";
-	select undef,undef,undef,0.2;
-	seek FILE, 0, 0;
-	my %taken = ();
-	while(<FILE>) {
-		chomp;
-		my ($id, $pid) = split / /;
-		$taken{$id} = $pid;
-	}
-	delete $taken{$myid};
-	seek FILE, 0, 0;
-	truncate FILE, 0 or die "can't truncate $file";
-	for my $k (keys %taken) {
-		print FILE $k . ' ' . $taken{$k} . "\n";
-	}
-	close FILE;
-	flock SEM, LOCK_UN or warn "can't unlock $file.sem";
-	close SEM;
-	delete $mtr_unique_assigned_ids{$myid};
-}
-
-1;
-

=== modified file 'tests/test-run.pl'
--- tests/test-run.pl	2010-09-28 21:14:58 +0000
+++ tests/test-run.pl	2010-10-07 19:35:15 +0000
@@ -22,15 +22,15 @@
 #
 #   - To make this Perl script easy to alter even for those that not
 #     code Perl that often, keeep the coding style as close as possible to
-#     the C/C++ MySQL coding standard.
+#     the C/C++ drizzle coding standard.
 #
 #   - All lists of arguments to send to commands are Perl lists/arrays,
 #     not strings we append args to. Within reason, most string
 #     concatenation for arguments should be avoided.
 #
 #   - Functions defined in the main program are not to be prefixed,
-#     functions in "library files" are to be prefixed with "mtr_" (for
-#     Mysql-Test-Run). There are some exceptions, code that fits best in
+#     functions in "library files" are to be prefixed with "dtr_" (for
+#     Drizzle-Test-Run). There are some exceptions, code that fits best in
 #     the main program, but are put into separate files to avoid
 #     clutter, may be without prefix.
 #
@@ -52,7 +52,7 @@
 # A nice way to trace the execution of this script while debugging
 # is to use the Devel::Trace package found at
 # "http://www.plover.com/~mjd/perl/Trace/" and run this script like
-# "perl -d:Trace drizzle-test-run.pl"
+# "perl -d:Trace test-run.pl"
 #
 
 
@@ -77,17 +77,17 @@
 select(STDOUT);
 $| = 1; # Automatically flush STDOUT
 
-require "mtr_cases.pl";
-require "mtr_process.pl";
-require "mtr_timer.pl";
-require "mtr_io.pl";
-require "mtr_gcov.pl";
-require "mtr_gprof.pl";
-require "mtr_report.pl";
-require "mtr_match.pl";
-require "mtr_misc.pl";
-require "mtr_stress.pl";
-require "mtr_unique.pl";
+require "dtr_cases.pl";
+require "dtr_process.pl";
+require "dtr_timer.pl";
+require "dtr_io.pl";
+require "dtr_gcov.pl";
+require "dtr_gprof.pl";
+require "dtr_report.pl";
+require "dtr_match.pl";
+require "dtr_misc.pl";
+require "dtr_stress.pl";
+require "dtr_unique.pl";
 
 $Devel::Trace::TRACE= 1;
 
@@ -100,8 +100,8 @@
 # Misc global variables
 our $drizzle_version_id;
 our $glob_suite_path=             undef;
-our $glob_mysql_test_dir=         undef;
-our $glob_mysql_bench_dir=        undef;
+our $glob_drizzle_test_dir=         undef;
+our $glob_drizzle_bench_dir=        undef;
 our $glob_scriptname=             undef;
 our $glob_timers=                 undef;
 our @glob_test_mode;
@@ -138,7 +138,7 @@
 
 our $opt_repeat_test= 1;
 
-our $exe_master_mysqld;
+our $exe_master_drizzled;
 our $exe_drizzle;
 our $exe_drizzle_client_test;
 our $exe_bug25714;
@@ -148,7 +148,7 @@
 our $exe_drizzleimport;
 our $exe_drizzle_fix_system_tables;
 our $exe_drizzletest;
-our $exe_slave_mysqld;
+our $exe_slave_drizzled;
 our $exe_perror;
 our $lib_udf_example;
 our $lib_example_plugin;
@@ -161,7 +161,7 @@
 our @opt_combinations;
 our $opt_skip_combination;
 
-our @opt_extra_mysqld_opt;
+our @opt_extra_drizzled_opt;
 
 our $opt_compress;
 
@@ -177,7 +177,7 @@
 our $opt_force;
 our $opt_reorder= 0;
 our $opt_enable_disabled;
-our $opt_mem= $ENV{'MTR_MEM'};
+our $opt_mem= $ENV{'DTR_MEM'};
 
 our $opt_gcov;
 our $opt_gcov_err;
@@ -196,7 +196,7 @@
 our $opt_manual_ddd;
 our $opt_manual_debug;
 # Magic number -69.4 results in traditional test ports starting from 9306.
-our $opt_mtr_build_thread=-69.4;
+our $opt_dtr_build_thread=-69.4;
 our $opt_debugger;
 our $opt_client_debugger;
 
@@ -241,7 +241,7 @@
 our $opt_user;
 
 my $opt_valgrind= 0;
-my $opt_valgrind_mysqld= 0;
+my $opt_valgrind_drizzled= 0;
 my $opt_valgrind_drizzletest= 0;
 my $opt_valgrind_drizzleslap= 0;
 my @default_valgrind_args= ("--show-reachable=yes --malloc-fill=0xDEADBEEF --free-fill=0xDEADBEEF");
@@ -269,7 +269,7 @@
 our $used_default_engine;
 our $debug_compiled_binaries;
 
-our %mysqld_variables;
+our %drizzled_variables;
 
 my $source_dist= 0;
 
@@ -286,7 +286,7 @@
 sub main ();
 sub initial_setup ();
 sub command_line_setup ();
-sub set_mtr_build_thread_ports($);
+sub set_dtr_build_thread_ports($);
 sub datadir_list_setup ();
 sub executable_setup ();
 sub environment_setup ();
@@ -294,10 +294,10 @@
 sub remove_stale_vardir ();
 sub setup_vardir ();
 sub check_running_as_root();
-sub mysqld_wait_started($);
+sub drizzled_wait_started($);
 sub run_benchmarks ($);
 sub initialize_servers ();
-sub mysql_install_db ();
+sub drizzle_install_db ();
 sub copy_install_db ($$);
 sub run_testcase ($);
 sub run_testcase_stop_servers ($$$);
@@ -306,8 +306,8 @@
 sub report_failure_and_restart ($);
 sub do_before_start_master ($);
 sub do_before_start_slave ($);
-sub mysqld_start ($$$);
-sub mysqld_arguments ($$$$);
+sub drizzled_start ($$$);
+sub drizzled_arguments ($$$$);
 sub stop_all_servers ();
 sub run_drizzletest ($);
 sub collapse_path ($);
@@ -326,7 +326,7 @@
 
   command_line_setup();
 
-  check_debug_support(\%mysqld_variables);
+  check_debug_support(\%drizzled_variables);
 
   executable_setup();
 
@@ -367,7 +367,7 @@
       {
 	my $extra_suite= $extra_suites{$dir};
 	if (defined $extra_suite){
-	  mtr_report("Found extra suite: $extra_suite");
+	  dtr_report("Found extra suite: $extra_suite");
 	  $opt_suites= "$extra_suite,$opt_suites";
 	  last;
 	}
@@ -386,14 +386,14 @@
 	# Count max number of slaves used by a test case
 	if ( $test->{slave_num} > $max_slave_num) {
 	  $max_slave_num= $test->{slave_num};
-	  mtr_error("Too many slaves") if $max_slave_num > 3;
+	  dtr_error("Too many slaves") if $max_slave_num > 3;
 	}
 
 	# Count max number of masters used by a test case
 	if ( $test->{master_num} > $max_master_num) {
 	  $max_master_num= $test->{master_num};
-	  mtr_error("Too many masters") if $max_master_num > 2;
-	  mtr_error("Too few masters") if $max_master_num < 1;
+	  dtr_error("Too many masters") if $max_master_num > 2;
+	  dtr_error("Too few masters") if $max_master_num < 1;
 	}
       }
       $use_innodb||= $test->{'innodb_test'};
@@ -408,7 +408,7 @@
     run_tests($tests);
   }
 
-  mtr_exit(0);
+  dtr_exit(0);
 }
 
 ##############################################################################
@@ -419,7 +419,7 @@
 
 #
 # When an option is no longer used by this program, it must be explicitly
-# ignored or else it will be passed through to mysqld.  GetOptions will call
+# ignored or else it will be passed through to drizzled.  GetOptions will call
 # this subroutine once for each such option on the command line.  See
 # Getopt::Long documentation.
 #
@@ -437,17 +437,17 @@
   my $opt_comment;
 
   # If so requested, we try to avail ourselves of a unique build thread number.
-  if ( $ENV{'MTR_BUILD_THREAD'} ) {
-    if ( lc($ENV{'MTR_BUILD_THREAD'}) eq 'auto' ) {
+  if ( $ENV{'DTR_BUILD_THREAD'} ) {
+    if ( lc($ENV{'DTR_BUILD_THREAD'}) eq 'auto' ) {
       print "Requesting build thread... ";
-      $ENV{'MTR_BUILD_THREAD'} = mtr_require_unique_id_and_wait("/tmp/mysql-test-ports", 200, 299);
-      print "got ".$ENV{'MTR_BUILD_THREAD'}."\n";
+      $ENV{'DTR_BUILD_THREAD'} = dtr_require_unique_id_and_wait("/tmp/drizzle-test-ports", 200, 299);
+      print "got ".$ENV{'DTR_BUILD_THREAD'}."\n";
     }
   }
 
-  if ( $ENV{'MTR_BUILD_THREAD'} )
+  if ( $ENV{'DTR_BUILD_THREAD'} )
   {
-    set_mtr_build_thread_ports($ENV{'MTR_BUILD_THREAD'});
+    set_dtr_build_thread_ports($ENV{'DTR_BUILD_THREAD'});
   }
 
   # This is needed for test log evaluation in "gen-build-status-page"
@@ -459,7 +459,7 @@
   # Note: Keep list, and the order, in sync with usage at end of this file
 
   # Options that are no longer used must still be processed, because all
-  # unprocessed options are passed directly to mysqld.  The user will be
+  # unprocessed options are passed directly to drizzled.  The user will be
   # warned that the option is being ignored.
   #
   # Put the complete option string here.  For example, to remove the --suite
@@ -489,15 +489,15 @@
              'master_port=i'            => \$opt_master_myport,
              'slave_port=i'             => \$opt_slave_myport,
              'memc_port=i'              => \$opt_memc_myport,
-	     'mtr-build-thread=i'       => \$opt_mtr_build_thread,
+	     'dtr-build-thread=i'       => \$opt_dtr_build_thread,
 
              # Test case authoring
              'record'                   => \$opt_record,
              'check-testcases'          => \$opt_check_testcases,
              'mark-progress'            => \$opt_mark_progress,
 
-             # Extra options used when starting mysqld
-             'mysqld=s'                 => \@opt_extra_mysqld_opt,
+             # Extra options used when starting drizzled
+             'drizzled=s'                 => \@opt_extra_drizzled_opt,
              'engine=s'                 => \$opt_engine,
 
              # Run test on running server
@@ -520,8 +520,8 @@
 	     'debugger=s'               => \$opt_debugger,
 	     'client-debugger=s'        => \$opt_client_debugger,
              'strace-client'            => \$opt_strace_client,
-             'master-binary=s'          => \$exe_master_mysqld,
-             'slave-binary=s'           => \$exe_slave_mysqld,
+             'master-binary=s'          => \$exe_master_drizzled,
+             'slave-binary=s'           => \$exe_slave_drizzled,
              'max-save-core=i'          => \$opt_max_save_core,
 
              # Coverage, profiling etc
@@ -530,7 +530,7 @@
              'valgrind|valgrind-all'    => \$opt_valgrind,
              'valgrind-drizzletest'       => \$opt_valgrind_drizzletest,
              'valgrind-drizzleslap'       => \$opt_valgrind_drizzleslap,
-             'valgrind-mysqld'          => \$opt_valgrind_mysqld,
+             'valgrind-drizzled'          => \$opt_valgrind_drizzled,
              'valgrind-options=s'       => sub {
 	       my ($opt, $value)= @_;
 	       # Deprecated option unless it's what we know pushbuild uses
@@ -565,7 +565,7 @@
              'top-srcdir=s'             => \$opt_top_srcdir,
              'suitepath=s'              => \$opt_suitepath,
              'testdir=s'                => \$opt_testdir,
-             'benchdir=s'               => \$glob_mysql_bench_dir,
+             'benchdir=s'               => \$glob_drizzle_bench_dir,
              'mem'                      => \$opt_mem,
 
              # Misc
@@ -602,13 +602,13 @@
 
   $glob_scriptname=  basename($0);
 
-  if ($opt_mtr_build_thread != 0)
+  if ($opt_dtr_build_thread != 0)
   {
-    set_mtr_build_thread_ports($opt_mtr_build_thread)
+    set_dtr_build_thread_ports($opt_dtr_build_thread)
   }
-  elsif ($ENV{'MTR_BUILD_THREAD'})
+  elsif ($ENV{'DTR_BUILD_THREAD'})
   {
-    $opt_mtr_build_thread= $ENV{'MTR_BUILD_THREAD'};
+    $opt_dtr_build_thread= $ENV{'DTR_BUILD_THREAD'};
   }
 
   if ( -d "../drizzled" )
@@ -619,33 +619,33 @@
   # Find the absolute path to the test directory
   if ( ! $opt_testdir )
   {
-    $glob_mysql_test_dir=  cwd();
+    $glob_drizzle_test_dir=  cwd();
   } 
   else
   {
-    $glob_mysql_test_dir= $opt_testdir;
+    $glob_drizzle_test_dir= $opt_testdir;
   }
-  $default_vardir= "$glob_mysql_test_dir/var";
-  $default_top_srcdir= "$glob_mysql_test_dir/..";
-  $default_top_builddir= "$glob_mysql_test_dir/..";
+  $default_vardir= "$glob_drizzle_test_dir/var";
+  $default_top_srcdir= "$glob_drizzle_test_dir/..";
+  $default_top_builddir= "$glob_drizzle_test_dir/..";
 
   if ( ! $opt_suitepath )
   {
-    $glob_suite_path= "$glob_mysql_test_dir/../plugin";
+    $glob_suite_path= "$glob_drizzle_test_dir/../plugin";
   }
   else
   {
     $glob_suite_path= $opt_suitepath;
   }
   # In most cases, the base directory we find everything relative to,
-  # is the parent directory of the "mysql-test" directory. For source
+  # is the parent directory of the "drizzle-test" directory. For source
   # distributions, TAR binary distributions and some other packages.
-  $glob_basedir= dirname($glob_mysql_test_dir);
+  $glob_basedir= dirname($glob_drizzle_test_dir);
 
   # In the RPM case, binaries and libraries are installed in the
   # default system locations, instead of having our own private base
-  # directory. And we install "/usr/share/mysql-test". Moving up one
-  # more directory relative to "mysql-test" gives us a usable base
+  # directory. And we install "/usr/share/drizzle-test". Moving up one
+  # more directory relative to "drizzle-test" gives us a usable base
   # directory for RPM installs.
   if ( ! $source_dist and ! -d "$glob_basedir/bin" )
   {
@@ -663,13 +663,13 @@
     $glob_builddir="..";
   }
 
-  # Expect mysql-bench to be located adjacent to the source tree, by default
-  $glob_mysql_bench_dir= "$glob_basedir/../mysql-bench"
-    unless defined $glob_mysql_bench_dir;
-  $glob_mysql_bench_dir= undef
-    unless -d $glob_mysql_bench_dir;
+  # Expect drizzle-bench to be located adjacent to the source tree, by default
+  $glob_drizzle_bench_dir= "$glob_basedir/../drizzle-bench"
+    unless defined $glob_drizzle_bench_dir;
+  $glob_drizzle_bench_dir= undef
+    unless -d $glob_drizzle_bench_dir;
 
-  $glob_timers= mtr_init_timers();
+  $glob_timers= dtr_init_timers();
 
   #
   # Find the drizzled executable to be able to find the drizzled version
@@ -677,13 +677,13 @@
   #
 
   # Look for the client binaries directory
-  $path_client_bindir= mtr_path_exists("$glob_builddir/client",
+  $path_client_bindir= dtr_path_exists("$glob_builddir/client",
                                        "$glob_basedir/client",
 				       "$glob_basedir/bin");
 
   if (!$opt_extern)
   {
-    $exe_drizzled=       mtr_exe_exists ("$glob_basedir/drizzled/drizzled",
+    $exe_drizzled=       dtr_exe_exists ("$glob_basedir/drizzled/drizzled",
 				       "$path_client_bindir/drizzled",
 				       "$glob_basedir/libexec/drizzled",
 				       "$glob_basedir/bin/drizzled",
@@ -691,11 +691,11 @@
                                        "$glob_builddir/drizzled/drizzled");
 
     # Use the drizzled found above to find out what features are available
-    collect_mysqld_features();
+    collect_drizzled_features();
   }
   else
   {
-    $mysqld_variables{'port'}= 4427;
+    $drizzled_variables{'port'}= 4427;
   }
 
   if (!$opt_engine)
@@ -715,7 +715,7 @@
   {
     if ( $arg =~ /^--skip-/ )
     {
-      push(@opt_extra_mysqld_opt, $arg);
+      push(@opt_extra_drizzled_opt, $arg);
     }
     elsif ( $arg =~ /^--$/ )
     {
@@ -736,14 +736,14 @@
   # --------------------------------------------------------------------------
   # Find out default storage engine being used(if any)
   # --------------------------------------------------------------------------
-  foreach my $arg ( @opt_extra_mysqld_opt )
+  foreach my $arg ( @opt_extra_drizzled_opt )
   {
     if ( $arg =~ /default-storage-engine=(\S+)/ )
     {
       $used_default_engine= $1;
     }
   }
-  mtr_report("Using default engine '$used_default_engine'")
+  dtr_report("Using default engine '$used_default_engine'")
     if defined $used_default_engine;
 
   # --------------------------------------------------------------------------
@@ -751,9 +751,9 @@
   # --------------------------------------------------------------------------
   if ( defined $opt_mem )
   {
-    mtr_error("Can't use --mem and --vardir at the same time ")
+    dtr_error("Can't use --mem and --vardir at the same time ")
       if $opt_vardir;
-    mtr_error("Can't use --mem and --tmpdir at the same time ")
+    dtr_error("Can't use --mem and --tmpdir at the same time ")
       if $opt_tmpdir;
 
     # Search through list of locations that are known
@@ -765,9 +765,9 @@
     {
       if ( -d $fs )
       {
-	mtr_report("Using tmpfs in $fs");
+	dtr_report("Using tmpfs in $fs");
 	$opt_mem= "$fs/var";
-	$opt_mem .= $opt_mtr_build_thread if $opt_mtr_build_thread;
+	$opt_mem .= $opt_dtr_build_thread if $opt_dtr_build_thread;
 	last;
       }
     }
@@ -816,7 +816,7 @@
 # --------------------------------------------------------------------------
   if ( $opt_record and ! @opt_cases )
   {
-    mtr_error("Will not run in record mode without a specific test case");
+    dtr_error("Will not run in record mode without a specific test case");
   }
 
   if ( $opt_record )
@@ -837,7 +837,7 @@
   # --------------------------------------------------------------------------
   if ( $opt_gcov and ! $source_dist )
   {
-    mtr_error("Coverage test needs the source - please use source dist");
+    dtr_error("Coverage test needs the source - please use source dist");
   }
 
   # --------------------------------------------------------------------------
@@ -851,47 +851,47 @@
     $glob_debugger= 1;
     if ( $opt_extern )
     {
-      mtr_error("Can't use --extern when using debugger");
+      dtr_error("Can't use --extern when using debugger");
     }
   }
 
   # --------------------------------------------------------------------------
   # Check if special exe was selected for master or slave
   # --------------------------------------------------------------------------
-  $exe_master_mysqld= $exe_master_mysqld || $exe_drizzled;
-  $exe_slave_mysqld=  $exe_slave_mysqld  || $exe_drizzled;
+  $exe_master_drizzled= $exe_master_drizzled || $exe_drizzled;
+  $exe_slave_drizzled=  $exe_slave_drizzled  || $exe_drizzled;
 
   # --------------------------------------------------------------------------
   # Check valgrind arguments
   # --------------------------------------------------------------------------
   if ( $opt_valgrind or $opt_valgrind_path or @valgrind_args)
   {
-    mtr_report("Turning on valgrind for all executables");
+    dtr_report("Turning on valgrind for all executables");
     $opt_valgrind= 1;
-    $opt_valgrind_mysqld= 1;
+    $opt_valgrind_drizzled= 1;
     $opt_valgrind_drizzletest= 1;
   }
-  elsif ( $opt_valgrind_mysqld )
+  elsif ( $opt_valgrind_drizzled )
   {
-    mtr_report("Turning on valgrind for mysqld(s) only");
+    dtr_report("Turning on valgrind for drizzled(s) only");
     $opt_valgrind= 1;
   }
   elsif ( $opt_valgrind_drizzletest )
   {
-    mtr_report("Turning on valgrind for drizzletest and drizzle_client_test only");
+    dtr_report("Turning on valgrind for drizzletest and drizzle_client_test only");
     $opt_valgrind= 1;
   }
   elsif ( $opt_valgrind_drizzleslap )
   {
-    mtr_report("Turning on valgrind for drizzleslap only");
+    dtr_report("Turning on valgrind for drizzleslap only");
     $opt_valgrind= 1;
   }
 
   if ( $opt_callgrind )
   {
-    mtr_report("Turning on valgrind with callgrind for mysqld(s)");
+    dtr_report("Turning on valgrind with callgrind for drizzled(s)");
     $opt_valgrind= 1;
-    $opt_valgrind_mysqld= 1;
+    $opt_valgrind_drizzled= 1;
 
     # Set special valgrind options unless options passed on command line
     push(@valgrind_args, "--trace-children=yes")
@@ -900,9 +900,9 @@
 
   if ( $opt_massif )
   {
-    mtr_report("Valgrind with Massif tool for drizzled(s)");
+    dtr_report("Valgrind with Massif tool for drizzled(s)");
     $opt_valgrind= 1;
-    $opt_valgrind_mysqld= 1;
+    $opt_valgrind_drizzled= 1;
   }
 
   if ( $opt_valgrind )
@@ -911,7 +911,7 @@
     push(@valgrind_args, @default_valgrind_args)
       unless @valgrind_args;
 
-    mtr_report("Running valgrind with options \"",
+    dtr_report("Running valgrind with options \"",
 	       join(" ", @valgrind_args), "\"");
   }
 
@@ -1041,12 +1041,12 @@
     warn("Currenty broken --extern");
 
     # Setup master->[0] with the settings for the extern server
-    $master->[0]->{'path_sock'}=  $opt_socket ? $opt_socket : "/tmp/mysql.sock";
-    mtr_report("Using extern server at '$master->[0]->{path_sock}'");
+    $master->[0]->{'path_sock'}=  $opt_socket ? $opt_socket : "/tmp/drizzle.sock";
+    dtr_report("Using extern server at '$master->[0]->{path_sock}'");
   }
   else
   {
-    mtr_error("--socket can only be used in combination with --extern")
+    dtr_error("--socket can only be used in combination with --extern")
       if $opt_socket;
   }
 
@@ -1062,11 +1062,11 @@
     # When both --valgrind and --debug is selected, send
     # all output to the trace file, making it possible to
     # see the exact location where valgrind complains
-    foreach my $mysqld (@{$master}, @{$slave})
+    foreach my $drizzled (@{$master}, @{$slave})
     {
-      my $sidx= $mysqld->{idx} ? "$mysqld->{idx}" : "";
-      $mysqld->{path_myerr}=
-	"$opt_vardir/log/" . $mysqld->{type} . "$sidx.trace";
+      my $sidx= $drizzled->{idx} ? "$drizzled->{idx}" : "";
+      $drizzled->{path_myerr}=
+	"$opt_vardir/log/" . $drizzled->{type} . "$sidx.trace";
     }
   }
 }
@@ -1104,7 +1104,7 @@
 #
 # Note the MASTER_MYPORT has to be set the same in all 4.x and 5.x
 # versions of this script, else a 4.0 test run might conflict with a
-# 5.1 test run, even if different MTR_BUILD_THREAD is used. This means
+# 5.1 test run, even if different DTR_BUILD_THREAD is used. This means
 # all port numbers might not be used in this version of the script.
 #
 # Also note the limitation of ports we are allowed to hand out. This
@@ -1113,20 +1113,20 @@
 # But a fairly safe range seems to be 5001 - 32767
 #
 
-sub set_mtr_build_thread_ports($) {
-  my $mtr_build_thread= shift;
+sub set_dtr_build_thread_ports($) {
+  my $dtr_build_thread= shift;
 
-  if ( lc($mtr_build_thread) eq 'auto' ) {
+  if ( lc($dtr_build_thread) eq 'auto' ) {
     print "Requesting build thread... ";
-    $ENV{'MTR_BUILD_THREAD'} = $mtr_build_thread = mtr_require_unique_id_and_wait("/tmp/mysql-test-ports", 200, 299);
-    print "got ".$mtr_build_thread."\n";
+    $ENV{'DTR_BUILD_THREAD'} = $dtr_build_thread = dtr_require_unique_id_and_wait("/tmp/drizzle-test-ports", 200, 299);
+    print "got ".$dtr_build_thread."\n";
   }
 
-  $mtr_build_thread= (($mtr_build_thread * 10) % 2000) - 1000;
+  $dtr_build_thread= (($dtr_build_thread * 10) % 2000) - 1000;
 
   # Up to two masters, up to three slaves
   # A magic value in command_line_setup depends on these equations.
-  $opt_master_myport=         gimme_a_good_port($mtr_build_thread + 9000); # and 1
+  $opt_master_myport=         gimme_a_good_port($dtr_build_thread + 9000); # and 1
 
 
   $opt_slave_myport=          gimme_a_good_port($opt_master_myport + 2);  # and 3 4
@@ -1134,7 +1134,7 @@
 
   if ( $opt_master_myport < 5001 or $opt_master_myport + 10 >= 32767 )
   {
-    mtr_error("MTR_BUILD_THREAD number results in a port",
+    dtr_error("DTR_BUILD_THREAD number results in a port",
               "outside 5001 - 32767",
               "($opt_master_myport - $opt_master_myport + 10)");
   }
@@ -1163,7 +1163,7 @@
 ##############################################################################
 
 
-sub collect_mysqld_features () {
+sub collect_drizzled_features () {
   my $found_variable_list_start= 0;
   my $tmpdir= tempdir(CLEANUP => 0); # Directory removed by this function
 
@@ -1183,44 +1183,44 @@
     {
       # Look for version
       my $exe_name= basename($exe_drizzled);
-      mtr_verbose("exe_name: $exe_name");
+      dtr_verbose("exe_name: $exe_name");
       if ( $line =~ /^\S*$exe_name\s\sVer\s([0-9]*)\.([0-9]*)\.([0-9]*)/ )
       {
 	#print "Major: $1 Minor: $2 Build: $3\n";
 	$drizzle_version_id= $1*10000 + $2*100 + $3;
 	#print "drizzle_version_id: $drizzle_version_id\n";
-	mtr_report("Drizzle Version $1.$2.$3");
+	dtr_report("Drizzle Version $1.$2.$3");
       }
     }
   }
   rmtree($tmpdir);
-  mtr_error("Could not find version of Drizzle") unless $drizzle_version_id;
+  dtr_error("Could not find version of Drizzle") unless $drizzle_version_id;
 
 }
 
 
 sub run_query($$) {
-  my ($mysqld, $query)= @_;
+  my ($drizzled, $query)= @_;
 
   my $args;
-  mtr_init_args(\$args);
+  dtr_init_args(\$args);
 
-  mtr_add_arg($args, "--no-defaults");
-  mtr_add_arg($args, "--skip-stack-trace");
-  mtr_add_arg($args, "--user=%s", $opt_user);
-  mtr_add_arg($args, "--port=%d", $mysqld->{'port'});
-  mtr_add_arg($args, "--silent"); # Tab separated output
-  mtr_add_arg($args, "-e '%s'", $query);
+  dtr_add_arg($args, "--no-defaults");
+  dtr_add_arg($args, "--skip-stack-trace");
+  dtr_add_arg($args, "--user=%s", $opt_user);
+  dtr_add_arg($args, "--port=%d", $drizzled->{'port'});
+  dtr_add_arg($args, "--silent"); # Tab separated output
+  dtr_add_arg($args, "-e '%s'", $query);
 
   my $cmd= "$exe_drizzle " . join(' ', @$args);
-  mtr_verbose("cmd: $cmd");
+  dtr_verbose("cmd: $cmd");
   return `$cmd`;
 }
 
 
-sub collect_mysqld_features_from_running_server ()
+sub collect_drizzled_features_from_running_server ()
 {
-  my $list= run_query($master->[0], "use mysql; SHOW VARIABLES");
+  my $list= run_query($master->[0], "use drizzle; SHOW VARIABLES");
 
   foreach my $line (split('\n', $list))
   {
@@ -1228,7 +1228,7 @@
     if ( $line =~ /^([\S]+)[ \t]+(.*?)\r?$/ )
     {
       print "$1=\"$2\"\n";
-      $mysqld_variables{$1}= $2;
+      $drizzled_variables{$1}= $2;
     }
   }
 }
@@ -1246,7 +1246,7 @@
     $exe_libtool= "../libtool";
     if ($opt_valgrind or $glob_debugger)
     {
-      mtr_report("Using \"$exe_libtool\" when running valgrind or debugger");
+      dtr_report("Using \"$exe_libtool\" when running valgrind or debugger");
     }
   }
 
@@ -1254,35 +1254,35 @@
   $exe_perror= "perror";
 
 # Look for the client binaries
-  $exe_drizzledump= mtr_exe_exists("$path_client_bindir/drizzledump");
-  $exe_drizzleimport= mtr_exe_exists("$path_client_bindir/drizzleimport");
-  $exe_drizzle=          mtr_exe_exists("$path_client_bindir/drizzle");
+  $exe_drizzledump= dtr_exe_exists("$path_client_bindir/drizzledump");
+  $exe_drizzleimport= dtr_exe_exists("$path_client_bindir/drizzleimport");
+  $exe_drizzle=          dtr_exe_exists("$path_client_bindir/drizzle");
 
   if (!$opt_extern)
   {
 # Look for SQL scripts directory
      if ( $drizzle_version_id >= 50100 )
      {
-         $exe_drizzleslap= mtr_exe_exists("$path_client_bindir/drizzleslap");
+         $exe_drizzleslap= dtr_exe_exists("$path_client_bindir/drizzleslap");
      }
   }
 
 # Look for schema_writer
   {
-    $exe_schemawriter= mtr_exe_exists("$glob_basedir/drizzled/message/schema_writer",
+    $exe_schemawriter= dtr_exe_exists("$glob_basedir/drizzled/message/schema_writer",
                                       "$glob_builddir/drizzled/message/schema_writer");
   }
 
 # Look for drizzletest executable
   {
-    $exe_drizzletest= mtr_exe_exists("$path_client_bindir/drizzletest");
+    $exe_drizzletest= dtr_exe_exists("$path_client_bindir/drizzletest");
   }
 
 # Look for drizzle_client_test executable which may _not_ exist in
 # some versions, test using it should be skipped
   {
     $exe_drizzle_client_test=
-      mtr_exe_maybe_exists(
+      dtr_exe_maybe_exists(
           "$glob_basedir/tests/drizzle_client_test",
           "$glob_basedir/bin/drizzle_client_test");
   }
@@ -1290,25 +1290,25 @@
 # Look for bug25714 executable which may _not_ exist in
 # some versions, test using it should be skipped
   $exe_bug25714=
-    mtr_exe_maybe_exists(
+    dtr_exe_maybe_exists(
         "$glob_basedir/tests/bug25714");
 }
 
 
 
-sub generate_cmdline_mysqldump ($) {
-  my($mysqld) = @_;
+sub generate_cmdline_drizzledump ($) {
+  my($drizzled) = @_;
   return
-    mtr_native_path($exe_drizzledump) .
+    dtr_native_path($exe_drizzledump) .
       " --no-defaults -uroot " .
-      "--port=$mysqld->{'port'} ";
+      "--port=$drizzled->{'port'} ";
 }
 
 sub generate_cmdline_drizzle ($) {
-  my($mysqld) = @_;
+  my($drizzled) = @_;
   return
-    mtr_native_path($exe_drizzle) .
-    " -uroot --port=$mysqld->{'port'} ";
+    dtr_native_path($exe_drizzle) .
+    " -uroot --port=$drizzled->{'port'} ";
 }
 
 
@@ -1324,25 +1324,25 @@
   my $exe= $exe_drizzle_client_test;
 
   my $args;
-  mtr_init_args(\$args);
+  dtr_init_args(\$args);
   if ( $opt_valgrind_drizzletest )
   {
     valgrind_arguments($args, \$exe);
   }
 
-  mtr_add_arg($args, "--no-defaults");
-  mtr_add_arg($args, "--testcase");
-  mtr_add_arg($args, "--user=root");
-  mtr_add_arg($args, "--port=$master->[0]->{'port'}");
+  dtr_add_arg($args, "--no-defaults");
+  dtr_add_arg($args, "--testcase");
+  dtr_add_arg($args, "--user=root");
+  dtr_add_arg($args, "--port=$master->[0]->{'port'}");
 
   if ( $opt_extern || $drizzle_version_id >= 50000 )
   {
-    mtr_add_arg($args, "--vardir=$opt_vardir")
+    dtr_add_arg($args, "--vardir=$opt_vardir")
   }
 
   if ( $opt_debug )
   {
-    mtr_add_arg($args,
+    dtr_add_arg($args,
       "--debug=d:t:A,$path_vardir_trace/log/drizzle_client_test.trace");
   }
 
@@ -1350,7 +1350,7 @@
 }
 
 
-# Note that some env is setup in spawn/run, in "mtr_process.pl"
+# Note that some env is setup in spawn/run, in "dtr_process.pl"
 
 sub environment_setup () {
 
@@ -1389,7 +1389,7 @@
   my $deb_version;
   if (  $opt_valgrind and -d $debug_libraries_path and
         (! -e '/etc/debian_version' or
-	 ($deb_version= mtr_grab_file('/etc/debian_version')) !~ /^[0-9]+\.[0-9]$/ or
+	 ($deb_version= dtr_grab_file('/etc/debian_version')) !~ /^[0-9]+\.[0-9]$/ or
          $deb_version > 3.1 ) )
   {
     push(@ld_library_paths, $debug_libraries_path);
@@ -1399,24 +1399,24 @@
 				$ENV{'LD_LIBRARY_PATH'} ?
 				split(':', $ENV{'LD_LIBRARY_PATH'}) : (),
                                 @ld_library_paths);
-  mtr_debug("LD_LIBRARY_PATH: $ENV{'LD_LIBRARY_PATH'}");
+  dtr_debug("LD_LIBRARY_PATH: $ENV{'LD_LIBRARY_PATH'}");
 
   $ENV{'DYLD_LIBRARY_PATH'}= join(":", @ld_library_paths,
 				  $ENV{'DYLD_LIBRARY_PATH'} ?
 				  split(':', $ENV{'DYLD_LIBRARY_PATH'}) : ());
-  mtr_debug("DYLD_LIBRARY_PATH: $ENV{'DYLD_LIBRARY_PATH'}");
+  dtr_debug("DYLD_LIBRARY_PATH: $ENV{'DYLD_LIBRARY_PATH'}");
 
   # The environment variable used for shared libs on AIX
   $ENV{'SHLIB_PATH'}= join(":", @ld_library_paths,
                            $ENV{'SHLIB_PATH'} ?
                            split(':', $ENV{'SHLIB_PATH'}) : ());
-  mtr_debug("SHLIB_PATH: $ENV{'SHLIB_PATH'}");
+  dtr_debug("SHLIB_PATH: $ENV{'SHLIB_PATH'}");
 
   # The environment variable used for shared libs on hp-ux
   $ENV{'LIBPATH'}= join(":", @ld_library_paths,
                         $ENV{'LIBPATH'} ?
                         split(':', $ENV{'LIBPATH'}) : ());
-  mtr_debug("LIBPATH: $ENV{'LIBPATH'}");
+  dtr_debug("LIBPATH: $ENV{'LIBPATH'}");
 
   # --------------------------------------------------------------------------
   # Also command lines in .opt files may contain env vars
@@ -1427,7 +1427,7 @@
   $ENV{'UMASK_DIR'}=          "0770"; # The octal *string*
   
   #
-  # MySQL tests can produce output in various character sets
+  # drizzle tests can produce output in various character sets
   # (especially, ctype_xxx.test). To avoid confusing Perl
   # with output which is incompatible with the current locale
   # settings, we reset the current values of LC_ALL and LC_CTYPE to "C".
@@ -1439,8 +1439,8 @@
   
   $ENV{'LC_COLLATE'}=         "C";
   $ENV{'USE_RUNNING_SERVER'}= $opt_extern;
-  $ENV{'DRIZZLE_TEST_DIR'}=     collapse_path($glob_mysql_test_dir);
-  $ENV{'MYSQLTEST_VARDIR'}=   $opt_vardir;
+  $ENV{'DRIZZLE_TEST_DIR'}=     collapse_path($glob_drizzle_test_dir);
+  $ENV{'DRIZZLETEST_VARDIR'}=   $opt_vardir;
   $ENV{'TOP_SRCDIR'}= $opt_top_srcdir;
   $ENV{'TOP_BUILDDIR'}= $opt_top_builddir;
   $ENV{'DRIZZLE_TMP_DIR'}=      $opt_tmpdir;
@@ -1453,43 +1453,43 @@
   $ENV{'SLAVE_MYPORT1'}=      $slave->[1]->{'port'};
   $ENV{'SLAVE_MYPORT2'}=      $slave->[2]->{'port'};
   $ENV{'MC_PORT'}=            $opt_memc_myport;
-  $ENV{'DRIZZLE_TCP_PORT'}=     $mysqld_variables{'drizzle-protocol.port'};
-
-  $ENV{'MTR_BUILD_THREAD'}=      $opt_mtr_build_thread;
-
-  $ENV{'EXE_MYSQL'}=          $exe_drizzle;
+  $ENV{'DRIZZLE_TCP_PORT'}=     $drizzled_variables{'drizzle-protocol.port'};
+
+  $ENV{'DTR_BUILD_THREAD'}=      $opt_dtr_build_thread;
+
+  $ENV{'EXE_DRIZZLE'}=          $exe_drizzle;
 
 
   # ----------------------------------------------------
   # Setup env to childs can execute myqldump
   # ----------------------------------------------------
-  my $cmdline_mysqldump= generate_cmdline_mysqldump($master->[0]);
-  my $cmdline_mysqldumpslave= generate_cmdline_mysqldump($slave->[0]);
-  my $cmdline_mysqldump_secondary= mtr_native_path($exe_drizzledump) .
+  my $cmdline_drizzledump= generate_cmdline_drizzledump($master->[0]);
+  my $cmdline_drizzledumpslave= generate_cmdline_drizzledump($slave->[0]);
+  my $cmdline_drizzledump_secondary= dtr_native_path($exe_drizzledump) .
        " --no-defaults -uroot " .
        " --port=$master->[0]->{'secondary_port'} ";
 
   if ( $opt_debug )
   {
-    $cmdline_mysqldump .=
-      " --debug=d:t:A,$path_vardir_trace/log/mysqldump-master.trace";
-    $cmdline_mysqldumpslave .=
-      " --debug=d:t:A,$path_vardir_trace/log/mysqldump-slave.trace";
-    $cmdline_mysqldump_secondary .=
-      " --debug=d:t:A,$path_vardir_trace/log/mysqldump-mysql.trace";
+    $cmdline_drizzledump .=
+      " --debug=d:t:A,$path_vardir_trace/log/drizzledump-master.trace";
+    $cmdline_drizzledumpslave .=
+      " --debug=d:t:A,$path_vardir_trace/log/drizzledump-slave.trace";
+    $cmdline_drizzledump_secondary .=
+      " --debug=d:t:A,$path_vardir_trace/log/drizzledump-drizzle.trace";
   }
-  $ENV{'DRIZZLE_DUMP'}= $cmdline_mysqldump;
-  $ENV{'DRIZZLE_DUMP_SLAVE'}= $cmdline_mysqldumpslave;
-  $ENV{'DRIZZLE_DUMP_SECONDARY'}= $cmdline_mysqldump_secondary;
+  $ENV{'DRIZZLE_DUMP'}= $cmdline_drizzledump;
+  $ENV{'DRIZZLE_DUMP_SLAVE'}= $cmdline_drizzledumpslave;
+  $ENV{'DRIZZLE_DUMP_SECONDARY'}= $cmdline_drizzledump_secondary;
 
   # ----------------------------------------------------
   # Setup env so we can execute drizzle client
   # ----------------------------------------------------
-  my $cmdline_drizzle = generate_cmdline_drizzle($master->[0]);
-  $ENV{'DRIZZLE'}= $cmdline_drizzle;
+  #my $cmdline_drizzle = generate_cmdline_drizzle($master->[0]);
+  #$ENV{'DRIZZLE'}= $cmdline_drizzle;
 
   # ----------------------------------------------------
-  # Setup env so childs can execute mysqlslap
+  # Setup env so childs can execute drizzleslap
   # ----------------------------------------------------
   if ( $exe_drizzleslap )
   {
@@ -1500,11 +1500,11 @@
       $cmdline_drizzleslap= "$glob_basedir/libtool --mode=execute valgrind --log-file=$opt_vardir/log/drizzleslap-valgrind.log ";
     }
     $cmdline_drizzleslap .=
-      mtr_native_path($exe_drizzleslap) .
+      dtr_native_path($exe_drizzleslap) .
       " -uroot " .
       "--port=$master->[0]->{'port'} ";
     my $cmdline_drizzleslap_secondary=
-      mtr_native_path($exe_drizzleslap) .
+      dtr_native_path($exe_drizzleslap) .
       " -uroot " .
       " --port=$master->[0]->{'secondary_port'} ";
 
@@ -1522,34 +1522,34 @@
 
 
   # ----------------------------------------------------
-  # Setup env so childs can execute mysqlimport
+  # Setup env so childs can execute drizzleimport
   # ----------------------------------------------------
-  my $cmdline_mysqlimport=
-    mtr_native_path($exe_drizzleimport) .
+  my $cmdline_drizzleimport=
+    dtr_native_path($exe_drizzleimport) .
     " -uroot " .
     "--port=$master->[0]->{'port'} ";
 
   if ( $opt_debug )
   {
-    $cmdline_mysqlimport .=
-      " --debug=d:t:A,$path_vardir_trace/log/mysqlimport.trace";
+    $cmdline_drizzleimport .=
+      " --debug=d:t:A,$path_vardir_trace/log/drizzleimport.trace";
   }
-  $ENV{'DRIZZLE_IMPORT'}= $cmdline_mysqlimport;
-
-
-  # ----------------------------------------------------
-  # Setup env so childs can execute mysql
-  # ----------------------------------------------------
-  my $cmdline_mysql=
-    mtr_native_path($exe_drizzle) .
+  $ENV{'DRIZZLE_IMPORT'}= $cmdline_drizzleimport;
+
+
+  # ----------------------------------------------------
+  # Setup env so childs can execute drizzle
+  # ----------------------------------------------------
+  my $cmdline_drizzle=
+    dtr_native_path($exe_drizzle) .
     " --no-defaults --host=localhost  --user=root --password= " .
     "--port=$master->[0]->{'port'} ";
   my $cmdline_drizzle_secondary=
-    mtr_native_path($exe_drizzle) .
+    dtr_native_path($exe_drizzle) .
     " --no-defaults --host=localhost  --user=root --password= " .
     " --port=$master->[0]->{'secondary_port'} ";
 
-  $ENV{'MYSQL'}= $cmdline_mysql;
+  $ENV{'DRIZZLE'}= $cmdline_drizzle;
   $ENV{'DRIZZLE_SECONDARY'}= $cmdline_drizzle_secondary;
 
   # ----------------------------------------------------
@@ -1564,32 +1564,32 @@
 
 
   # ----------------------------------------------------
-  # Setup env so childs can execute mysql_fix_system_tables
+  # Setup env so childs can execute drizzle_fix_system_tables
   # ----------------------------------------------------
   #if ( !$opt_extern)
   if ( 0 )
   {
-    my $cmdline_mysql_fix_system_tables=
+    my $cmdline_drizzle_fix_system_tables=
       "$exe_drizzle_fix_system_tables --no-defaults --host=localhost " .
       "--user=root --password= " .
       "--basedir=$glob_basedir --bindir=$path_client_bindir --verbose " .
       "--port=$master->[0]->{'port'} ";
-    $ENV{'DRIZZLE_FIX_SYSTEM_TABLES'}=  $cmdline_mysql_fix_system_tables;
+    $ENV{'DRIZZLE_FIX_SYSTEM_TABLES'}=  $cmdline_drizzle_fix_system_tables;
 
   }
 
   # ----------------------------------------------------
   # Setup env so childs can shutdown the server
   # ----------------------------------------------------
-  $ENV{'DRIZZLED_SHUTDOWN'}= mtr_native_path($exe_drizzle);
+  $ENV{'DRIZZLED_SHUTDOWN'}= dtr_native_path($exe_drizzle);
 
   # ----------------------------------------------------
   # Setup env so childs can execute perror  
   # ----------------------------------------------------
-  $ENV{'MY_PERROR'}= mtr_native_path($exe_perror);
+  $ENV{'MY_PERROR'}= dtr_native_path($exe_perror);
 
   # ----------------------------------------------------
-  # Add the path where mysqld will find ha_example.so
+  # Add the path where drizzled will find ha_example.so
   # ----------------------------------------------------
   $ENV{'EXAMPLE_PLUGIN'}=
     ($lib_example_plugin ? basename($lib_example_plugin) : "");
@@ -1601,7 +1601,7 @@
   # ----------------------------------------------------
   if (!$opt_extern)
   {
-    print "Using MTR_BUILD_THREAD      = $ENV{MTR_BUILD_THREAD}\n";
+    print "Using DTR_BUILD_THREAD      = $ENV{DTR_BUILD_THREAD}\n";
     print "Using MASTER_MYPORT         = $ENV{MASTER_MYPORT}\n";
     print "Using MASTER_MYPORT1        = $ENV{MASTER_MYPORT1}\n";
     print "Using SLAVE_MYPORT          = $ENV{SLAVE_MYPORT}\n";
@@ -1631,9 +1631,9 @@
 
 sub handle_int_signal () {
   $SIG{INT}= 'DEFAULT';         # If we get a ^C again, we die...
-  mtr_warning("got INT signal, cleaning up.....");
+  dtr_warning("got INT signal, cleaning up.....");
   stop_all_servers();
-  mtr_error("We die from ^C signal from user");
+  dtr_error("We die from ^C signal from user");
 }
 
 
@@ -1645,11 +1645,11 @@
 
 sub kill_running_servers () {
   {
-    # Ensure that no old mysqld test servers are running
+    # Ensure that no old drizzled test servers are running
     # This is different from terminating processes we have
     # started from this run of the script, this is terminating
     # leftovers from previous runs.
-    mtr_kill_leftovers();
+    dtr_kill_leftovers();
    }
 }
 
@@ -1659,17 +1659,17 @@
 #
 sub remove_stale_vardir () {
 
-  mtr_report("Removing Stale Files");
+  dtr_report("Removing Stale Files");
 
   # Safety!
-  mtr_error("No, don't remove the vardir when running with --extern")
+  dtr_error("No, don't remove the vardir when running with --extern")
     if $opt_extern;
 
-  mtr_verbose("opt_vardir: $opt_vardir");
+  dtr_verbose("opt_vardir: $opt_vardir");
   if ( $opt_vardir eq $default_vardir )
   {
     #
-    # Running with "var" in mysql-test dir
+    # Running with "var" in drizzle-test dir
     #
     if ( -l $opt_vardir)
     {
@@ -1678,44 +1678,44 @@
       if ( $opt_mem and readlink($opt_vardir) eq $opt_mem )
       {
 	# Remove the directory which the link points at
-	mtr_verbose("Removing " . readlink($opt_vardir));
-	mtr_rmtree(readlink($opt_vardir));
+	dtr_verbose("Removing " . readlink($opt_vardir));
+	dtr_rmtree(readlink($opt_vardir));
 
 	# Remove the "var" symlink
-	mtr_verbose("unlink($opt_vardir)");
+	dtr_verbose("unlink($opt_vardir)");
 	unlink($opt_vardir);
       }
       elsif ( $opt_mem )
       {
 	# Just remove the "var" symlink
-	mtr_report("WARNING: Removing '$opt_vardir' symlink it's wrong");
+	dtr_report("WARNING: Removing '$opt_vardir' symlink it's wrong");
 
-	mtr_verbose("unlink($opt_vardir)");
+	dtr_verbose("unlink($opt_vardir)");
 	unlink($opt_vardir);
       }
       else
       {
-	# Some users creates a soft link in mysql-test/var to another area
+	# Some users creates a soft link in drizzle-test/var to another area
 	# - allow it, but remove all files in it
 
-	mtr_report("WARNING: Using the 'mysql-test/var' symlink");
+	dtr_report("WARNING: Using the 'drizzle-test/var' symlink");
 
 	# Make sure the directory where it points exist
-	mtr_error("The destination for symlink $opt_vardir does not exist")
+	dtr_error("The destination for symlink $opt_vardir does not exist")
 	  if ! -d readlink($opt_vardir);
 
 	foreach my $bin ( glob("$opt_vardir/*") )
 	{
-	  mtr_verbose("Removing bin $bin");
-	  mtr_rmtree($bin);
+	  dtr_verbose("Removing bin $bin");
+	  dtr_rmtree($bin);
 	}
       }
     }
     else
     {
       # Remove the entire "var" dir
-      mtr_verbose("Removing $opt_vardir/");
-      mtr_rmtree("$opt_vardir/");
+      dtr_verbose("Removing $opt_vardir/");
+      dtr_rmtree("$opt_vardir/");
     }
 
     if ( $opt_mem )
@@ -1723,8 +1723,8 @@
       # A symlink from var/ to $opt_mem will be set up
       # remove the $opt_mem dir to assure the symlink
       # won't point at an old directory
-      mtr_verbose("Removing $opt_mem");
-      mtr_rmtree($opt_mem);
+      dtr_verbose("Removing $opt_mem");
+      dtr_rmtree($opt_mem);
     }
 
   }
@@ -1734,14 +1734,14 @@
     # Running with "var" in some other place
     #
 
-    # Remove the var/ dir in mysql-test dir if any
+    # Remove the var/ dir in drizzle-test dir if any
     # this could be an old symlink that shouldn't be there
-    mtr_verbose("Removing $default_vardir");
-    mtr_rmtree($default_vardir);
+    dtr_verbose("Removing $default_vardir");
+    dtr_rmtree($default_vardir);
 
     # Remove the "var" dir
-    mtr_verbose("Removing $opt_vardir/");
-    mtr_rmtree("$opt_vardir/");
+    dtr_verbose("Removing $opt_vardir/");
+    dtr_rmtree("$opt_vardir/");
   }
 }
 
@@ -1749,42 +1749,42 @@
 # Create var and the directories needed in var
 #
 sub setup_vardir() {
-  mtr_report("Creating Directories");
+  dtr_report("Creating Directories");
 
   if ( $opt_vardir eq $default_vardir )
   {
     #
-    # Running with "var" in mysql-test dir
+    # Running with "var" in drizzle-test dir
     #
     if ( -l $opt_vardir )
     {
       #  it's a symlink
 
       # Make sure the directory where it points exist
-      mtr_error("The destination for symlink $opt_vardir does not exist")
+      dtr_error("The destination for symlink $opt_vardir does not exist")
 	if ! -d readlink($opt_vardir);
     }
     elsif ( $opt_mem )
     {
       # Runinng with "var" as a link to some "memory" location, normally tmpfs
-      mtr_verbose("Creating $opt_mem");
+      dtr_verbose("Creating $opt_mem");
       mkpath($opt_mem);
 
-      mtr_report("Symlinking 'var' to '$opt_mem'");
+      dtr_report("Symlinking 'var' to '$opt_mem'");
       symlink($opt_mem, $opt_vardir);
     }
   }
 
   if ( ! -d $opt_vardir )
   {
-    mtr_verbose("Creating $opt_vardir");
+    dtr_verbose("Creating $opt_vardir");
     mkpath($opt_vardir);
   }
 
   # Ensure a proper error message if vardir couldn't be created
   unless ( -d $opt_vardir and -w $opt_vardir )
   {
-    mtr_error("Writable 'var' directory is needed, use the " .
+    dtr_error("Writable 'var' directory is needed, use the " .
 	      "'--vardir=<path>' option");
   }
 
@@ -1796,7 +1796,7 @@
   # Create new data dirs
   foreach my $data_dir (@data_dir_lst)
   {
-    mkpath("$data_dir/local/mysql");
+    mkpath("$data_dir/local/drizzle");
     system("$exe_schemawriter mysql $data_dir/local/mysql/db.opt");
 
     mkpath("$data_dir/local/test");
@@ -1804,7 +1804,7 @@
   }
 
   # Make a link std_data_ln in var/ that points to std_data
-  symlink(collapse_path("$glob_mysql_test_dir/std_data"),
+  symlink(collapse_path("$glob_drizzle_test_dir/std_data"),
           "$opt_vardir/std_data_ln");
 
   symlink(collapse_path("$glob_suite_path/filesystem_engine/tests/t"),
@@ -1826,7 +1826,7 @@
   # Check if running as root
   # i.e a file can be read regardless what mode we set it to
   my $test_file= "$opt_vardir/test_running_as_root.txt";
-  mtr_tofile($test_file, "MySQL");
+  dtr_tofile($test_file, "Drizzle");
   chmod(oct("0000"), $test_file);
 
   my $result="";
@@ -1842,10 +1842,10 @@
   my $file_mode= (stat($test_file))[2] & 07777;
 
   $ENV{'DRIZZLE_TEST_ROOT'}= "NO";
-  mtr_verbose("result: $result, file_mode: $file_mode");
-  if ($result eq "MySQL" && $file_mode == 0)
+  dtr_verbose("result: $result, file_mode: $file_mode");
+  if ($result eq "Drizzle" && $file_mode == 0)
   {
-    mtr_warning("running this script as _root_ will cause some " .
+    dtr_warning("running this script as _root_ will cause some " .
                 "tests to be skipped");
     $ENV{'DRIZZLE_TEST_ROOT'}= "YES";
   }
@@ -1857,20 +1857,20 @@
 
 
 sub check_debug_support ($) {
-  my $mysqld_variables= shift;
+  my $drizzled_variables= shift;
 
-  if ( ! $mysqld_variables->{'debug'} )
+  if ( ! $drizzled_variables->{'debug'} )
   {
-    #mtr_report("Binaries are not debug compiled");
+    #dtr_report("Binaries are not debug compiled");
     $debug_compiled_binaries= 0;
 
     if ( $opt_debug )
     {
-      mtr_error("Can't use --debug, binaries does not support it");
+      dtr_error("Can't use --debug, binaries does not support it");
     }
     return;
   }
-  mtr_report("Binaries are debug compiled");
+  dtr_report("Binaries are debug compiled");
   $debug_compiled_binaries= 1;
 }
 
@@ -1887,42 +1887,42 @@
   my $args;
 
   {
-    mysqld_start($master->[0],[],[]);
+    drizzled_start($master->[0],[],[]);
     if ( ! $master->[0]->{'pid'} )
     {
-      mtr_error("Can't start the mysqld server");
+      dtr_error("Can't start the drizzled server");
     }
   }
 
-  mtr_init_args(\$args);
+  dtr_init_args(\$args);
 
-  mtr_add_arg($args, "--user=%s", $opt_user);
+  dtr_add_arg($args, "--user=%s", $opt_user);
 
   if ( $opt_small_bench )
   {
-    mtr_add_arg($args, "--small-test");
-    mtr_add_arg($args, "--small-tables");
+    dtr_add_arg($args, "--small-test");
+    dtr_add_arg($args, "--small-tables");
   }
 
-  chdir($glob_mysql_bench_dir)
-    or mtr_error("Couldn't chdir to '$glob_mysql_bench_dir': $!");
+  chdir($glob_drizzle_bench_dir)
+    or dtr_error("Couldn't chdir to '$glob_drizzle_bench_dir': $!");
 
   if ( ! $benchmark )
   {
-    mtr_run("$glob_mysql_bench_dir/run-all-tests", $args, "", "", "", "");
+    dtr_run("$glob_drizzle_bench_dir/run-all-tests", $args, "", "", "", "");
     # FIXME check result code?!
   }
   elsif ( -x $benchmark )
   {
-    mtr_run("$glob_mysql_bench_dir/$benchmark", $args, "", "", "", "");
+    dtr_run("$glob_drizzle_bench_dir/$benchmark", $args, "", "", "", "");
     # FIXME check result code?!
   }
   else
   {
-    mtr_error("Benchmark $benchmark not found");
+    dtr_error("Benchmark $benchmark not found");
   }
 
-  chdir($glob_mysql_test_dir);          # Go back
+  chdir($glob_drizzle_test_dir);          # Go back
 
   {
     stop_masters();
@@ -1939,13 +1939,13 @@
 sub run_tests () {
   my ($tests)= @_;
 
-  mtr_print_thick_line();
-
-  mtr_timer_start($glob_timers,"suite", 60 * $opt_suite_timeout);
-
-  mtr_report_tests_not_skipped_though_disabled($tests);
-
-  mtr_print_header();
+  dtr_print_thick_line();
+
+  dtr_timer_start($glob_timers,"suite", 60 * $opt_suite_timeout);
+
+  dtr_report_tests_not_skipped_though_disabled($tests);
+
+  dtr_print_header();
 
   foreach my $tinfo ( @$tests )
   {
@@ -1956,13 +1956,13 @@
 	  next;
 	}
 
-      mtr_timer_start($glob_timers,"testcase", 60 * $opt_testcase_timeout);
+      dtr_timer_start($glob_timers,"testcase", 60 * $opt_testcase_timeout);
       run_testcase($tinfo);
-      mtr_timer_stop($glob_timers,"testcase");
+      dtr_timer_stop($glob_timers,"testcase");
     }
   }
 
-  mtr_print_line();
+  dtr_print_line();
 
   if ( ! $glob_debugger and
        ! $opt_extern )
@@ -1979,9 +1979,9 @@
     gprof_collect(); # collect coverage information
   }
 
-  mtr_report_stats($tests);
+  dtr_report_stats($tests);
 
-  mtr_timer_stop($glob_timers,"suite");
+  dtr_timer_stop($glob_timers,"suite");
 }
 
 
@@ -2001,12 +2001,12 @@
     # vardir does not already exist it should be created
     if ( ! -d $opt_vardir )
     {
-      mtr_report("Creating '$opt_vardir'");
+      dtr_report("Creating '$opt_vardir'");
       setup_vardir();
     }
     else
     {
-      mtr_verbose("No need to create '$opt_vardir' it already exists");
+      dtr_verbose("No need to create '$opt_vardir' it already exists");
     }
   }
   else
@@ -2018,7 +2018,7 @@
       remove_stale_vardir();
       setup_vardir();
 
-      mysql_install_db();
+      drizzle_install_db();
       if ( $opt_force )
       {
 	# Save a snapshot of the freshly installed db
@@ -2029,11 +2029,11 @@
   }
   check_running_as_root();
 
-  mtr_log_init("$opt_vardir/log/drizzle-test-run.log");
+  dtr_log_init("$opt_vardir/log/drizzle-test-run.log");
 
 }
 
-sub mysql_install_db () {
+sub drizzle_install_db () {
 
   if ($max_master_num > 1)
   {
@@ -2054,10 +2054,10 @@
   my $type=      shift;
   my $data_dir=  shift;
 
-  mtr_report("Installing \u$type Database");
+  dtr_report("Installing \u$type Database");
 
   # Just copy the installed db from first master
-  mtr_copy_dir($master->[0]->{'path_myddir'}, $data_dir);
+  dtr_copy_dir($master->[0]->{'path_myddir'}, $data_dir);
 
 }
 
@@ -2075,8 +2075,8 @@
     {
       my $data_dir= $slave->[$idx]->{'path_myddir'};
       my $name= basename($data_dir);
-      mtr_rmtree($data_dir);
-      mtr_copy_dir("$path_snapshot/$name", $data_dir);
+      dtr_rmtree($data_dir);
+      dtr_copy_dir("$path_snapshot/$name", $data_dir);
     }
   }
 }
@@ -2095,8 +2095,8 @@
 
   if ( $tinfo->{'skip'} )
   {
-    mtr_report_test_name($tinfo);
-    mtr_report_test_skipped($tinfo);
+    dtr_report_test_name($tinfo);
+    dtr_report_test_skipped($tinfo);
     return 1;
   }
 
@@ -2110,7 +2110,7 @@
   my $args;
 
   # Remove old files produced by drizzletest
-  my $base_file= mtr_match_extension($tinfo->{'result_file'},
+  my $base_file= dtr_match_extension($tinfo->{'result_file'},
 				    "result"); # Trim extension
   unlink("$base_file.reject");
   unlink("$base_file.progress");
@@ -2124,9 +2124,9 @@
   my $tinfo= shift;
 
   # Save info from this testcase run to drizzletest.log
-  mtr_appendfile_to_file($path_current_test_log, $path_drizzletest_log)
+  dtr_appendfile_to_file($path_current_test_log, $path_drizzletest_log)
     if -f $path_current_test_log;
-  mtr_appendfile_to_file($path_timefile, $path_drizzletest_log)
+  dtr_appendfile_to_file($path_timefile, $path_drizzletest_log)
     if -f $path_timefile;
 }
 
@@ -2138,12 +2138,12 @@
   # Write a marker to all log files
 
   # The file indicating current test name
-  mtr_tonewfile($path_current_test_log, $log_msg);
+  dtr_tonewfile($path_current_test_log, $log_msg);
 
-  # each mysqld's .err file
-  foreach my $mysqld (@{$master}, @{$slave})
+  # each drizzled's .err file
+  foreach my $drizzled (@{$master}, @{$slave})
   {
-    mtr_tofile($mysqld->{path_myerr}, $log_msg);
+    dtr_tofile($drizzled->{path_myerr}, $log_msg);
   }
 
 }
@@ -2171,7 +2171,7 @@
 
   if ( ! $reason )
   {
-    mtr_warning("Could not find reason for skipping test in $path_timefile");
+    dtr_warning("Could not find reason for skipping test in $path_timefile");
     $reason= "Detected by testcase(reason unknown) ";
   }
   $tinfo->{'comment'}= $reason;
@@ -2191,7 +2191,7 @@
 
 # We don't start and kill the servers for each testcase. But some
 # testcases needs a restart, because they specify options to start
-# mysqld with. After that testcase, we need to restart again, to set
+# drizzled with. After that testcase, we need to restart again, to set
 # back the normal options.
 
 sub run_testcase ($) {
@@ -2202,7 +2202,7 @@
   # -------------------------------------------------------
 
   $ENV{'TZ'}= $tinfo->{'timezone'};
-  mtr_verbose("Setting timezone: $tinfo->{'timezone'}");
+  dtr_verbose("Setting timezone: $tinfo->{'timezone'}");
 
   my $master_restart= run_testcase_need_master_restart($tinfo);
   my $slave_restart= run_testcase_need_slave_restart($tinfo);
@@ -2212,9 +2212,9 @@
     # Can't restart a running server that may be in use
     if ( $opt_extern )
     {
-      mtr_report_test_name($tinfo);
+      dtr_report_test_name($tinfo);
       $tinfo->{comment}= "Can't restart a running server";
-      mtr_report_test_skipped($tinfo);
+      dtr_report_test_skipped($tinfo);
       return;
     }
 
@@ -2224,12 +2224,12 @@
   # Write to all log files to indicate start of testcase
   run_testcase_mark_logs($tinfo, "CURRENT_TEST: $tinfo->{name}\n");
 
-  my $died= mtr_record_dead_children();
+  my $died= dtr_record_dead_children();
   if ($died or $master_restart or $slave_restart)
   {
     if (run_testcase_start_servers($tinfo))
     {
-      mtr_report_test_name($tinfo);
+      dtr_report_test_name($tinfo);
       report_failure_and_restart($tinfo);
       return 1;
     }
@@ -2240,8 +2240,8 @@
   # ----------------------------------------------------------------------
   if ( $opt_start_and_exit or $opt_start_dirty )
   {
-    mtr_timer_stop_all($glob_timers);
-    mtr_report("\nServers started, exiting");
+    dtr_timer_stop_all($glob_timers);
+    dtr_report("\nServers started, exiting");
     exit(0);
   }
 
@@ -2249,13 +2249,13 @@
     do_before_run_drizzletest($tinfo);
 
     my $res= run_drizzletest($tinfo);
-    mtr_report_test_name($tinfo);
+    dtr_report_test_name($tinfo);
 
     do_after_run_drizzletest($tinfo);
 
     if ( $res == 0 )
     {
-      mtr_report_test_passed($tinfo);
+      dtr_report_test_passed($tinfo);
     }
     elsif ( $res == 62 )
     {
@@ -2263,7 +2263,7 @@
 
       # Try to get reason from drizzletest.log
       find_testcase_skipped_reason($tinfo);
-      mtr_report_test_skipped($tinfo);
+      dtr_report_test_skipped($tinfo);
     }
     elsif ( $res == 63 )
     {
@@ -2299,13 +2299,13 @@
 #
 sub save_installed_db () {
 
-  mtr_report("Saving snapshot of installed databases");
-  mtr_rmtree($path_snapshot);
+  dtr_report("Saving snapshot of installed databases");
+  dtr_rmtree($path_snapshot);
 
   foreach my $data_dir (@data_dir_lst)
   {
     my $name= basename($data_dir);
-    mtr_copy_dir("$data_dir", "$path_snapshot/$name");
+    dtr_copy_dir("$data_dir", "$path_snapshot/$name");
   }
 }
 
@@ -2324,7 +2324,7 @@
   {
     last if $opt_max_save_core > 0 && $num_saved_cores >= $opt_max_save_core;
     my $core_name= basename($core_file);
-    mtr_report("Saving $core_name");
+    dtr_report("Saving $core_name");
     mkdir($save_name) if ! -d $save_name;
     rename("$core_file", "$save_name/$core_name");
     ++$num_saved_cores;
@@ -2341,27 +2341,27 @@
 
   if ( -d $path_snapshot)
   {
-    mtr_report("Restoring snapshot of databases");
+    dtr_report("Restoring snapshot of databases");
 
     foreach my $data_dir (@data_dir_lst)
     {
       my $name= basename($data_dir);
       save_files_before_restore($test_name, $data_dir);
-      mtr_rmtree("$data_dir");
-      mtr_copy_dir("$path_snapshot/$name", "$data_dir");
+      dtr_rmtree("$data_dir");
+      dtr_copy_dir("$path_snapshot/$name", "$data_dir");
     }
   }
   else
   {
     # No snapshot existed
-    mtr_error("No snapshot existed");
+    dtr_error("No snapshot existed");
   }
 }
 
 sub report_failure_and_restart ($) {
   my $tinfo= shift;
 
-  mtr_report_test_failed($tinfo);
+  dtr_report_test_failed($tinfo);
   print "\n";
   if ( $opt_force )
   {
@@ -2370,19 +2370,19 @@
 
     # Restore the snapshot of the installed test db
     restore_installed_db($tinfo->{'name'});
-    mtr_report("Resuming Tests\n");
+    dtr_report("Resuming Tests\n");
     return;
   }
 
   my $test_mode= join(" ", @::glob_test_mode) || "default";
-  mtr_report("Aborting: $tinfo->{'name'} failed in $test_mode mode. ");
-  mtr_report("To continue, re-run with '--force'.");
+  dtr_report("Aborting: $tinfo->{'name'} failed in $test_mode mode. ");
+  dtr_report("To continue, re-run with '--force'.");
   if ( ! $glob_debugger and
        ! $opt_extern )
   {
     stop_all_servers();
   }
-  mtr_exit(1);
+  dtr_exit(1);
 
 }
 
@@ -2394,11 +2394,11 @@
   # Run master initialization shell script if one exists
   if ( $init_script )
   {
-    my $ret= mtr_run("/bin/sh", [$init_script], "", "", "", "");
+    my $ret= dtr_run("/bin/sh", [$init_script], "", "", "", "");
     if ( $ret != 0 )
     {
       # FIXME rewrite those scripts to return 0 if successful
-      # mtr_warning("$init_script exited with code $ret");
+      # dtr_warning("$init_script exited with code $ret");
     }
   }
 }
@@ -2457,11 +2457,11 @@
   # Run slave initialization shell script if one exists
   if ( $init_script )
   {
-    my $ret= mtr_run("/bin/sh", [$init_script], "", "", "", "");
+    my $ret= dtr_run("/bin/sh", [$init_script], "", "", "", "");
     if ( $ret != 0 )
     {
       # FIXME rewrite those scripts to return 0 if successful
-      # mtr_warning("$init_script exited with code $ret");
+      # dtr_warning("$init_script exited with code $ret");
     }
   }
 
@@ -2472,13 +2472,13 @@
 }
 
 
-sub mysqld_arguments ($$$$) {
+sub drizzled_arguments ($$$$) {
   my $args=              shift;
-  my $mysqld=            shift;
+  my $drizzled=            shift;
   my $extra_opt=         shift;
   my $slave_master_info= shift;
 
-  my $idx= $mysqld->{'idx'};
+  my $idx= $drizzled->{'idx'};
   my $sidx= "";                 # Index as string, 0 is empty string
   if ( $idx> 0 )
   {
@@ -2487,60 +2487,60 @@
 
   my $prefix= "";               # If drizzletest server arg
 
-  mtr_add_arg($args, "%s--no-defaults", $prefix);
+  dtr_add_arg($args, "%s--no-defaults", $prefix);
 
   if ($opt_engine)
   {
-    mtr_add_arg($args, "%s--default-storage-engine=%s", $prefix, $opt_engine);
+    dtr_add_arg($args, "%s--default-storage-engine=%s", $prefix, $opt_engine);
   }
 
   if ( $drizzle_version_id >= 50036)
   {
-    # By default, prevent the started mysqld to access files outside of vardir
-    mtr_add_arg($args, "%s--secure-file-priv=%s", $prefix, $opt_vardir);
+    # By default, prevent the started drizzled to access files outside of vardir
+    dtr_add_arg($args, "%s--secure-file-priv=%s", $prefix, $opt_vardir);
   }
 
-  mtr_add_arg($args, "%s--tmpdir=$opt_tmpdir", $prefix);
+  dtr_add_arg($args, "%s--tmpdir=$opt_tmpdir", $prefix);
 
   # Increase default connect_timeout to avoid intermittent
   # disconnects when test servers are put under load
   # see BUG#28359
-  mtr_add_arg($args, "%s--mysql-protocol.connect-timeout=60", $prefix);
-
-
-  # When mysqld is run by a root user(euid is 0), it will fail
+  dtr_add_arg($args, "%s--mysql-protocol.connect-timeout=60", $prefix);
+
+
+  # When drizzled is run by a root user(euid is 0), it will fail
   # to start unless we specify what user to run as, see BUG#30630
   my $euid= $>;
-  if (grep(/^--user/, @$extra_opt, @opt_extra_mysqld_opt) == 0) {
-    mtr_add_arg($args, "%s--user=root", $prefix);
+  if (grep(/^--user/, @$extra_opt, @opt_extra_drizzled_opt) == 0) {
+    dtr_add_arg($args, "%s--user=root", $prefix);
   }
 
-  mtr_add_arg($args, "%s--pid-file=%s", $prefix,
-	      $mysqld->{'path_pid'});
-
-  mtr_add_arg($args, "%s--mysql-protocol.port=%d", $prefix,
-              $mysqld->{'port'});
-
-  mtr_add_arg($args, "%s--drizzle-protocol.port=%d", $prefix,
-              $mysqld->{'secondary_port'});
-
-  mtr_add_arg($args, "%s--datadir=%s", $prefix,
-	      $mysqld->{'path_myddir'});
+  dtr_add_arg($args, "%s--pid-file=%s", $prefix,
+	      $drizzled->{'path_pid'});
+
+  dtr_add_arg($args, "%s--mysql-protocol.port=%d", $prefix,
+              $drizzled->{'port'});
+
+  dtr_add_arg($args, "%s--mysql-protocol.port=%d", $prefix,
+              $drizzled->{'secondary_port'});
+
+  dtr_add_arg($args, "%s--datadir=%s", $prefix,
+	      $drizzled->{'path_myddir'});
 
   # Check if "extra_opt" contains --skip-log-bin
-  if ( $mysqld->{'type'} eq 'master' )
+  if ( $drizzled->{'type'} eq 'master' )
   {
-    mtr_add_arg($args, "%s--server-id=%d", $prefix,
+    dtr_add_arg($args, "%s--server-id=%d", $prefix,
 	       $idx > 0 ? $idx + 101 : 1);
 
-    mtr_add_arg($args,
+    dtr_add_arg($args,
       "%s--innodb.data-file-path=ibdata1:20M:autoextend", $prefix);
 
   }
   else
   {
-    mtr_error("unknown mysqld type")
-      unless $mysqld->{'type'} eq 'slave';
+    dtr_error("unknown drizzled type")
+      unless $drizzled->{'type'} eq 'slave';
 
     # Directory where slaves find the dumps generated by "load data"
     # on the server. The path need to have constant length otherwise
@@ -2551,39 +2551,39 @@
     {
       foreach my $arg ( @$slave_master_info )
       {
-        mtr_add_arg($args, "%s%s", $prefix, $arg);
+        dtr_add_arg($args, "%s%s", $prefix, $arg);
       }
     }
     else
     {
       my $slave_server_id=  2 + $idx;
       my $slave_rpl_rank= $slave_server_id;
-      mtr_add_arg($args, "%s--server-id=%d", $prefix, $slave_server_id);
+      dtr_add_arg($args, "%s--server-id=%d", $prefix, $slave_server_id);
     }
   } # end slave
 
   if ( $opt_debug )
   {
-    mtr_add_arg($args, "%s--debug=d:t:i:A,%s/log/%s%s.trace",
-                $prefix, $path_vardir_trace, $mysqld->{'type'}, $sidx);
+    dtr_add_arg($args, "%s--debug=d:t:i:A,%s/log/%s%s.trace",
+                $prefix, $path_vardir_trace, $drizzled->{'type'}, $sidx);
   }
 
-  mtr_add_arg($args, "%s--sort-buffer-size=256K", $prefix);
-  mtr_add_arg($args, "%s--max-heap-table-size=1M", $prefix);
+  dtr_add_arg($args, "%s--sort-buffer-size=256K", $prefix);
+  dtr_add_arg($args, "%s--max-heap-table-size=1M", $prefix);
 
   if ( $opt_warnings )
   {
-    mtr_add_arg($args, "%s--log-warnings", $prefix);
+    dtr_add_arg($args, "%s--log-warnings", $prefix);
   }
 
-  # Indicate to "mysqld" it will be debugged in debugger
+  # Indicate to "drizzled" it will be debugged in debugger
   if ( $glob_debugger )
   {
-    mtr_add_arg($args, "%s--gdb", $prefix);
+    dtr_add_arg($args, "%s--gdb", $prefix);
   }
 
   my $found_skip_core= 0;
-  foreach my $arg ( @opt_extra_mysqld_opt, @$extra_opt )
+  foreach my $arg ( @opt_extra_drizzled_opt, @$extra_opt )
   {
     # Allow --skip-core-file to be set in <testname>-[master|slave].opt file
     if ($arg eq "--skip-core-file")
@@ -2592,12 +2592,12 @@
     }
     else
     {
-      mtr_add_arg($args, "%s%s", $prefix, $arg);
+      dtr_add_arg($args, "%s%s", $prefix, $arg);
     }
   }
   if ( !$found_skip_core )
   {
-    mtr_add_arg($args, "%s%s", $prefix, "--core-file");
+    dtr_add_arg($args, "%s%s", $prefix, "--core-file");
   }
 
   return $args;
@@ -2606,12 +2606,12 @@
 
 ##############################################################################
 #
-#  Start mysqld and return the PID
+#  Start drizzled and return the PID
 #
 ##############################################################################
 
-sub mysqld_start ($$$) {
-  my $mysqld=            shift;
+sub drizzled_start ($$$) {
+  my $drizzled=            shift;
   my $extra_opt=         shift;
   my $slave_master_info= shift;
 
@@ -2620,30 +2620,30 @@
   my $pid= -1;
   my $wait_for_pid_file= 1;
 
-  my $type= $mysqld->{'type'};
-  my $idx= $mysqld->{'idx'};
+  my $type= $drizzled->{'type'};
+  my $idx= $drizzled->{'idx'};
 
   if ( $type eq 'master' )
   {
-    $exe= $exe_master_mysqld;
+    $exe= $exe_master_drizzled;
   }
   elsif ( $type eq 'slave' )
   {
-    $exe= $exe_slave_mysqld;
+    $exe= $exe_slave_drizzled;
   }
   else
   {
-    mtr_error("Unknown 'type' \"$type\" passed to mysqld_start");
+    dtr_error("Unknown 'type' \"$type\" passed to drizzled_start");
   }
 
-  mtr_init_args(\$args);
+  dtr_init_args(\$args);
 
-  if ( $opt_valgrind_mysqld )
+  if ( $opt_valgrind_drizzled )
   {
     valgrind_arguments($args, \$exe);
   }
 
-  mysqld_arguments($args,$mysqld,$extra_opt,$slave_master_info);
+  drizzled_arguments($args,$drizzled,$extra_opt,$slave_master_info);
 
   if ( $opt_gdb || $opt_manual_gdb)
   {
@@ -2664,7 +2664,7 @@
   elsif ( $opt_manual_debug )
   {
      print "\nStart $type in your debugger\n" .
-           "dir: $glob_mysql_test_dir\n" .
+           "dir: $glob_drizzle_test_dir\n" .
            "exe: $exe\n" .
 	   "args:  " . join(" ", @$args)  . "\n\n" .
 	   "Waiting ....\n";
@@ -2679,74 +2679,74 @@
   }
 
   # Remove the pidfile
-  unlink($mysqld->{'path_pid'});
+  unlink($drizzled->{'path_pid'});
 
   if ( defined $exe )
   {
-    mtr_verbose("running Drizzle with: $exe @$args");
-    $pid= mtr_spawn($exe, $args, "",
-		    $mysqld->{'path_myerr'},
-		    $mysqld->{'path_myerr'},
+    dtr_verbose("running Drizzle with: $exe @$args");
+    $pid= dtr_spawn($exe, $args, "",
+		    $drizzled->{'path_myerr'},
+		    $drizzled->{'path_myerr'},
 		    "",
 		    { append_log_file => 1 });
   }
 
 
-  if ( $wait_for_pid_file && !sleep_until_file_created($mysqld->{'path_pid'},
-						       $mysqld->{'start_timeout'},
+  if ( $wait_for_pid_file && !sleep_until_file_created($drizzled->{'path_pid'},
+						       $drizzled->{'start_timeout'},
 						       $pid))
   {
 
-    mtr_error("Failed to start mysqld $mysqld->{'type'}");
+    dtr_error("Failed to start drizzled $drizzled->{'type'}");
   }
 
 
   # Remember pid of the started process
-  $mysqld->{'pid'}= $pid;
+  $drizzled->{'pid'}= $pid;
 
   # Remember options used when starting
-  $mysqld->{'start_opts'}= $extra_opt;
-  $mysqld->{'start_slave_master_info'}= $slave_master_info;
+  $drizzled->{'start_opts'}= $extra_opt;
+  $drizzled->{'start_slave_master_info'}= $slave_master_info;
 
-  mtr_verbose("mysqld pid: $pid");
+  dtr_verbose("drizzled pid: $pid");
   return $pid;
 }
 
 
 sub stop_all_servers () {
 
-  mtr_report("Stopping All Servers");
+  dtr_report("Stopping All Servers");
 
   my %admin_pids; # hash of admin processes that requests shutdown
   my @kill_pids;  # list of processes to shutdown/kill
   my $pid;
 
   # Start shutdown of all started masters
-  foreach my $mysqld (@{$slave}, @{$master})
+  foreach my $drizzled (@{$slave}, @{$master})
   {
-    if ( $mysqld->{'pid'} )
+    if ( $drizzled->{'pid'} )
     {
-      $pid= mtr_server_shutdown($mysqld);
+      $pid= dtr_server_shutdown($drizzled);
       $admin_pids{$pid}= 1;
 
       push(@kill_pids,{
-		       pid      => $mysqld->{'pid'},
-                       real_pid => $mysqld->{'real_pid'},
-		       pidfile  => $mysqld->{'path_pid'},
-		       sockfile => $mysqld->{'path_sock'},
-		       port     => $mysqld->{'port'},
-                       errfile  => $mysqld->{'path_myerr'},
+		       pid      => $drizzled->{'pid'},
+                       real_pid => $drizzled->{'real_pid'},
+		       pidfile  => $drizzled->{'path_pid'},
+		       sockfile => $drizzled->{'path_sock'},
+		       port     => $drizzled->{'port'},
+                       errfile  => $drizzled->{'path_myerr'},
 		      });
 
-      $mysqld->{'pid'}= 0; # Assume we are done with it
+      $drizzled->{'pid'}= 0; # Assume we are done with it
     }
   }
 
   # Wait blocking until all shutdown processes has completed
-  mtr_wait_blocking(\%admin_pids);
+  dtr_wait_blocking(\%admin_pids);
 
   # Make sure that process has shutdown else try to kill them
-  mtr_check_stop_servers(\@kill_pids);
+  dtr_check_stop_servers(\@kill_pids);
 }
 
 
@@ -2760,32 +2760,32 @@
   if ( $tinfo->{'master_sh'} )
   {
     $do_restart= 1;           # Always restart if script to run
-    mtr_verbose("Restart master: Always restart if script to run");
+    dtr_verbose("Restart master: Always restart if script to run");
   }
   if ( $tinfo->{'force_restart'} )
   {
     $do_restart= 1; # Always restart if --force-restart in -opt file
-    mtr_verbose("Restart master: Restart forced with --force-restart");
+    dtr_verbose("Restart master: Restart forced with --force-restart");
   }
   elsif( $tinfo->{'component_id'} eq 'im' )
   {
     $do_restart= 1;
-    mtr_verbose("Restart master: Always restart for im tests");
+    dtr_verbose("Restart master: Always restart for im tests");
   }
   elsif ( $master->[0]->{'running_master_options'} and
 	  $master->[0]->{'running_master_options'}->{'timezone'} ne
 	  $tinfo->{'timezone'})
   {
     $do_restart= 1;
-    mtr_verbose("Restart master: Different timezone");
+    dtr_verbose("Restart master: Different timezone");
   }
   # Check that running master was started with same options
   # as the current test requires
-  elsif (! mtr_same_opts($master->[0]->{'start_opts'},
+  elsif (! dtr_same_opts($master->[0]->{'start_opts'},
                          $tinfo->{'master_opt'}) )
   {
     # Chech that diff is binlog format only
-    my $diff_opts= mtr_diff_opts($master->[0]->{'start_opts'},$tinfo->{'master_opt'});
+    my $diff_opts= dtr_diff_opts($master->[0]->{'start_opts'},$tinfo->{'master_opt'});
     if (scalar(@$diff_opts) eq 2) 
     {
       $do_restart= 1;
@@ -2793,7 +2793,7 @@
     else
     {
       $do_restart= 1;
-      mtr_verbose("Restart master: running with different options '" .
+      dtr_verbose("Restart master: running with different options '" .
 	         join(" ", @{$tinfo->{'master_opt'}}) . "' != '" .
 	  	join(" ", @{$master->[0]->{'start_opts'}}) . "'" );
     }
@@ -2803,12 +2803,12 @@
     if ( $opt_extern )
     {
       $do_restart= 0;
-      mtr_verbose("No restart: using extern master");
+      dtr_verbose("No restart: using extern master");
     }
     else
     {
       $do_restart= 1;
-      mtr_verbose("Restart master: master is not started");
+      dtr_verbose("Restart master: master is not started");
     }
   }
   return $do_restart;
@@ -2823,16 +2823,16 @@
 
   if ( $max_slave_num == 0)
   {
-    mtr_verbose("Skip slave restart: No testcase use slaves");
+    dtr_verbose("Skip slave restart: No testcase use slaves");
   }
   else
   {
 
     # Check if any slave is currently started
     my $any_slave_started= 0;
-    foreach my $mysqld (@{$slave})
+    foreach my $drizzled (@{$slave})
     {
-      if ( $mysqld->{'pid'} )
+      if ( $drizzled->{'pid'} )
       {
 	$any_slave_started= 1;
 	last;
@@ -2841,12 +2841,12 @@
 
     if ($any_slave_started)
     {
-      mtr_verbose("Restart slave: Slave is started, always restart");
+      dtr_verbose("Restart slave: Slave is started, always restart");
       $do_slave_restart= 1;
     }
     elsif ( $tinfo->{'slave_num'} )
     {
-      mtr_verbose("Restart slave: Test need slave");
+      dtr_verbose("Restart slave: Test need slave");
       $do_slave_restart= 1;
     }
   }
@@ -2880,24 +2880,24 @@
     delete $master->[0]->{'running_master_options'}; # Forget history
 
     # Start shutdown of all started masters
-    foreach my $mysqld (@{$master})
+    foreach my $drizzled (@{$master})
     {
-      if ( $mysqld->{'pid'} )
+      if ( $drizzled->{'pid'} )
       {
-        $pid= mtr_server_shutdown($mysqld);
+        $pid= dtr_server_shutdown($drizzled);
 
         $admin_pids{$pid}= 1;
 
         push(@kill_pids,{
-              pid      => $mysqld->{'pid'},
-              real_pid => $mysqld->{'real_pid'},
-              pidfile  => $mysqld->{'path_pid'},
-              sockfile => $mysqld->{'path_sock'},
-              port     => $mysqld->{'port'},
-              errfile   => $mysqld->{'path_myerr'},
+              pid      => $drizzled->{'pid'},
+              real_pid => $drizzled->{'real_pid'},
+              pidfile  => $drizzled->{'path_pid'},
+              sockfile => $drizzled->{'path_sock'},
+              port     => $drizzled->{'port'},
+              errfile   => $drizzled->{'path_myerr'},
         });
 
-        $mysqld->{'pid'}= 0; # Assume we are done with it
+        $drizzled->{'pid'}= 0; # Assume we are done with it
       }
     }
   }
@@ -2908,24 +2908,24 @@
     delete $slave->[0]->{'running_slave_options'}; # Forget history
 
     # Start shutdown of all started slaves
-    foreach my $mysqld (@{$slave})
+    foreach my $drizzled (@{$slave})
     {
-      if ( $mysqld->{'pid'} )
+      if ( $drizzled->{'pid'} )
       {
-        $pid= mtr_server_shutdown($mysqld);
+        $pid= dtr_server_shutdown($drizzled);
 
         $admin_pids{$pid}= 1;
 
         push(@kill_pids,{
-              pid      => $mysqld->{'pid'},
-              real_pid => $mysqld->{'real_pid'},
-              pidfile  => $mysqld->{'path_pid'},
-              sockfile => $mysqld->{'path_sock'},
-              port     => $mysqld->{'port'},
-              errfile  => $mysqld->{'path_myerr'},
+              pid      => $drizzled->{'pid'},
+              real_pid => $drizzled->{'real_pid'},
+              pidfile  => $drizzled->{'path_pid'},
+              sockfile => $drizzled->{'path_sock'},
+              port     => $drizzled->{'port'},
+              errfile  => $drizzled->{'path_myerr'},
         });
 
-        $mysqld->{'pid'}= 0; # Assume we are done with it
+        $drizzled->{'pid'}= 0; # Assume we are done with it
       }
     }
   }
@@ -2936,11 +2936,11 @@
   # ----------------------------------------------------------------------
 
   # Wait blocking until all shutdown processes has completed
-  mtr_wait_blocking(\%admin_pids);
+  dtr_wait_blocking(\%admin_pids);
 
 
   # Make sure that process has shutdown else try to kill them
-  mtr_check_stop_servers(\@kill_pids);
+  dtr_check_stop_servers(\@kill_pids);
 }
 
 
@@ -2958,14 +2958,14 @@
   my $tinfo= shift;
   my $tname= $tinfo->{'name'};
 
-  if ( $tinfo->{'component_id'} eq 'mysqld' )
+  if ( $tinfo->{'component_id'} eq 'drizzled' )
   {
     if ( !$master->[0]->{'pid'} )
     {
-      # Master mysqld is not started
+      # Master drizzled is not started
       do_before_start_master($tinfo);
 
-      mysqld_start($master->[0],$tinfo->{'master_opt'},[]);
+      drizzled_start($master->[0],$tinfo->{'master_opt'},[]);
 
     }
 
@@ -2986,7 +2986,7 @@
     {
       if ( ! $slave->[$idx]->{'pid'} )
       {
-	mysqld_start($slave->[$idx],$tinfo->{'slave_opt'},
+	drizzled_start($slave->[$idx],$tinfo->{'slave_opt'},
 		     $tinfo->{'slave_mi'});
 
       }
@@ -2996,17 +2996,17 @@
     $slave->[0]->{'running_slave_options'}= $tinfo;
   }
 
-  # Wait for mysqld's to start
-  foreach my $mysqld (@{$master},@{$slave})
+  # Wait for drizzled's to start
+  foreach my $drizzled (@{$master},@{$slave})
   {
 
-    next if !$mysqld->{'pid'};
+    next if !$drizzled->{'pid'};
 
-    if (mysqld_wait_started($mysqld))
+    if (drizzled_wait_started($drizzled))
     {
       # failed to start
       $tinfo->{'comment'}=
-	"Failed to start $mysqld->{'type'} mysqld $mysqld->{'idx'}";
+	"Failed to start $drizzled->{'type'} drizzled $drizzled->{'idx'}";
       return 1;
     }
   }
@@ -3025,48 +3025,48 @@
 sub run_check_testcase ($$) {
 
   my $mode=     shift;
-  my $mysqld=   shift;
+  my $drizzled=   shift;
 
-  my $name= "check-" . $mysqld->{'type'} . $mysqld->{'idx'};
+  my $name= "check-" . $drizzled->{'type'} . $drizzled->{'idx'};
 
   my $args;
-  mtr_init_args(\$args);
-
-  mtr_add_arg($args, "--no-defaults");
-  mtr_add_arg($args, "--silent");
-  mtr_add_arg($args, "--tmpdir=%s", $opt_tmpdir);
-
-  mtr_add_arg($args, "--port=%d", $mysqld->{'port'});
-  mtr_add_arg($args, "--database=test");
-  mtr_add_arg($args, "--user=%s", $opt_user);
-  mtr_add_arg($args, "--password=");
-
-  mtr_add_arg($args, "-R");
-  mtr_add_arg($args, "$opt_vardir/tmp/$name.result");
+  dtr_init_args(\$args);
+
+  dtr_add_arg($args, "--no-defaults");
+  dtr_add_arg($args, "--silent");
+  dtr_add_arg($args, "--tmpdir=%s", $opt_tmpdir);
+
+  dtr_add_arg($args, "--port=%d", $drizzled->{'port'});
+  dtr_add_arg($args, "--database=test");
+  dtr_add_arg($args, "--user=%s", $opt_user);
+  dtr_add_arg($args, "--password=");
+
+  dtr_add_arg($args, "-R");
+  dtr_add_arg($args, "$opt_vardir/tmp/$name.result");
 
   if ( $mode eq "before" )
   {
-    mtr_add_arg($args, "--record");
+    dtr_add_arg($args, "--record");
   }
 
   if ( $opt_testdir )
   {
-    mtr_add_arg($args, "--testdir=%s", $opt_testdir);
+    dtr_add_arg($args, "--testdir=%s", $opt_testdir);
   }
 
-  my $res = mtr_run_test($exe_drizzletest,$args,
+  my $res = dtr_run_test($exe_drizzletest,$args,
 	        "include/check-testcase.test", "", "", "");
 
   if ( $res == 1  and $mode eq "after")
   {
-    mtr_run("diff",["-u",
+    dtr_run("diff",["-u",
 		    "$opt_vardir/tmp/$name.result",
 		    "$opt_vardir/tmp/$name.reject"],
 	    "", "", "", "");
   }
   elsif ( $res )
   {
-    mtr_error("Could not execute 'check-testcase' $mode testcase");
+    dtr_error("Could not execute 'check-testcase' $mode testcase");
   }
   return $res;
 }
@@ -3081,18 +3081,18 @@
   my $args;
 
   {
-    mysqld_start($master->[0],[],[]);
+    drizzled_start($master->[0],[],[]);
     if ( ! $master->[0]->{'pid'} )
     {
-      mtr_error("Can't start the mysqld server");
+      dtr_error("Can't start the drizzled server");
     }
-    mysqld_wait_started($master->[0]);
+    drizzled_wait_started($master->[0]);
   }
 
   my $tinfo = {};
   $tinfo->{'name'} = 'report features';
   $tinfo->{'result_file'} = undef;
-  $tinfo->{'component_id'} = 'mysqld';
+  $tinfo->{'component_id'} = 'drizzled';
   $tinfo->{'path'} = 'include/report-features.test';
   $tinfo->{'timezone'}=  "GMT-3";
   $tinfo->{'slave_num'} = 0;
@@ -3113,56 +3113,56 @@
   my $exe= $exe_drizzletest;
   my $args;
 
-  mtr_init_args(\$args);
+  dtr_init_args(\$args);
 
-  mtr_add_arg($args, "--no-defaults");
-  mtr_add_arg($args, "--silent");
-  mtr_add_arg($args, "--tmpdir=%s", $opt_tmpdir);
-  mtr_add_arg($args, "--logdir=%s/log", $opt_vardir);
+  dtr_add_arg($args, "--no-defaults");
+  dtr_add_arg($args, "--silent");
+  dtr_add_arg($args, "--tmpdir=%s", $opt_tmpdir);
+  dtr_add_arg($args, "--logdir=%s/log", $opt_vardir);
 
   # Log line number and time  for each line in .test file
-  mtr_add_arg($args, "--mark-progress")
+  dtr_add_arg($args, "--mark-progress")
     if $opt_mark_progress;
 
   {
-    mtr_add_arg($args, "--port=%d", $master->[0]->{'port'});
-    mtr_add_arg($args, "--database=test");
-    mtr_add_arg($args, "--user=%s", $opt_user);
-    mtr_add_arg($args, "--password=");
+    dtr_add_arg($args, "--port=%d", $master->[0]->{'port'});
+    dtr_add_arg($args, "--database=test");
+    dtr_add_arg($args, "--user=%s", $opt_user);
+    dtr_add_arg($args, "--password=");
   }
 
   if ( $opt_strace_client )
   {
     $exe=  "strace";            # FIXME there are ktrace, ....
-    mtr_add_arg($args, "-o");
-    mtr_add_arg($args, "%s/log/drizzletest.strace", $opt_vardir);
-    mtr_add_arg($args, "$exe_drizzletest");
+    dtr_add_arg($args, "-o");
+    dtr_add_arg($args, "%s/log/drizzletest.strace", $opt_vardir);
+    dtr_add_arg($args, "$exe_drizzletest");
   }
 
   if ( $opt_timer )
   {
-    mtr_add_arg($args, "--timer-file=%s/log/timer", $opt_vardir);
+    dtr_add_arg($args, "--timer-file=%s/log/timer", $opt_vardir);
   }
 
   if ( $opt_compress )
   {
-    mtr_add_arg($args, "--compress");
+    dtr_add_arg($args, "--compress");
   }
 
   if ( $opt_sleep )
   {
-    mtr_add_arg($args, "--sleep=%d", $opt_sleep);
+    dtr_add_arg($args, "--sleep=%d", $opt_sleep);
   }
 
   if ( $opt_debug )
   {
-    mtr_add_arg($args, "--debug=d:t:A,%s/log/drizzletest.trace",
+    dtr_add_arg($args, "--debug=d:t:A,%s/log/drizzletest.trace",
 		$path_vardir_trace);
   }
 
   if ( $opt_testdir )
   {
-    mtr_add_arg($args, "--testdir=%s", $opt_testdir);
+    dtr_add_arg($args, "--testdir=%s", $opt_testdir);
   }
 
 
@@ -3170,7 +3170,7 @@
   # export DRIZZLE_TEST variable containing <path>/drizzletest <args>
   # ----------------------------------------------------------------------
   $ENV{'DRIZZLE_TEST'}=
-    mtr_native_path($exe_drizzletest) . " " . join(" ", @$args);
+    dtr_native_path($exe_drizzletest) . " " . join(" ", @$args);
 
   # ----------------------------------------------------------------------
   # Add arguments that should not go into the DRIZZLE_TEST env var
@@ -3182,23 +3182,23 @@
     # We do this here, since we do not want to Valgrind the nested invocations
     # of drizzletest; that would mess up the stderr output causing test failure.
     my @args_saved = @$args;
-    mtr_init_args(\$args);
+    dtr_init_args(\$args);
     valgrind_arguments($args, \$exe);
-    mtr_add_arg($args, "%s", $_) for @args_saved;
+    dtr_add_arg($args, "%s", $_) for @args_saved;
   }
 
-  mtr_add_arg($args, "--test-file=%s", $tinfo->{'path'});
+  dtr_add_arg($args, "--test-file=%s", $tinfo->{'path'});
 
   # Number of lines of resut to include in failure report
-  mtr_add_arg($args, "--tail-lines=20");
+  dtr_add_arg($args, "--tail-lines=20");
 
   if ( defined $tinfo->{'result_file'} ) {
-    mtr_add_arg($args, "--result-file=%s", $tinfo->{'result_file'});
+    dtr_add_arg($args, "--result-file=%s", $tinfo->{'result_file'});
   }
 
   if ( $opt_record )
   {
-    mtr_add_arg($args, "--record");
+    dtr_add_arg($args, "--record");
   }
 
   if ( $opt_client_gdb )
@@ -3216,24 +3216,24 @@
 
   if ( $opt_check_testcases )
   {
-    foreach my $mysqld (@{$master}, @{$slave})
+    foreach my $drizzled (@{$master}, @{$slave})
     {
-      if ($mysqld->{'pid'})
+      if ($drizzled->{'pid'})
       {
-	run_check_testcase("before", $mysqld);
+	run_check_testcase("before", $drizzled);
       }
     }
   }
 
-  my $res = mtr_run_test($exe,$args,"","",$path_timefile,"");
+  my $res = dtr_run_test($exe,$args,"","",$path_timefile,"");
 
   if ( $opt_check_testcases )
   {
-    foreach my $mysqld (@{$master}, @{$slave})
+    foreach my $drizzled (@{$master}, @{$slave})
     {
-      if ($mysqld->{'pid'})
+      if ($drizzled->{'pid'})
       {
-	if (run_check_testcase("after", $mysqld))
+	if (run_check_testcase("after", $drizzled))
 	{
 	  # Check failed, mark the test case with that info
 	  $tinfo->{'check_testcase_failed'}= 1;
@@ -3263,14 +3263,14 @@
   if ( $type eq "client" )
   {
     # write init file for client
-    mtr_tofile($dbx_init_file,
+    dtr_tofile($dbx_init_file,
                "runargs $str\n" .
                "run\n");
   }
   else
   {
     # write init file for drizzled
-    mtr_tofile($dbx_init_file,
+    dtr_tofile($dbx_init_file,
                "stop in __1cIdrizzledLmysql_parse6Fpn0AHSession_pkcI_v_\n" .
                "runargs $str\n" .
                "run\n" .
@@ -3288,14 +3288,14 @@
   }
 
   $$args= [];
-  mtr_add_arg($$args, "-title");
-  mtr_add_arg($$args, "$type");
-  mtr_add_arg($$args, "-e");
+  dtr_add_arg($$args, "-title");
+  dtr_add_arg($$args, "$type");
+  dtr_add_arg($$args, "-e");
 
-  mtr_add_arg($$args, "dbx");
-  mtr_add_arg($$args, "-c");
-  mtr_add_arg($$args, "source $dbx_init_file");
-  mtr_add_arg($$args, "$$exe");
+  dtr_add_arg($$args, "dbx");
+  dtr_add_arg($$args, "-c");
+  dtr_add_arg($$args, "source $dbx_init_file");
+  dtr_add_arg($$args, "$$exe");
 
   $$exe= "xterm";
 }
@@ -3330,15 +3330,15 @@
   if ( $type eq "client" )
   {
     # write init file for client
-    mtr_tofile($gdb_init_file,
+    dtr_tofile($gdb_init_file,
 	       "set args $str\n" .
                "$extra_gdb_init" .
 	       "break main\n");
   }
   else
   {
-    # write init file for mysqld
-    mtr_tofile($gdb_init_file,
+    # write init file for drizzled
+    dtr_tofile($gdb_init_file,
 	       "set args $str\n" .
                "$extra_gdb_init" .
                "set breakpoint pending on\n" .
@@ -3353,7 +3353,7 @@
   if ( $opt_manual_gdb )
   {
      print "\nTo start gdb for $type, type in another window:\n";
-     print "$glob_mysql_test_dir/../libtool --mode=execute gdb -cd $glob_mysql_test_dir -x $gdb_init_file $$exe\n";
+     print "$glob_drizzle_test_dir/../libtool --mode=execute gdb -cd $glob_drizzle_test_dir -x $gdb_init_file $$exe\n";
 
      # Indicate the exe should not be started
      $$exe= undef;
@@ -3361,20 +3361,20 @@
   }
 
   $$args= [];
-  mtr_add_arg($$args, "-title");
-  mtr_add_arg($$args, "$type");
-  mtr_add_arg($$args, "-e");
+  dtr_add_arg($$args, "-title");
+  dtr_add_arg($$args, "$type");
+  dtr_add_arg($$args, "-e");
 
   if ( $exe_libtool )
   {
-    mtr_add_arg($$args, $exe_libtool);
-    mtr_add_arg($$args, "--mode=execute");
+    dtr_add_arg($$args, $exe_libtool);
+    dtr_add_arg($$args, "--mode=execute");
   }
 
-  mtr_add_arg($$args, "gdb");
-  mtr_add_arg($$args, "-x");
-  mtr_add_arg($$args, "$gdb_init_file");
-  mtr_add_arg($$args, "$$exe");
+  dtr_add_arg($$args, "gdb");
+  dtr_add_arg($$args, "-x");
+  dtr_add_arg($$args, "$gdb_init_file");
+  dtr_add_arg($$args, "$$exe");
 
   $$exe= "xterm";
 }
@@ -3398,14 +3398,14 @@
   if ( $type eq "client" )
   {
     # write init file for client
-    mtr_tofile($gdb_init_file,
+    dtr_tofile($gdb_init_file,
 	       "set args $str\n" .
 	       "break main\n");
   }
   else
   {
-    # write init file for mysqld
-    mtr_tofile($gdb_init_file,
+    # write init file for drizzled
+    dtr_tofile($gdb_init_file,
 	       "file $$exe\n" .
 	       "set args $str\n" .
 	       "break drizzled::mysql_parse\n" .
@@ -3417,7 +3417,7 @@
   if ( $opt_manual_ddd )
   {
      print "\nTo start ddd for $type, type in another window:\n";
-     print "ddd -cd $glob_mysql_test_dir -x $gdb_init_file $$exe\n";
+     print "ddd -cd $glob_drizzle_test_dir -x $gdb_init_file $$exe\n";
 
      # Indicate the exe should not be started
      $$exe= undef;
@@ -3429,15 +3429,15 @@
   if ( $exe_libtool )
   {
     $$exe= $exe_libtool;
-    mtr_add_arg($$args, "--mode=execute");
-    mtr_add_arg($$args, "ddd");
+    dtr_add_arg($$args, "--mode=execute");
+    dtr_add_arg($$args, "ddd");
   }
   else
   {
     $$exe= "ddd";
   }
-  mtr_add_arg($$args, "--command=$gdb_init_file");
-  mtr_add_arg($$args, "$save_exe");
+  dtr_add_arg($$args, "--command=$gdb_init_file");
+  dtr_add_arg($$args, "$save_exe");
 }
 
 
@@ -3475,7 +3475,7 @@
 #  }
   else
   {
-    mtr_error("Unknown argument \"$debugger\" passed to --debugger");
+    dtr_error("Unknown argument \"$debugger\" passed to --debugger");
   }
 }
 
@@ -3489,25 +3489,25 @@
 
   if ( $opt_callgrind)
   {
-    mtr_add_arg($args, "--tool=callgrind");
+    dtr_add_arg($args, "--tool=callgrind");
   }
   elsif ($opt_massif)
   {
-    mtr_add_arg($args, "--tool=massif");
+    dtr_add_arg($args, "--tool=massif");
   }
   else
   {
-    mtr_add_arg($args, "--tool=memcheck"); # From >= 2.1.2 needs this option
-    mtr_add_arg($args, "--leak-check=yes");
-    mtr_add_arg($args, "--num-callers=16");
-    mtr_add_arg($args, "--suppressions=%s/valgrind.supp", $glob_mysql_test_dir)
-      if -f "$glob_mysql_test_dir/valgrind.supp";
+    dtr_add_arg($args, "--tool=memcheck"); # From >= 2.1.2 needs this option
+    dtr_add_arg($args, "--leak-check=yes");
+    dtr_add_arg($args, "--num-callers=16");
+    dtr_add_arg($args, "--suppressions=%s/valgrind.supp", $glob_drizzle_test_dir)
+      if -f "$glob_drizzle_test_dir/valgrind.supp";
   }
 
   # Add valgrind options, can be overriden by user
-  mtr_add_arg($args, '%s', $_) for (@valgrind_args);
+  dtr_add_arg($args, '%s', $_) for (@valgrind_args);
 
-  mtr_add_arg($args, $$exe);
+  dtr_add_arg($args, $$exe);
 
   $$exe= $opt_valgrind_path || "valgrind";
 
@@ -3521,12 +3521,12 @@
 }
 
 
-sub mysqld_wait_started($){
-  my $mysqld= shift;
+sub drizzled_wait_started($){
+  my $drizzled= shift;
 
-  if (sleep_until_file_created($mysqld->{'path_pid'},
-            $mysqld->{'start_timeout'},
-            $mysqld->{'pid'}) == 0)
+  if (sleep_until_file_created($drizzled->{'path_pid'},
+            $drizzled->{'start_timeout'},
+            $drizzled->{'pid'}) == 0)
   {
     # Failed to wait for pid file
     return 1;
@@ -3534,7 +3534,7 @@
 
   # Get the "real pid" of the process, it will be used for killing
   # the process in ActiveState's perl on windows
-  $mysqld->{'real_pid'}= mtr_get_pid_from_file($mysqld->{'path_pid'});
+  $drizzled->{'real_pid'}= dtr_get_pid_from_file($drizzled->{'path_pid'});
 
   return 0;
 }
@@ -3604,7 +3604,7 @@
                         using a builtin list of standard locations
                         for tmpfs (/dev/shm)
                         The option can also be set using environment
-                        variable MTR_MEM=[DIR]
+                        variable DTR_MEM=[DIR]
 
 Options to control what test suites or cases to run
 
@@ -3620,7 +3620,7 @@
                         list of suite names.
                         The default is: "$opt_suites_default"
   skip-rpl              Skip the replication test cases.
-  combination="ARG1 .. ARG2" Specify a set of "mysqld" arguments for one
+  combination="ARG1 .. ARG2" Specify a set of "drizzled" arguments for one
                         combination.
   skip-combination      Skip any combination options and combinations files
   repeat-test=n         How many times to repeat each test (default: 1)
@@ -3629,8 +3629,8 @@
 
   master_port=PORT      Specify the port number used by the first master
   slave_port=PORT       Specify the port number used by the first slave
-  mtr-build-thread=#    Specify unique collection of ports. Can also be set by
-                        setting the environment variable MTR_BUILD_THREAD.
+  dtr-build-thread=#    Specify unique collection of ports. Can also be set by
+                        setting the environment variable DTR_BUILD_THREAD.
 
 Options for test case authoring
 
@@ -3640,7 +3640,7 @@
 
 Options that pass on options
 
-  mysqld=ARGS           Specify additional arguments to "mysqld"
+  drizzled=ARGS           Specify additional arguments to "drizzled"
 
 Options to run test on running server
 
@@ -3652,18 +3652,18 @@
   client-ddd            Start drizzletest client in ddd
   client-debugger=NAME  Start drizzletest in the selected debugger
   client-gdb            Start drizzletest client in gdb
-  ddd                   Start mysqld in ddd
+  ddd                   Start drizzled in ddd
   debug                 Dump trace output for all servers and client programs
-  debugger=NAME         Start mysqld in the selected debugger
-  gdb                   Start the mysqld(s) in gdb
-  manual-debug          Let user manually start mysqld in debugger, before
+  debugger=NAME         Start drizzled in the selected debugger
+  gdb                   Start the drizzled(s) in gdb
+  manual-debug          Let user manually start drizzled in debugger, before
                         running test(s)
-  manual-gdb            Let user manually start mysqld in gdb, before running
-                        test(s)
-  manual-ddd            Let user manually start mysqld in ddd, before running
-                        test(s)
-  master-binary=PATH    Specify the master "mysqld" to use
-  slave-binary=PATH     Specify the slave "mysqld" to use
+  manual-gdb            Let user manually start drizzled in gdb, before running
+                        test(s)
+  manual-ddd            Let user manually start drizzled in ddd, before running
+                        test(s)
+  master-binary=PATH    Specify the master "drizzled" to use
+  slave-binary=PATH     Specify the slave "drizzled" to use
   strace-client         Create strace output for drizzletest client
   max-save-core         Limit the number of core files saved (to avoid filling
                         up disks for heavily crashing server). Defaults to
@@ -3673,13 +3673,13 @@
 
   gcov                  FIXME
   gprof                 See online documentation on how to use it.
-  valgrind              Run the "drizzletest" and "mysqld" executables using
+  valgrind              Run the "drizzletest" and "drizzled" executables using
                         valgrind with default options
   valgrind-all          Synonym for --valgrind
   valgrind-drizzleslap  Run "drizzleslap" with valgrind.
   valgrind-drizzletest  Run the "drizzletest" and "drizzle_client_test" executable
                         with valgrind
-  valgrind-mysqld       Run the "mysqld" executable with valgrind
+  valgrind-drizzled       Run the "drizzled" executable with valgrind
   valgrind-options=ARGS Deprecated, use --valgrind-option
   valgrind-option=ARGS  Option to give valgrind, replaces default option(s),
                         can be specified more then once
@@ -3703,11 +3703,11 @@
 
   testcase-timeout=MINUTES Max test case run time (default $default_testcase_timeout)
   suite-timeout=MINUTES Max test suite run time (default $default_suite_timeout)
-  warnings | log-warnings Pass --log-warnings to mysqld
+  warnings | log-warnings Pass --log-warnings to drizzled
 
   sleep=SECONDS         Passed to drizzletest, will be used as fixed sleep time
 
 HERE
-  mtr_exit(1);
+  dtr_exit(1);
 
 }

